(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    205354,       4445]
NotebookOptionsPosition[    200040,       4350]
NotebookOutlinePosition[    200399,       4366]
CellTagsIndexPosition[    200356,       4363]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"flyTurnCoords", "[", 
    RowBox[{"f_", ",", " ", "g_", ",", "Vfly_", ",", "nTurns_"}], "]"}], " ", 
   ":=", " ", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{
      RowBox[{"f", "[", "t", "]"}], " ", "is", " ", "the", " ", "position", 
      " ", "of", " ", "car", " ", "1", " ", "at", " ", "time", " ", 
      RowBox[{"t", ".", " ", 
       RowBox[{"f", "[", "0", "]"}]}], " ", "is", " ", "assumed", " ", "to", 
      " ", "be", " ", "0.", "\[IndentingNewLine]", 
      RowBox[{"g", "[", "t", "]"}], " ", "is", " ", "the", " ", "position", 
      " ", "of", " ", "car", " ", "2", " ", "at", " ", "time", " ", 
      RowBox[{"t", ".", "\[IndentingNewLine]", "Vfly"}], " ", "is", " ", "a", 
      " ", "order", " ", "pair", " ", 
      RowBox[{"{", 
       RowBox[{"Vright", ",", " ", "Vleft"}], "}"}]}], " ", "=", " ", 
     RowBox[{
      RowBox[{"fly", "'"}], "s", " ", "velocities", " ", "to", " ", "the", 
      " ", "right", " ", "and", " ", "to", " ", "the", " ", 
      RowBox[{"left", ".", "\[IndentingNewLine]", "nTurns"}], " ", "is", " ", 
      "the", " ", "number", " ", "of", " ", "time", " ", "to", " ", 
      "calculate", " ", 
      RowBox[{"fly", "'"}], "s", " ", 
      RowBox[{"trajectory", ".", "  ", "\[IndentingNewLine]", "The"}], " ", 
      RowBox[{"fly", "'"}], "s", " ", "initial", " ", "position", " ", "is", 
      " ", "assumed", " ", "to", " ", "be", " ", "at", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"0", ",", " ", 
         RowBox[{"f", "[", "0", "]"}]}], ")"}], ".", "\[IndentingNewLine]", 
       "This"}], " ", "function", " ", "returns", " ", 
      RowBox[{"{", 
       RowBox[{"t", ",", " ", "x"}], "}"}], " ", "coordinates", " ", "that", 
      " ", "the", " ", "fly", " ", "meets", " ", "the", " ", 
      RowBox[{"cars", "."}]}]}], "\[IndentingNewLine]", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "V1", ",", "V2", ",", "t0", ",", "x0", " ", ",", " ", "pt", " ", ",", 
       " ", 
       RowBox[{"coords", " ", "=", " ", 
        RowBox[{"{", "}"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"V1", ",", "V2"}], "}"}], " ", "=", " ", "Vfly"}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"t0", ",", "x0"}], "}"}], " ", "=", " ", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"f", "[", "0", "]"}]}], "}"}]}], ";", "\[IndentingNewLine]", 
      
      RowBox[{"pt", "=", " ", 
       RowBox[{"{", 
        RowBox[{"t0", ",", "x0"}], "}"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"coords", " ", "=", " ", 
       RowBox[{"Append", "[", 
        RowBox[{"coords", ",", "pt"}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"For", "[", 
       RowBox[{
        RowBox[{"turn", " ", "=", " ", "1"}], ",", " ", 
        RowBox[{"turn", " ", "\[LessEqual]", " ", "nTurns"}], ",", " ", 
        RowBox[{"turn", " ", "++"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"pt", " ", "=", " ", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"t", ",", " ", 
             RowBox[{"g", "[", "t", "]"}]}], "}"}], "/.", " ", 
           RowBox[{"FindRoot", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"x0", " ", "+", " ", 
               RowBox[{"V1", " ", 
                RowBox[{"(", 
                 RowBox[{"t", "-", "t0"}], ")"}]}]}], " ", "\[Equal]", 
              RowBox[{"g", "[", "t", "]"}]}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"t", ",", "t0"}], "}"}]}], "]"}]}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"coords", " ", "=", " ", 
          RowBox[{"Append", "[", 
           RowBox[{"coords", ",", " ", "pt"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"t0", ",", "x0"}], "}"}], " ", "=", " ", "pt"}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"pt", " ", "=", " ", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"t", ",", " ", 
             RowBox[{"f", "[", "t", "]"}]}], "}"}], " ", "/.", " ", 
           RowBox[{"FindRoot", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"x0", " ", "+", " ", 
               RowBox[{"V2", " ", 
                RowBox[{"(", 
                 RowBox[{"t", "-", "t0"}], ")"}]}]}], " ", "\[Equal]", 
              RowBox[{"f", "[", "t", "]"}]}], ",", " ", 
             RowBox[{"{", 
              RowBox[{"t", ",", "t0"}], "}"}]}], "]"}]}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{"coords", " ", "=", " ", 
          RowBox[{"Append", "[", 
           RowBox[{"coords", ",", " ", "pt"}], "]"}]}], ";", 
         "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{"t0", ",", "x0"}], "}"}], " ", "=", " ", "pt"}], ";"}]}], 
       "]"}], ";", "\[IndentingNewLine]", "coords"}]}], "\[IndentingNewLine]",
     "]"}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"pathLength", "[", "coords_", "]"}], ":=", " ", 
    RowBox[{"Apply", "[", 
     RowBox[{"Plus", ",", 
      RowBox[{"Abs", "[", 
       RowBox[{"Differences", "[", 
        RowBox[{
         RowBox[{"Transpose", "[", "coords", "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], "]"}], "]"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"pathLength", "[", "coords_", "]"}], " ", "calculates", " ", 
    "the", " ", "distance", " ", "that", " ", "the", " ", "fly", " ", "flies",
     " ", "between", " ", "points", " ", "specified", " ", "in", " ", 
    RowBox[{"coords", ".", "  ", "coords"}], " ", "should", " ", "be", " ", 
    "the", " ", 
    RowBox[{"{", 
     RowBox[{"t", ",", "x"}], "}"}], " ", "coordinates", " ", "obtained", " ",
     "from", " ", 
    RowBox[{"flyTurnCoords", "[", " ", "]"}]}], " ", "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"flyPathLength", "[", 
    RowBox[{"T_", ",", "d_", ",", "V1_", ",", " ", "V2_"}], "]"}], " ", ":=", 
   " ", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"d", 
       RowBox[{"(", 
        RowBox[{"V1", "-", "V2"}], ")"}]}], " ", "+", " ", 
      RowBox[{"2", " ", "V1", " ", "V2", " ", "T"}]}], ")"}], "/", 
    RowBox[{"(", 
     RowBox[{"V1", "+", "V2"}], ")"}]}]}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "Distance", " ", "that", " ", "the", " ", "fly", " ", "travels", " ", 
    "between", " ", "the", " ", "two", " ", "cars", " ", "untill", " ", "the",
     " ", 
    RowBox[{"collision", ".", "  ", "The"}], " ", "collision", " ", "is", " ",
     "assumed", " ", "to", " ", "be", " ", "at", " ", "distance", " ", "d", 
    " ", "from", " ", "the", " ", 
    RowBox[{"origin", ".", " ", "The"}], " ", "time", " ", "of", " ", "the", 
    " ", "collision", " ", "is", " ", "assumed", " ", "to", " ", "be", " ", 
    "at", " ", 
    RowBox[{"T", ".", " ", "V1"}], " ", "is", " ", "the", " ", 
    RowBox[{"fly", "'"}], "s", " ", "speed", " ", "to", " ", "the", " ", 
    RowBox[{"right", ".", " ", "V2"}], " ", "is", " ", "the", " ", 
    RowBox[{"fly", "'"}], " ", "speed", " ", "to", " ", "the", " ", 
    RowBox[{"left", "."}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"flyPathLength", "[", 
    RowBox[{"T_", ",", " ", "d_", ",", "Vfly_"}], "]"}], ":=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"V1", ",", " ", "V2"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"(*", " ", 
      RowBox[{
       RowBox[{"If", " ", "V1"}], ",", " ", 
       RowBox[{
       "V2", " ", "is", " ", "implicitly", " ", "passed", " ", "in", " ", 
        "Vfly", " ", "vector"}], ",", " ", 
       RowBox[{"use", " ", "this", " ", "version", " ", "of", " ", 
        RowBox[{"function", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"V1", ",", " ", "V2"}], "}"}], " ", "=", " ", 
       RowBox[{"Abs", "[", "Vfly", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"flyPathLength", "[", 
       RowBox[{"T", ",", " ", "d", ",", " ", "V1", ",", " ", "V2"}], 
       "]"}]}]}], "]"}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"showFlyFlight", "[", 
   RowBox[{
   "f_", ",", " ", "g_", " ", ",", "Vfly_", ",", " ", "tmax_", ",", " ", 
    "iterations_"}], "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Draw", " ", "the", " ", "positions", " ", "of", " ", "car", " ", "1"}], 
    ",", " ", 
    RowBox[{"car", " ", "2"}], ",", " ", 
    RowBox[{"and", " ", "the", " ", 
     RowBox[{"fly", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"flightLength", ",", "coords", ",", "  ", "g1", ",", " ", "g2"}],
      "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"coords", " ", "=", " ", 
      RowBox[{"flyTurnCoords", "[", 
       RowBox[{
       "f", ",", " ", "g", " ", ",", " ", "Vfly", ",", " ", "iterations"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"g1", " ", "=", " ", 
      RowBox[{"Plot", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"f", "[", "t", "]"}], ",", " ", 
          RowBox[{"g", "[", "t", "]"}]}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"t", ",", " ", "0", ",", " ", "tmax"}], "}"}], ",", " ", 
        RowBox[{"PlotLabel", "\[Rule]", 
         RowBox[{
         "\"\<Spacetime diagram of two trains and a fly\\n Fly's path length \
= \>\"", " ", "<>", " ", 
          RowBox[{"ToString", "[", 
           RowBox[{"pathLength", "[", "coords", "]"}], "]"}]}]}], ",", " ", 
        RowBox[{"AxesLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"\"\<t\>\"", ",", "\"\<x\>\""}], "}"}]}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"g2", " ", "=", 
      RowBox[{"Graphics", "[", 
       RowBox[{"Line", "[", "coords", "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"Print", "[", 
        RowBox[{"\"\<Path length = \>\"", ",", 
         RowBox[{"pathLength", "[", "coords", "]"}]}], "]"}], ";"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"Show", "[", 
      RowBox[{"g1", ",", "g2"}], "]"}]}]}], 
   "]"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.741088033584647*^9, 3.741088046317493*^9}, {
   3.7410880902351837`*^9, 3.741088168168478*^9}, {3.741088235985858*^9, 
   3.741088299695846*^9}, {3.7410883315660343`*^9, 3.7410884662830143`*^9}, {
   3.741088524580064*^9, 3.741088666820574*^9}, {3.741088733556086*^9, 
   3.7410888965145617`*^9}, {3.741089236736548*^9, 3.741089246136088*^9}, {
   3.7410894680399227`*^9, 3.7410894747809067`*^9}, {3.7410895652270927`*^9, 
   3.741089593724916*^9}, 3.7410896464671297`*^9, {3.741089778307208*^9, 
   3.741089811602417*^9}, {3.74108987091446*^9, 3.741089885614005*^9}, {
   3.7410899543410807`*^9, 3.7410899985679703`*^9}, {3.741090185912346*^9, 
   3.7410902187111597`*^9}, {3.7410905469706717`*^9, 3.741090549752543*^9}, {
   3.741090582281746*^9, 3.74109059396004*^9}, {3.7410906975247717`*^9, 
   3.7410906979595537`*^9}, {3.741090865672141*^9, 3.741090892465084*^9}, {
   3.741094870875201*^9, 3.741094892998439*^9}, {3.741094935943348*^9, 
   3.741095106312149*^9}, 3.7410952497014437`*^9, {3.741095282868023*^9, 
   3.741095586363325*^9}, {3.7410956272384233`*^9, 3.74109570328155*^9}, {
   3.74109586416523*^9, 3.7410958706560507`*^9}, {3.741095918818186*^9, 
   3.741095926794289*^9}, {3.741096046904217*^9, 3.741096048130934*^9}, {
   3.741096090648037*^9, 3.7410960910399323`*^9}, {3.7413204625278873`*^9, 
   3.7413207429112*^9}, {3.7413207915796003`*^9, 3.741320925377787*^9}, {
   3.741320994204484*^9, 3.741321135523595*^9}, {3.7413212017989492`*^9, 
   3.7413213547327347`*^9}, {3.741321392456848*^9, 3.741321440831764*^9}, {
   3.741321511573469*^9, 3.7413215148062353`*^9}, {3.741322056469454*^9, 
   3.741322059404696*^9}, {3.7413229819867287`*^9, 
   3.74132311976884*^9}},ExpressionUUID->"26c5627a-761b-4c37-88eb-\
ad85b5c29dbf"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Testing", " ", "with", " ", "car", " ", "1", " ", "moving", " ", "to", 
     " ", "the", " ", "right", " ", "at", " ", "40", " ", "kmph"}], ",", " ", 
    
    RowBox[{
    "car", " ", "2", " ", "moving", " ", "to", " ", "the", " ", "left", " ", 
     "at", " ", "60", " ", 
     RowBox[{"kmph", ".", " ", "Car"}], " ", 
     RowBox[{"2", "'"}], "s", " ", "initial", " ", "position", " ", "is", " ",
      "40", " ", "km", " ", "away", " ", "from", " ", "car", " ", "1.", " ", 
     "\[IndentingNewLine]", "The", " ", "fly", " ", "flies", " ", "at", " ", 
     "80", " ", "kmph", " ", "to", " ", "both", " ", "right", " ", "and", " ", 
     RowBox[{"left", "."}]}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "t_", "]"}], " ", ":=", " ", 
     RowBox[{"0", " ", "+", " ", 
      RowBox[{"40", " ", "t"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", "t_", "]"}], " ", ":=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "60"}], " ", "t"}], " ", "+", " ", "40"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Vfly", " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{"80", ",", 
       RowBox[{"-", "80"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"coords", " ", "=", 
     RowBox[{"flyTurnCoords", "[", 
      RowBox[{"f", ",", " ", "g", " ", ",", " ", "Vfly", ",", " ", "5"}], 
      "]"}]}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Find", " ", "5", " ", "rounds", " ", "of", " ", "the", " ", "fly", " ", 
     "meeting", " ", "both", " ", "cars"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The fly flies a total of \>\"", ",", " ", 
      RowBox[{"flyPathLength", "[", 
       RowBox[{
        RowBox[{"40", " ", "/", 
         RowBox[{"(", 
          RowBox[{"40", "+", "60"}], ")"}]}], ",", " ", 
        RowBox[{"40", " ", 
         RowBox[{"40", " ", "/", 
          RowBox[{"(", 
           RowBox[{"40", "+", "60"}], ")"}]}]}], ",", " ", "80", ",", " ", 
        "80"}], "]"}], ",", " ", 
      "\"\< km. (Given by theoretical formula.)\>\""}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<The {t,x} coordinates that the fly meets the car: \>\"", ",", " ", 
      "coords"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\<Explicitly sum the flight distance from the coordinates above: \>\"",
      ",", 
     RowBox[{"pathLength", "[", "coords", "]"}], ",", " ", "\"\< km.\>\""}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{"showFlyFlight", "[", 
    RowBox[{"f", ",", "g", ",", "Vfly", ",", " ", 
     RowBox[{"40", "/", 
      RowBox[{"(", 
       RowBox[{"40", "+", "60"}], ")"}]}], ",", " ", "5"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.741089731794352*^9, 3.741089746901844*^9}, {
   3.741089878161564*^9, 3.741089890028084*^9}, {3.7410899798011703`*^9, 
   3.7410899805477667`*^9}, {3.741095967060012*^9, 3.741095968009597*^9}, {
   3.74132149076116*^9, 3.741321972719577*^9}, {3.741322002803752*^9, 
   3.7413220312206993`*^9}, {3.741322209486197*^9, 3.741322216166813*^9}, 
   3.741322631585619*^9},ExpressionUUID->"928a85d9-42c3-4186-8265-\
0cee8aabe1d2"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The fly flies a total of \"\>", "\[InvisibleSpace]", "32", 
   "\[InvisibleSpace]", "\<\" km. (Given by theoretical formula.)\"\>"}],
  SequenceForm[
  "The fly flies a total of ", 32, " km. (Given by theoretical formula.)"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.741321801572114*^9, 3.7413218121980762`*^9}, {
   3.7413218564265623`*^9, 3.7413218698662233`*^9}, {3.741321947655448*^9, 
   3.741321974257642*^9}, {3.74132203469812*^9, 3.7413220621888847`*^9}, 
   3.7413222175084553`*^9, 3.741322639883482*^9, 3.7413237469965153`*^9, 
   3.741333193764048*^9},ExpressionUUID->"7edca5f8-b883-4ba7-8fe0-\
3503ab2a6116"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The {t,x} coordinates that the fly meets the car: \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.2857142857142857`", ",", "22.857142857142858`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.38095238095238093`", ",", "15.238095238095237`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.3945578231292517`", ",", "16.3265306122449`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.39909297052154197`", ",", "15.96371882086168`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3997408487204406`", ",", "16.015549076773567`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.39995680812007345`", ",", "15.998272324802938`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.3999876594628781`", ",", "16.000740432227314`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.39999794324381305`", ",", "15.999917729752521`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.3999994123553752`", ",", "16.00003525867749`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.3999999020592292`", ",", "15.999996082369169`"}], "}"}]}], 
    "}"}]}],
  SequenceForm[
  "The {t,x} coordinates that the fly meets the car: ", {{0, 0}, {
    0.2857142857142857, 22.857142857142858`}, {0.38095238095238093`, 
    15.238095238095237`}, {0.3945578231292517, 16.3265306122449}, {
    0.39909297052154197`, 15.96371882086168}, {0.3997408487204406, 
    16.015549076773567`}, {0.39995680812007345`, 15.998272324802938`}, {
    0.3999876594628781, 16.000740432227314`}, {0.39999794324381305`, 
    15.999917729752521`}, {0.3999994123553752, 16.00003525867749}, {
    0.3999999020592292, 15.999996082369169`}}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.741321801572114*^9, 3.7413218121980762`*^9}, {
   3.7413218564265623`*^9, 3.7413218698662233`*^9}, {3.741321947655448*^9, 
   3.741321974257642*^9}, {3.74132203469812*^9, 3.7413220621888847`*^9}, 
   3.7413222175084553`*^9, 3.741322639883482*^9, 3.7413237469965153`*^9, 
   3.741333193775372*^9},ExpressionUUID->"ea40fb29-9b92-427c-b65b-\
5945aa24129e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Explicitly sum the flight distance from the coordinates above: \
\"\>", "\[InvisibleSpace]", "31.99999216473833`", 
   "\[InvisibleSpace]", "\<\" km.\"\>"}],
  SequenceForm[
  "Explicitly sum the flight distance from the coordinates above: ", 
   31.99999216473833, " km."],
  Editable->False]], "Print",
 CellChangeTimes->{{3.741321801572114*^9, 3.7413218121980762`*^9}, {
   3.7413218564265623`*^9, 3.7413218698662233`*^9}, {3.741321947655448*^9, 
   3.741321974257642*^9}, {3.74132203469812*^9, 3.7413220621888847`*^9}, 
   3.7413222175084553`*^9, 3.741322639883482*^9, 3.7413237469965153`*^9, 
   3.74133319379004*^9},ExpressionUUID->"f596cf8b-b1a4-49c2-9234-\
34b21ef5f8fc"]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV0Hk41AkYwHEmUnJMmjDjajTkiJ/HSnfv60hyVI5IK2wq8nSgqa0eiR46
FqFVyVBC0TUMw1YIzWg36xqD8RNDohwhRROJbf/4Pt//P8z9xz0PUuTk5Nx/
9v9zhp+xGy7ZbXE5OCiqHrq+JYyyvLqYtgIUHBjhPXQ2fNU+W5RMswKbO+mZ
JfQ42JT32CSahuDaICnOoqdBz1DtgZO0XeB7QFZ5jZ4HvMQWSgQtCLqJSw5J
dD4wpB2iY7RwyF6+8+IfdCE0LvR/dpQWAxcWlay6Qm8F2lt3v6SaFPDzu1v4
aaIfIqw57xQH0kF1PtZ/m/446LMTRpuOZ4Oxx9igIGESZiJ+m38syIPTjesh
fXIauKZq2pyGAmDwl0rl5efBV0HsRLd8AmV9DvVNmyjIuaylSassgpdhWTp+
HxVQNmKlwnpRDFPGm9WfHFXCxiAf1ahhPlCmH1F1jJQx1fpDatdEGayZDyrz
4qpgeJYgQnH8KdTH2TS+MlPHOvpj/1Na5aCfMjL9YIyK1C/zdeOMShiW9Ujb
rDRQ1B3oyNteBbnD5XVqV5ehpCg+Ue+valDVyx/v76fhJmbq0/dlNZBwuPRQ
NksT92UYDnvVv4RJfNQfel4Lp2oO79vaJIBIayFfU6CNrp9t2zs/CEHKFSaI
mAy0HH8Q5f29FmbCWjmmZ3XwYkbLAc/ZV2BipzR3qFwXM3fEek5q/AMOOcwQ
npY+mvAGYhlaryFSL9Dwrb8B2veOS1madWD6cfcSifsKpGvH2InN/gWq+qdF
wpkVGDJXO6BoUQ9yVZzClZlMPDGamtzl2AChNuXkYldDVHmwIOSmbyMUbN+f
/eKrITKWmce0+zbBpxEG9f2NlfjF/khTl20zFHltW5DmyMI0cdb5lKfNcMY5
/g7/PQujXHKcytaKQKfbpSM33ggFtYep3BoR2KyNS6NbG+NWbZXvIfYt4KPf
NC0vNkaj4xGDXxpaYKwuqS88dhViFu+r3S4xpCgEsD1ZJpjDE+pQmsWgLC3N
oQhNMLguwyFtbyvMRsV6r48wxcDnromDb1pBVhBQ2Kdhhs+5VRK10DYIzShM
0nhphv5XFm7In2iDEvPLi5YeM8f1G00q5SPbQcklcvUFtdXInlBxsPzRDiKL
ZvGZitU4HF0/pHteAnm3gdUfYIH5nwPyz81JwKPQdqnenAUKwvghRZc7gB1/
N7broSUynvc731tMQvagHkfNjcAf5xQYA0tIiMqKD5LuILDXjjXCUiNhj+eo
EdeDwPuvg5PyNEigVlQUufsS+AvZJ8rVISEm+ddXifsJdPvWuzfHgoRA21sT
ymcIPGfbfeSOBwm6cTRnpfsEBs3Mbu7xIuHbuihVSQGBji901Q18SGgbfddy
/xGByk7+vNt7SUj0LdnnxCPwxu43U1nBJMyaeZ6IryCQyyajM0+S0ClKvr1A
TGDquumdXb+TUHpRFixuI5A9q83UPUtC6sZA09wOAjfE7RFwoklwvmfJt5cS
+PefEiXOJRKenW54HTtE4ENfWUfnFRLSLNYke3wk8KqO1kNGIgmRfZnezHEC
vXN93DJSSDB1O9JTPUng2pBTep3XSFCUb81LkRHIML8xRr9OQm/pxrCgmZ9+
Y6VVfjdJqAjLJax+/PQrbku5dYuEdIMlU/PzBP4HPzRJyQ==
        "]]},
      Annotation[#, "Charting`Private`Tag$2880#1"]& ], 
     TagBox[
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV0Hs01HkcxvHJopSsk3Eb1Cq7q7V1fo2aMW6fz8wPFbohykp21dGFRGgr
KS1FSaZad7bEumzrGJVLLWIaxRJjMH1dCiGXSkJN5bL2j+e8z/Pvy/iXQJf9
SgwGY8v8/m/WSHlI4wW+LTHr/zI3R+MhJe2HxcxvQFJ5vk5j/n/QO1l0hUmB
aMfqJKNZGq2zb5tGMBEuHj/Ctpqm8cWwZF8ocztYihUHwhQ0iuJalIKYPpDu
ubT99TsaWc+fSY8wj4JPLKeI9NL4VNWrPIB5FgYHY/bdEdPI7N2y+3J1Agxx
+35yO0djEDvtpcpAMqhOtro62tO4POTSm6bAG8BuZUqD1Wj8HPTz3G1xNrg4
qnXHPBFg4WoNvbTGPLhiljQ8cUmAHsoyB/21f0NVFolydhRgWoyuDrOiCGZt
DubI1QT4cZRSN6ksht12V2tLG/n41Md9afjIXcjrCQyLjuOjkP1K2DVeAlpD
g9/lbePj0QxxkMpYGVzW+strRouP9fq3vcJ0H8Dn1lXGKEPUnJirH2NVQNQC
zqA8EVHavddOtLkKlB5N8/bsRJQXRccZlT6E+AJNLW1tRGtjYdlgSTX4K04R
uhhwT+rKEdeGGsh+DAUWFOBU9cE99k1i0A7ghMtLbNHpPae949UjCLBNPLzD
3BbXjuWHu32RQJ9Hwn6q2AbPp7bsc5muBeHGCp9yng2mb410mVz2BL73dT1h
VGqNpqKBSJZuHUy5GV4zs7FGQc/YcxOdeuiNP1OaKbFCfb2zfNkP/8LdSadP
r2kr9JuVDKisaYCHlJP1QL0lHnsjvNJl1wjFyXfSyzZaonr+V35JHk+hZlPJ
wvFaHrK0zM62ezSBetPoMdlWHk4I/Ju6OM1gHXlxJqHBAq/LMs4klDVDjppX
jMLFAsMdsxxKuFL4seOxkaSTi2LJQc3CaimktKc3+3ty0V5P/YufoAUgPzuq
speD3wYGDU00tkBjrrb7qDcHMUP0gb9dBtfDy01r+jdgluiRgVKzDH5N+agy
678BfetT6euerUD3ZTK0R9fj3vtOcUOdrbBxwYnptqD1eL+wSq5xoA3Yzv9o
B781R69YVcvc8TawfJHCOxZgjjwr04oFwe1walOB9/IpNoaMq9NrZ9rhVveq
m9nBbByJaBg2PCMHlc3N/a2KdZj73jv39KwcfpvWMT8UuQ7Fh+76FcU8g+HO
2syOOQpZ9/s35agRiBHmL5k6T+HMaWXWwBICL+vSuCSKwh6+yaiJBgFbpXjf
inMU/lnnezl7GYHJ4OAH0REUmpM+6S0DAj5uVod1wih0VvR4Zq0hwNNtrOfu
p/A0p9v/jx0ERtPfxZ6kKfT5PG3zwpWAQ1vfPW8+hXaVhl+vcCdwY2lbrwAo
XOzgJcr0JOARUc5bYkVh4s7OqQxfAuK954bT2BQWhpCI9FACGSuZmyuMKRRa
fNrWdZyAwlM19OYKCkOm9YwNTxJwvaa4EW1EoWXULnFaBIHFyt2KLfoUPr4m
X5h2gUDoQE7ec00KCzw+PuuIJSA1Sm6t0aAw3kC3gBVHwMz9IiNXnUK3W+7O
qQkEemuP7ApcRCHXL8yo4yoB6zmfKFfVeT+zxLf6vxNI5roWcZXn/d7eq9qd
RGAi0L7LQGner7gtISWFwNY87iIGg8L/APOVSks=
        "]]},
      Annotation[#, "Charting`Private`Tag$2880#2"]& ]}, {}, {}}, 
   LineBox[{{0, 0}, {0.2857142857142857, 22.857142857142858`}, {
     0.38095238095238093`, 15.238095238095237`}, {0.3945578231292517, 
     16.3265306122449}, {0.39909297052154197`, 15.96371882086168}, {
     0.3997408487204406, 16.015549076773567`}, {0.39995680812007345`, 
     15.998272324802938`}, {0.3999876594628781, 16.000740432227314`}, {
     0.39999794324381305`, 15.999917729752521`}, {0.3999994123553752, 
     16.00003525867749}, {0.3999999020592292, 15.999996082369169`}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], 
    FormBox["\"x\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox[
   "\"Spacetime diagram of two trains and a fly\\n Fly's path length = 32.\"",
     TraditionalForm],
  PlotRange->NCache[{{0, 
      Rational[2, 5]}, {0., 39.999999510204084`}}, {{0, 0.4}, {0., 
     39.999999510204084`}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.7413220348380632`*^9, 3.741322062323884*^9}, 
   3.741322217672063*^9, 3.741322640034361*^9, 3.7413237471578503`*^9, 
   3.7413331939696407`*^9},ExpressionUUID->"588da5bd-c883-4fed-967c-\
ab6dcc73f13e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"f", "[", "t_", "]"}], " ", ":=", " ", 
     RowBox[{"0", " ", "+", 
      RowBox[{"40", " ", "t"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"g", "[", "t_", "]"}], ":=", " ", 
    RowBox[{"InterpolatingPolynomial", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "60"}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"0.2", ",", " ", "30"}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"0.4", ",", "16"}], "}"}]}], "}"}], ",", "t"}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Vfly", " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{"80", ",", 
       RowBox[{"-", "80"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"coords", " ", "=", 
     RowBox[{"flyTurnCoords", "[", 
      RowBox[{"f", ",", " ", "g", " ", ",", " ", "Vfly", ",", " ", "8"}], 
      "]"}]}], ";"}], " ", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Find", " ", "8", " ", "rounds", " ", "of", " ", "the", " ", "fly", " ", 
     "meeting", " ", "both", " ", "cars"}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{"\"\<The fly flies a total of \>\"", ",", " ", 
      RowBox[{"flyPathLength", "[", 
       RowBox[{
        RowBox[{"40", " ", "/", 
         RowBox[{"(", 
          RowBox[{"40", "+", "60"}], ")"}]}], ",", " ", 
        RowBox[{"40", " ", 
         RowBox[{"40", " ", "/", 
          RowBox[{"(", 
           RowBox[{"40", "+", "60"}], ")"}]}]}], ",", "Vfly"}], "]"}], ",", 
      " ", "\"\< km. (Given by theoretical formula.)\>\""}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Print", "[", 
     RowBox[{
     "\"\<The {t,x} coordinates that the fly meets the car: \>\"", ",", " ", 
      "coords"}], "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Print", "[", 
    RowBox[{
    "\"\<Explicitly sum the flight distance from the coordinates above: \>\"",
      ",", 
     RowBox[{"pathLength", "[", "coords", "]"}], ",", " ", "\"\< km.\>\""}], 
    "]"}], "\[IndentingNewLine]", 
   RowBox[{"showFlyFlight", "[", 
    RowBox[{"f", ",", "g", ",", "Vfly", ",", " ", 
     RowBox[{"40", "/", 
      RowBox[{"(", 
       RowBox[{"40", "+", "60"}], ")"}]}], ",", " ", "8"}], 
    "]"}]}]}]], "Input",
 CellChangeTimes->{{3.7413222475518847`*^9, 3.741322395662301*^9}, 
   3.741322628728663*^9, {3.74132314870413*^9, 
   3.741323149457261*^9}},ExpressionUUID->"bff9cfb2-dcdf-4b83-929a-\
cc96b6e8731a"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The fly flies a total of \"\>", "\[InvisibleSpace]", "32", 
   "\[InvisibleSpace]", "\<\" km. (Given by theoretical formula.)\"\>"}],
  SequenceForm[
  "The fly flies a total of ", 32, " km. (Given by theoretical formula.)"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.741322342710182*^9, 3.741322359544401*^9}, 
   3.741322396920128*^9, 3.7413226401400013`*^9, 3.74132315045469*^9, 
   3.7413237472790813`*^9, 
   3.741333194024869*^9},ExpressionUUID->"437ee6fd-5464-4f83-8300-\
f76c28109d72"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The {t,x} coordinates that the fly meets the car: \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.2805066540485125`", ",", "22.440532323881`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.37400887206468336`", ",", "14.960354882587335`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.3907057411992579`", ",", "16.296104413353298`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3962713642441161`", ",", "15.850854569764643`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3986474585765914`", ",", "16.040942116362665`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3994394900207498`", ",", "15.977579600829992`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.39979625366676047`", ",", "16.006120692510848`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.3999151748820974`", ",", "15.996606995283894`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3999691562322863`", ",", "16.000925503299012`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.39998715001568264`", ",", "15.999486000627305`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.39999532731812815`", ",", "16.000140184822946`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.39999805308561`", ",", "15.9999221234244`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3999992920320422`", ",", "16.000021239138977`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3999997050141863`", ",", "15.999988200567453`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3999998927324523`", ",", "16.000003218028734`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.39999995530520766`", ",", "15.999998212208306`"}], "}"}]}], 
    "}"}]}],
  SequenceForm[
  "The {t,x} coordinates that the fly meets the car: ", {{0, 0}, {
    0.2805066540485125, 22.440532323881}, {0.37400887206468336`, 
    14.960354882587335`}, {0.3907057411992579, 16.296104413353298`}, {
    0.3962713642441161, 15.850854569764643`}, {0.3986474585765914, 
    16.040942116362665`}, {0.3994394900207498, 15.977579600829992`}, {
    0.39979625366676047`, 16.006120692510848`}, {0.3999151748820974, 
    15.996606995283894`}, {0.3999691562322863, 16.000925503299012`}, {
    0.39998715001568264`, 15.999486000627305`}, {0.39999532731812815`, 
    16.000140184822946`}, {0.39999805308561, 15.9999221234244}, {
    0.3999992920320422, 16.000021239138977`}, {0.3999997050141863, 
    15.999988200567453`}, {0.3999998927324523, 16.000003218028734`}, {
    0.39999995530520766`, 15.999998212208306`}}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.741322342710182*^9, 3.741322359544401*^9}, 
   3.741322396920128*^9, 3.7413226401400013`*^9, 3.74132315045469*^9, 
   3.7413237472790813`*^9, 
   3.741333194035314*^9},ExpressionUUID->"a538f80f-134a-488a-989d-\
a11fb081215e"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Explicitly sum the flight distance from the coordinates above: \
\"\>", "\[InvisibleSpace]", "31.999996424416615`", 
   "\[InvisibleSpace]", "\<\" km.\"\>"}],
  SequenceForm[
  "Explicitly sum the flight distance from the coordinates above: ", 
   31.999996424416615`, " km."],
  Editable->False]], "Print",
 CellChangeTimes->{{3.741322342710182*^9, 3.741322359544401*^9}, 
   3.741322396920128*^9, 3.7413226401400013`*^9, 3.74132315045469*^9, 
   3.7413237472790813`*^9, 
   3.741333194048106*^9},ExpressionUUID->"577f9c22-7924-4e5e-9c9c-\
0af6e9ae8085"]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV0Hk41AkYwHEmUnJMmjDjajTkiJ/HSnfv60hyVI5IK2wq8nSgqa0eiR46
FqFVyVBC0TUMw1YIzWg36xqD8RNDohwhRROJbf/4Pt//P8z9xz0PUuTk5Nx/
9v9zhp+xGy7ZbXE5OCiqHrq+JYyyvLqYtgIUHBjhPXQ2fNU+W5RMswKbO+mZ
JfQ42JT32CSahuDaICnOoqdBz1DtgZO0XeB7QFZ5jZ4HvMQWSgQtCLqJSw5J
dD4wpB2iY7RwyF6+8+IfdCE0LvR/dpQWAxcWlay6Qm8F2lt3v6SaFPDzu1v4
aaIfIqw57xQH0kF1PtZ/m/446LMTRpuOZ4Oxx9igIGESZiJ+m38syIPTjesh
fXIauKZq2pyGAmDwl0rl5efBV0HsRLd8AmV9DvVNmyjIuaylSassgpdhWTp+
HxVQNmKlwnpRDFPGm9WfHFXCxiAf1ahhPlCmH1F1jJQx1fpDatdEGayZDyrz
4qpgeJYgQnH8KdTH2TS+MlPHOvpj/1Na5aCfMjL9YIyK1C/zdeOMShiW9Ujb
rDRQ1B3oyNteBbnD5XVqV5ehpCg+Ue+valDVyx/v76fhJmbq0/dlNZBwuPRQ
NksT92UYDnvVv4RJfNQfel4Lp2oO79vaJIBIayFfU6CNrp9t2zs/CEHKFSaI
mAy0HH8Q5f29FmbCWjmmZ3XwYkbLAc/ZV2BipzR3qFwXM3fEek5q/AMOOcwQ
npY+mvAGYhlaryFSL9Dwrb8B2veOS1madWD6cfcSifsKpGvH2InN/gWq+qdF
wpkVGDJXO6BoUQ9yVZzClZlMPDGamtzl2AChNuXkYldDVHmwIOSmbyMUbN+f
/eKrITKWmce0+zbBpxEG9f2NlfjF/khTl20zFHltW5DmyMI0cdb5lKfNcMY5
/g7/PQujXHKcytaKQKfbpSM33ggFtYep3BoR2KyNS6NbG+NWbZXvIfYt4KPf
NC0vNkaj4xGDXxpaYKwuqS88dhViFu+r3S4xpCgEsD1ZJpjDE+pQmsWgLC3N
oQhNMLguwyFtbyvMRsV6r48wxcDnromDb1pBVhBQ2Kdhhs+5VRK10DYIzShM
0nhphv5XFm7In2iDEvPLi5YeM8f1G00q5SPbQcklcvUFtdXInlBxsPzRDiKL
ZvGZitU4HF0/pHteAnm3gdUfYIH5nwPyz81JwKPQdqnenAUKwvghRZc7gB1/
N7broSUynvc731tMQvagHkfNjcAf5xQYA0tIiMqKD5LuILDXjjXCUiNhj+eo
EdeDwPuvg5PyNEigVlQUufsS+AvZJ8rVISEm+ddXifsJdPvWuzfHgoRA21sT
ymcIPGfbfeSOBwm6cTRnpfsEBs3Mbu7xIuHbuihVSQGBji901Q18SGgbfddy
/xGByk7+vNt7SUj0LdnnxCPwxu43U1nBJMyaeZ6IryCQyyajM0+S0ClKvr1A
TGDquumdXb+TUHpRFixuI5A9q83UPUtC6sZA09wOAjfE7RFwoklwvmfJt5cS
+PefEiXOJRKenW54HTtE4ENfWUfnFRLSLNYke3wk8KqO1kNGIgmRfZnezHEC
vXN93DJSSDB1O9JTPUng2pBTep3XSFCUb81LkRHIML8xRr9OQm/pxrCgmZ9+
Y6VVfjdJqAjLJax+/PQrbku5dYuEdIMlU/PzBP4HPzRJyQ==
        "]]},
      Annotation[#, "Charting`Private`Tag$2993#1"]& ], 
     TagBox[
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV0Xk41Akcx/FpopRpkiZzUZF2lWV/mJCR73eGcQ9RoXYUqWeqpwMr7dPj
2qNDK1diM7GSzqedjC2hkIa2ZNzXDyHtiLHlEap1rv3j87z/f32M95/wP0il
UCjihf3ffE1plOqcwOnsltmP8/NiPEJd87SIsR4u8AyEWrNi/MQ6XZjCIGDC
/L5SZ0qMjgX3zOIYCHOLQ/fqT4ixb7jmwEnGdhgKqh77ekiMiqRmagQjBFZn
JqZKGsXI6e1sOs4Ih/JgunwkT4z1SySlxxgJcNBk0eFrQjEy3oh3X6xKhTXz
lH/UP3hjhLXsrbb6N/CxzGIOVHrh2qhf3zecyINHAhbn+govnIoInb+nLAAD
q6TgOl9PlG+is2Sq29C5LiDv/TUPDNRqcWVb/gG5AXQH9rA7ys4zDRjlhcAc
nL7kZueOn0cImmlFEcjW9BbcyXDD+pCAFTGaB+DO5t7ve+eKadbv0nrGioGz
y0eq9nDF8BxlhPZoCbSyy1Qbi0RYy74niWY+hhCTwJY5PRHqjc/XjnLKwbN6
SDoU64JNr/e5KDwqoZZh4kQbcMaOwjNJRo+eQklCRfxtb2d0NE4rGSyuAt3u
b9LTqoUYnG2i2VH3DHLHk6dieUKcrDocLGpQwhfFpsgdCgF6fbRt73pXDZpS
Vk79VwK0HL0Ts3O6Buq+LN0bnY94Nrv5gP/Mc8hoC04Vbka86vOj/4T+C6Aq
M/tnAgDNFOofOcyXMPgTlT0Z7oTC/tFeU4NaWJs4efvh5W3IZiUIWja/guL4
yJQ+uSNK52rU2hZ1UJEi09bt5eP379NSelxU4FagffMtlY+0O4ulWYH1UJ/b
7kOxcUDOavOE9sAGeKZrEZJ5aiuOC4829Ng2gr/v8qijf9pjRktOfGpJI6wv
nGJMUO0xxjPftdiuCdK9jy0lJHaorDmsJ69qgtKghG6e3BZFLNq0VNgMIgkc
OqZvixtPRAyNq5qB88ZLqQjfgpij+CTY3gKZ2ucZof08zFdUc6mNLbDJQ+Nn
uZuHYbXZzhl7WuGtf75OusoG95V5JQ11t0KeYbXxGz8bLJNXdtAPtQF//omB
bos1ShKXONwaawMe17WvPtgat/LNyhdFtgN3nrCf/GSFUWM0Z8vZdniRMDiR
mGyFmri6YcP4DuArvOilNlZ46+PeW7FzHVAx1HNprJ9A5ZEH0sLznaBZRqGZ
JBPIKfvb/cYyEib3Xwg97kbgbKwWR61LQnekmilwJbBfYDpiSieBpnnszRAR
ePNl2MUCfRJ20rutnggJtCEHmq5zSYi2HBhe5USg95f+PfkWJFBVq1e18QiM
tX199Hc/Ehx+1nIsMyEwZGpmW98OEm7E1FVdNSbQpcJw5boAEr57vfJ5/HoC
l7tKFLl7SJC36ni6rSUwc1f3ZE4YCYPZSuhhEyiPIuOuniQh54xkwGgVgWn2
//r2nCLh1XiXr44egVEzLGPD0ySIXrbyx+kEOvwSpJTFkWB01yGllkbgX5c6
lsrOkbDPuWFDvA6BdwM/d3YlkvBhxOzMwuOYzGXe5SSR8GJ69oBkCYE7rwd4
Z6eSEObHyeNrEWgnjTbqSidhQ1botPniBT/zzA/syyR862LaZkhd8PvwsHJ3
FgnngvZb0Bct+BW1pV65QoJ5K1eLQiHwPwyGNsU=
        "]]},
      Annotation[#, "Charting`Private`Tag$2993#2"]& ]}, {}, {}}, 
   LineBox[{{0, 0}, {0.2805066540485125, 22.440532323881}, {
     0.37400887206468336`, 14.960354882587335`}, {0.3907057411992579, 
     16.296104413353298`}, {0.3962713642441161, 15.850854569764643`}, {
     0.3986474585765914, 16.040942116362665`}, {0.3994394900207498, 
     15.977579600829992`}, {0.39979625366676047`, 16.006120692510848`}, {
     0.3999151748820974, 15.996606995283894`}, {0.3999691562322863, 
     16.000925503299012`}, {0.39998715001568264`, 15.999486000627305`}, {
     0.39999532731812815`, 16.000140184822946`}, {0.39999805308561, 
     15.9999221234244}, {0.3999992920320422, 16.000021239138977`}, {
     0.3999997050141863, 15.999988200567453`}, {0.3999998927324523, 
     16.000003218028734`}, {0.39999995530520766`, 15.999998212208306`}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], 
    FormBox["\"x\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox[
   "\"Spacetime diagram of two trains and a fly\\n Fly's path length = 32.\"",
     TraditionalForm],
  PlotRange->NCache[{{0, 
      Rational[2, 5]}, {0., 59.99999844897961}}, {{0, 0.4}, {0., 
     59.99999844897961}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.74132234288074*^9, 3.74132235973787*^9}, 
   3.7413223970627832`*^9, 3.741322640286181*^9, 3.7413231506084423`*^9, 
   3.741323747446759*^9, 
   3.741333194132159*^9},ExpressionUUID->"25f3163e-d048-4b8a-9374-\
07d1cf54e1a2"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "t_", "]"}], " ", ":=", " ", 
   RowBox[{"InterpolatingPolynomial", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"0.2", ",", " ", "12"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"0.4", ",", "16"}], "}"}]}], "}"}], ",", "t"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "[", "t_", "]"}], ":=", " ", 
  RowBox[{"InterpolatingPolynomial", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "60"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"0.2", ",", " ", "30"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"0.4", ",", "16"}], "}"}]}], "}"}], ",", "t"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Vfly", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"80", ",", 
     RowBox[{"-", "80"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"coords", " ", "=", 
    RowBox[{"flyTurnCoords", "[", 
     RowBox[{"f", ",", " ", "g", " ", ",", " ", "Vfly", ",", " ", "20"}], 
     "]"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Find", " ", "20", " ", "rounds", " ", "of", " ", "the", " ", "fly", " ", 
    "meeting", " ", "both", " ", "cars"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<The fly flies a total of \>\"", ",", " ", 
    RowBox[{"flyPathLength", "[", 
     RowBox[{
      RowBox[{"40", " ", "/", 
       RowBox[{"(", 
        RowBox[{"40", "+", "60"}], ")"}]}], ",", " ", 
      RowBox[{"40", " ", 
       RowBox[{"40", " ", "/", 
        RowBox[{"(", 
         RowBox[{"40", "+", "60"}], ")"}]}]}], ",", " ", "Vfly"}], "]"}], ",",
     " ", "\"\< km. (Given by theoretical formula.)\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<The {t,x} coordinates that the fly meets the car: \>\"", ",", " ", 
    "coords"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<Explicitly sum the flight distance from the coordinates above: \>\"", 
   ",", 
   RowBox[{"pathLength", "[", "coords", "]"}], ",", " ", "\"\< km.\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"showFlyFlight", "[", 
  RowBox[{"f", ",", "g", ",", "Vfly", ",", " ", 
   RowBox[{"40", "/", 
    RowBox[{"(", 
     RowBox[{"40", "+", "60"}], ")"}]}], ",", " ", "20"}], "]"}]}], "Input",
 CellChangeTimes->{{3.741322479016059*^9, 3.741322562859398*^9}, 
   3.741322624343652*^9, {3.7413231562765083`*^9, 
   3.7413231581752853`*^9}},ExpressionUUID->"e7aec5fb-b84e-4bdd-8a21-\
27332f67fc14"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The fly flies a total of \"\>", "\[InvisibleSpace]", "32", 
   "\[InvisibleSpace]", "\<\" km. (Given by theoretical formula.)\"\>"}],
  SequenceForm[
  "The fly flies a total of ", 32, " km. (Given by theoretical formula.)"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.741322515881421*^9, 3.741322563865733*^9}, 
   3.7413226403725643`*^9, 3.741323159099546*^9, 3.741323747578534*^9, 
   3.741333194214984*^9},ExpressionUUID->"5779cc5a-eb12-4873-8c63-\
153f99ebc349"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The {t,x} coordinates that the fly meets the car: \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.2805066540485125`", ",", "22.440532323881`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.36274795195176046`", ",", "15.861228491621166`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.3752801947194653`", ",", "16.863807913037554`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3863119954675349`", ",", "15.98126385319192`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.3903835544474887`", ",", "16.306988571588224`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.39426206644420486`", ",", "15.996707611850928`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.3958876364587683`", ",", "16.126753213016002`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3974799896864438`", ",", "15.999364954801957`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.39817906708590073`", ",", "16.05529114675851`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.39887179747156354`", ",", "15.999872715905482`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.3991818631944194`", ",", "16.024677973733947`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.39949066214740386`", ",", "15.99997405749519`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3996300571440019`", ",", "16.011125657223285`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3997691944482956`", ",", "15.99999467287973`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.39983224101453957`", ",", "16.005038398179256`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.39989523471148736`", ",", "15.999998902423432`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.3999238275903887`", ",", "16.002286332735537`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.39995240958064293`", ",", "15.9999997735152`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.3999653930224074`", ",", "16.00103844885636`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.399978374217705`", ",", "15.999999953232553`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.39998427303319406`", ",", "16.000471858471677`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.3999901713848421`", ",", "15.999999990339832`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.399992852096964`", ",", "16.000214447309585`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.39999553271327964`", ",", "15.999999998004334`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.3999967511015373`", ",", "16.00009746906495`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.399997969470003`", ",", "15.999999999587695`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.3999985232586245`", ",", "16.00004430267742`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.39999907704315707`", ",", "15.999999999914815`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.3999993287602533`", ",", "16.000020137282515`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.39999958047650475`", ",", "15.9999999999824`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.3999996948923327`", ",", "16.000009153248637`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3999998093079861`", ",", "15.999999999996364`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.399999861314967`", ",", "16.000004160554838`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.3999999133219085`", ",", "15.999999999999249`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.399999936961401`", ",", "16.000001891158764`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.39999996060088683`", ",", "15.999999999999845`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.3999999713461022`", ",", "16.0000008596171`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3999999820913162`", ",", "15.999999999999968`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.39999998697550326`", ",", "16.000000390734936`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.39999999185969004`", ",", "15.999999999999993`"}], "}"}]}], 
    "}"}]}],
  SequenceForm[
  "The {t,x} coordinates that the fly meets the car: ", {{0, 0.}, {
    0.2805066540485125, 22.440532323881}, {0.36274795195176046`, 
    15.861228491621166`}, {0.3752801947194653, 16.863807913037554`}, {
    0.3863119954675349, 15.98126385319192}, {0.3903835544474887, 
    16.306988571588224`}, {0.39426206644420486`, 15.996707611850928`}, {
    0.3958876364587683, 16.126753213016002`}, {0.3974799896864438, 
    15.999364954801957`}, {0.39817906708590073`, 16.05529114675851}, {
    0.39887179747156354`, 15.999872715905482`}, {0.3991818631944194, 
    16.024677973733947`}, {0.39949066214740386`, 15.99997405749519}, {
    0.3996300571440019, 16.011125657223285`}, {0.3997691944482956, 
    15.99999467287973}, {0.39983224101453957`, 16.005038398179256`}, {
    0.39989523471148736`, 15.999998902423432`}, {0.3999238275903887, 
    16.002286332735537`}, {0.39995240958064293`, 15.9999997735152}, {
    0.3999653930224074, 16.00103844885636}, {0.399978374217705, 
    15.999999953232553`}, {0.39998427303319406`, 16.000471858471677`}, {
    0.3999901713848421, 15.999999990339832`}, {0.399992852096964, 
    16.000214447309585`}, {0.39999553271327964`, 15.999999998004334`}, {
    0.3999967511015373, 16.00009746906495}, {0.399997969470003, 
    15.999999999587695`}, {0.3999985232586245, 16.00004430267742}, {
    0.39999907704315707`, 15.999999999914815`}, {0.3999993287602533, 
    16.000020137282515`}, {0.39999958047650475`, 15.9999999999824}, {
    0.3999996948923327, 16.000009153248637`}, {0.3999998093079861, 
    15.999999999996364`}, {0.399999861314967, 16.000004160554838`}, {
    0.3999999133219085, 15.999999999999249`}, {0.399999936961401, 
    16.000001891158764`}, {0.39999996060088683`, 15.999999999999845`}, {
    0.3999999713461022, 16.0000008596171}, {0.3999999820913162, 
    15.999999999999968`}, {0.39999998697550326`, 16.000000390734936`}, {
    0.39999999185969004`, 15.999999999999993`}}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.741322515881421*^9, 3.741322563865733*^9}, 
   3.7413226403725643`*^9, 3.741323159099546*^9, 3.741323747578534*^9, 
   3.741333194227536*^9},ExpressionUUID->"c2e55fbb-e965-463b-a1fa-\
af63afd8b626"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Explicitly sum the flight distance from the coordinates above: \
\"\>", "\[InvisibleSpace]", "31.999999348776083`", 
   "\[InvisibleSpace]", "\<\" km.\"\>"}],
  SequenceForm[
  "Explicitly sum the flight distance from the coordinates above: ", 
   31.999999348776083`, " km."],
  Editable->False]], "Print",
 CellChangeTimes->{{3.741322515881421*^9, 3.741322563865733*^9}, 
   3.7413226403725643`*^9, 3.741323159099546*^9, 3.741323747578534*^9, 
   3.741333194241273*^9},ExpressionUUID->"b905afe9-de86-4b47-a345-\
8cf4129fd920"]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV0gs4lNkfB/AhpTTZFhkGZXJZuZ1Wm11q/U5SbLGVLJGiYqmUlKSSVa6t
2UpNEk1JoSKLvzIpTKEmQi7N+75yW7FuSW6b+/xP7/Oc5z2f5zzn+f2e7/nx
9gY6+8qzWCwhWV//aX1Pgqtj19mQbY24N93mgPwScb6aLrAkrvuXaEbBfxqn
ci+qrQSWYOTqMg0BrL2bbRSuhoH1V2D2cfW70NZb4XNcbSuwHs0X2aoWQB6/
Xj5IzRsihPE2A+xy4LbSdYfVjoD4mVXkJlYj1MzzfHJILQLEvANGC7o/gNo/
Tu5/Pb8EPdVyy+yiRiHIIuXD3K4k2PH0B4PvTWdhaXD8QG1gKixen3AsXzQH
TwbtkWWX3YXU1LJY8Z35OGeFskZK9T0I/Tvrzl7dRdhNoWGjpvlDmN9/kvfD
58U4JY6jrlacC6kfOiYvWariL/0r2fol+eBgkT0hcViCa7xdF4X1FYCF57GV
/JMcnGDRndA89BjEpwW5RSc08RFhWdDcQRFISg+d2+elhSs1sz1DOE8hRLd/
NGqvDl48Iqsc5BZD+5DEVNlyGa5r8bLL+6UUApNFxXYJupjKjebrFIph6f0r
quWneXgtL0H07+PnoLvRRzK7ZTnelby8b/ubF5A0Leeti/Tw2PP9uzbUlkFK
/SumfFwPbx62lDZ1l8PerOunF77Rx+aD98NcpirAw1oUYiIwwDHJ9T7O0y8h
dTztopuDIb7x61nnURUJJHxSaU5Q+A4b5XWd5XJegyAzPjf14XfYtn2wVV+9
EpxtKvM1nYywpkbEugbjKkg/tWpAfcQI+81WdM01ewO35/+Z5Be7Ah8bSLjY
bFcNKkYu98Z1jTH7/hy/a241cCVaYXVorjHmqppESN1qofy9xL0BmeAR24Da
Zsu34DhUpNScb4IFDcI/LoneQr7LKhRnaIrDNqVtfPxjHUSlhsTmJ5jisor9
i3Oe14FApYYvJzPFGzTYU3629bBzXKUpaLcZNggM6hmprofq4ZLushIzjIV5
/63b2gCPRI0y2bfmOC2vXEv+bQNcifw2b+suc7yvMnm9wKMRYOnDE+OZ5tir
aDO/530jKPiENi/oNsdFOaWUsv87aDXkjZrpI+x5fp515tA78G+MKe7bgbDV
GqNiuaNS0DPQ/3I9EmGVGgg0D5ZCfHfO2g1RCPd5u/F2hkjBWF6O/Zn4RkxM
dMEpKbDxlL1dDMKs+k4nv0gp7Gm1X90dh7DE/3brG4EUHNPXdalfQNg1kctK
KpSCiWdhsk4SwsFD7PXmM1JQOpy1U/IA4QeDmTOrZVIQqt566JiFcPuArehn
OQrWymKT3hI79oWaOc2lIPWelRWVjbDeh05OwCIKJtdrZ7TlIFzf+OzjfR3i
G61mLfkII1FAooENBStot7E/ixD2eay4zQxTYAejvvJPEU4uSFu42paCgx+j
A08Sz8ujI+w2UtCmcd7p92cIt963O7jvVwrci5RXrylBmJ+ijW/vpiBpGSe/
7jnJI/xNr/YfFNgf0/bJkyD8RPIigHuWgmfWnGbN1wjHqTwZ5ERSYA5KQ2eJ
DTPSx1RiKVCU0UNbKxHeWx0ut+AiBRc9NLf0VSHMaH2vOXaTgqkIg1ClWpKf
6KpDdQkFtvEHo1jvEL4mz6+qFFPwy/ChFE/i3x3P/Sp5QYFTov8WEbFC+2GX
spcUbLq68cJhKcJY0cH7SQ0FWoHpflIKYdFvkyfSWyngXv4Ud6UJ4czh3Zln
ZimIupoTXdZG+nXwPprBoiHfIXFasx1h/5t7fq6VpyHT7ONsILHRJp8GXUUa
evgd6dx/yHvd3i8r+4aGitSJsAMdCOdsDXZT4tHwr07dltFOhB/lnFe8tp4G
ySGDuNxehBMV4utLN5Bz94aAceIQD76wx56GqhODzdCHsOW8i6usHWn46HDU
q5pYtEvg1eJCw3mcNtDRj/Az9q1Cvd9pMI7OMh8fQLjsQIFfbhwNSj771lcN
kfkztVpT8CcNeQVG5axhhG0GipVFfBpOfznUtppYFPjqUeklGk5uD+26SZwT
3DSnNokGni8fBYwgnBTOSh24R4POYN7TkVGEpRB9bOgBDTN7QjqXjyGsKqdk
P5ZNA+tVUeY24guRqp+mc2kI8iubeUgcGWe4lv2Ehlm5xu49/yF8+LIjbfya
hnLh8P8ef0E4e3tdlnkVDS0Wj6PaiHvVXP+wqKaBWzQxqDhO5vOal6F1Hal3
k5XoRux+42jwLwwNR14s0h0mtstIWuzfS+ofMTBVm0T4nJ9O58F+Gpy/67lr
SVxqlFYYOEDDq7fGoh3E1llZu08M0bB0EuWkEKPckuyYCRqOZ1jR2lMIc4s6
HdIXMFDru0mfPY3wzBkFbtdCBjhHeyJNiNvX6ffrKzOgylnou4k44/W+v+6q
MGBo0poVQ7yK6ai7o8VA0emnmyeI1YXydz7oMHDbKbxQbQbhSe/lwXq6DKwV
VdxFxOKePep39Bngu3XM8SF2HG/3SDNjIKXEufElMXrGMu1ADOi6Wju2EqtE
6M7wLBhwj8nYMEZMK3rfum3JQHcuu5g3S/LitH1IBQaCzBeXBBPbv58taF/H
wNV4bds4YuNbS2N07RgIOPvQPoX4s+Fuo1QHBn76cRdVSnzGsiXg1jbSX9XI
/DkyhL0np39u287A7ID+dRViuxLtb5a5MnD8ftMDHrHSRs+8mx4MnOlrcLYh
HlgQdq7Vk4FvjnB6NxO/rU7ZvtSLgd8utLHciRN/ez8m3MfAtGCmIIj4pObU
yxZfBnad2b7tDLFnCzdJx5+Bo7NmgXHEy309rIUBDIgqjyAh8dwVpxa2HGag
dwlTl0Hc8/F6s3YQA9UTFWN/y77OLxN+4zgD+fFmL8TECT9NbGk+wUCe1b0D
EuLgaQ2e9ikGfCMyBbXEbuKfhneGkfteJlhKbB21oywlnIEeatWhZmIdh1DB
+whSv0es1UHMYif5akUysOZy/eZu4s7aQsud0aTfRv+ZfuJXVyjFlFgGPP+O
XPmZ+IHbF7rpPANTy/W6RogvaHEecPkMOCF7rS/EQW2Wpz0uMODSOFg/Qexy
x9Ux+RIDyio67GniH/1CdJouMxDWU/NyhphrkvhJ8yoDQre5c2TEM58elbpf
Y+CYl1j81e357y5dv07ylX39EP4/EXvIcA==
        "]]},
      Annotation[#, "Charting`Private`Tag$3044#1"]& ], 
     TagBox[
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV0Xk41Akcx/FpopRpkiZzUZF2lWV/mJCR73eGcQ9RoXYUqWeqpwMr7dPj
2qNDK1diM7GSzqedjC2hkIa2ZNzXDyHtiLHlEap1rv3j87z/f32M95/wP0il
UCjihf3ffE1plOqcwOnsltmP8/NiPEJd87SIsR4u8AyEWrNi/MQ6XZjCIGDC
/L5SZ0qMjgX3zOIYCHOLQ/fqT4ixb7jmwEnGdhgKqh77ekiMiqRmagQjBFZn
JqZKGsXI6e1sOs4Ih/JgunwkT4z1SySlxxgJcNBk0eFrQjEy3oh3X6xKhTXz
lH/UP3hjhLXsrbb6N/CxzGIOVHrh2qhf3zecyINHAhbn+govnIoInb+nLAAD
q6TgOl9PlG+is2Sq29C5LiDv/TUPDNRqcWVb/gG5AXQH9rA7ys4zDRjlhcAc
nL7kZueOn0cImmlFEcjW9BbcyXDD+pCAFTGaB+DO5t7ve+eKadbv0nrGioGz
y0eq9nDF8BxlhPZoCbSyy1Qbi0RYy74niWY+hhCTwJY5PRHqjc/XjnLKwbN6
SDoU64JNr/e5KDwqoZZh4kQbcMaOwjNJRo+eQklCRfxtb2d0NE4rGSyuAt3u
b9LTqoUYnG2i2VH3DHLHk6dieUKcrDocLGpQwhfFpsgdCgF6fbRt73pXDZpS
Vk79VwK0HL0Ts3O6Buq+LN0bnY94Nrv5gP/Mc8hoC04Vbka86vOj/4T+C6Aq
M/tnAgDNFOofOcyXMPgTlT0Z7oTC/tFeU4NaWJs4efvh5W3IZiUIWja/guL4
yJQ+uSNK52rU2hZ1UJEi09bt5eP379NSelxU4FagffMtlY+0O4ulWYH1UJ/b
7kOxcUDOavOE9sAGeKZrEZJ5aiuOC4829Ng2gr/v8qijf9pjRktOfGpJI6wv
nGJMUO0xxjPftdiuCdK9jy0lJHaorDmsJ69qgtKghG6e3BZFLNq0VNgMIgkc
OqZvixtPRAyNq5qB88ZLqQjfgpij+CTY3gKZ2ucZof08zFdUc6mNLbDJQ+Nn
uZuHYbXZzhl7WuGtf75OusoG95V5JQ11t0KeYbXxGz8bLJNXdtAPtQF//omB
bos1ShKXONwaawMe17WvPtgat/LNyhdFtgN3nrCf/GSFUWM0Z8vZdniRMDiR
mGyFmri6YcP4DuArvOilNlZ46+PeW7FzHVAx1HNprJ9A5ZEH0sLznaBZRqGZ
JBPIKfvb/cYyEib3Xwg97kbgbKwWR61LQnekmilwJbBfYDpiSieBpnnszRAR
ePNl2MUCfRJ20rutnggJtCEHmq5zSYi2HBhe5USg95f+PfkWJFBVq1e18QiM
tX199Hc/Ehx+1nIsMyEwZGpmW98OEm7E1FVdNSbQpcJw5boAEr57vfJ5/HoC
l7tKFLl7SJC36ni6rSUwc1f3ZE4YCYPZSuhhEyiPIuOuniQh54xkwGgVgWn2
//r2nCLh1XiXr44egVEzLGPD0ySIXrbyx+kEOvwSpJTFkWB01yGllkbgX5c6
lsrOkbDPuWFDvA6BdwM/d3YlkvBhxOzMwuOYzGXe5SSR8GJ69oBkCYE7rwd4
Z6eSEObHyeNrEWgnjTbqSidhQ1botPniBT/zzA/syyR862LaZkhd8PvwsHJ3
FgnngvZb0Bct+BW1pV65QoJ5K1eLQiHwPwyGNsU=
        "]]},
      Annotation[#, "Charting`Private`Tag$3044#2"]& ]}, {}, {}}, 
   LineBox[{{0, 0.}, {0.2805066540485125, 22.440532323881}, {
     0.36274795195176046`, 15.861228491621166`}, {0.3752801947194653, 
     16.863807913037554`}, {0.3863119954675349, 15.98126385319192}, {
     0.3903835544474887, 16.306988571588224`}, {0.39426206644420486`, 
     15.996707611850928`}, {0.3958876364587683, 16.126753213016002`}, {
     0.3974799896864438, 15.999364954801957`}, {0.39817906708590073`, 
     16.05529114675851}, {0.39887179747156354`, 15.999872715905482`}, {
     0.3991818631944194, 16.024677973733947`}, {0.39949066214740386`, 
     15.99997405749519}, {0.3996300571440019, 16.011125657223285`}, {
     0.3997691944482956, 15.99999467287973}, {0.39983224101453957`, 
     16.005038398179256`}, {0.39989523471148736`, 15.999998902423432`}, {
     0.3999238275903887, 16.002286332735537`}, {0.39995240958064293`, 
     15.9999997735152}, {0.3999653930224074, 16.00103844885636}, {
     0.399978374217705, 15.999999953232553`}, {0.39998427303319406`, 
     16.000471858471677`}, {0.3999901713848421, 15.999999990339832`}, {
     0.399992852096964, 16.000214447309585`}, {0.39999553271327964`, 
     15.999999998004334`}, {0.3999967511015373, 16.00009746906495}, {
     0.399997969470003, 15.999999999587695`}, {0.3999985232586245, 
     16.00004430267742}, {0.39999907704315707`, 15.999999999914815`}, {
     0.3999993287602533, 16.000020137282515`}, {0.39999958047650475`, 
     15.9999999999824}, {0.3999996948923327, 16.000009153248637`}, {
     0.3999998093079861, 15.999999999996364`}, {0.399999861314967, 
     16.000004160554838`}, {0.3999999133219085, 15.999999999999249`}, {
     0.399999936961401, 16.000001891158764`}, {0.39999996060088683`, 
     15.999999999999845`}, {0.3999999713461022, 16.0000008596171}, {
     0.3999999820913162, 15.999999999999968`}, {0.39999998697550326`, 
     16.000000390734936`}, {0.39999999185969004`, 15.999999999999993`}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], 
    FormBox["\"x\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox[
   "\"Spacetime diagram of two trains and a fly\\n Fly's path length = 32.\"",
     TraditionalForm],
  PlotRange->NCache[{{0, 
      Rational[2, 5]}, {0., 59.99999844897961}}, {{0, 0.4}, {0., 
     59.99999844897961}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.741322516026464*^9, 3.74132256401633*^9}, 
   3.741322640527955*^9, 3.741323159250252*^9, 3.7413237477529163`*^9, 
   3.7413331943313303`*^9},ExpressionUUID->"98a76991-f70f-4fba-8f71-\
772a7162c3cb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "t_", "]"}], " ", ":=", " ", 
   RowBox[{"InterpolatingPolynomial", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"0.2", ",", " ", "12"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"0.4", ",", "16"}], "}"}]}], "}"}], ",", "t"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "[", "t_", "]"}], ":=", " ", 
  RowBox[{"InterpolatingPolynomial", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "30"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"0.2", ",", " ", "25"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"0.4", ",", "16"}], "}"}]}], "}"}], ",", "t"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Vfly", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"80", ",", 
     RowBox[{"-", "80"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"coords", " ", "=", 
    RowBox[{"flyTurnCoords", "[", 
     RowBox[{"f", ",", " ", "g", " ", ",", " ", "Vfly", ",", " ", "20"}], 
     "]"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Find", " ", "20", " ", "round", " ", "of", " ", "the", " ", "fly", " ", 
    "meeting", " ", "both", " ", "cars"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<The fly flies a total of \>\"", ",", " ", 
    RowBox[{"flyPathLength", "[", 
     RowBox[{
      RowBox[{"40", " ", "/", 
       RowBox[{"(", 
        RowBox[{"40", "+", "60"}], ")"}]}], ",", " ", 
      RowBox[{"40", " ", 
       RowBox[{"40", " ", "/", 
        RowBox[{"(", 
         RowBox[{"40", "+", "60"}], ")"}]}]}], ",", " ", "Vfly"}], "]"}], ",",
     " ", "\"\< km. (Given by theoretical formula.)\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<The {t,x} coordinates that the fly meets the car: \>\"", ",", " ", 
    "coords"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<Explicitly sum the flight distance from the coordinates above: \>\"", 
   ",", 
   RowBox[{"pathLength", "[", "coords", "]"}], ",", " ", "\"\< km.\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"showFlyFlight", "[", 
  RowBox[{"f", ",", "g", ",", "Vfly", ",", " ", 
   RowBox[{"40", "/", 
    RowBox[{"(", 
     RowBox[{"40", "+", "60"}], ")"}]}], ",", " ", "20"}], "]"}]}], "Input",
 CellChangeTimes->{{3.7413226561018267`*^9, 3.7413226982328987`*^9}, {
  3.7413231659294567`*^9, 
  3.741323166918076*^9}},ExpressionUUID->"d9f2d61b-af28-4db3-9ff7-\
3580181cbc85"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The fly flies a total of \"\>", "\[InvisibleSpace]", "32", 
   "\[InvisibleSpace]", "\<\" km. (Given by theoretical formula.)\"\>"}],
  SequenceForm[
  "The fly flies a total of ", 32, " km. (Given by theoretical formula.)"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.741322660328042*^9, 3.741322699760215*^9}, 
   3.741323168633009*^9, 3.741323747872485*^9, 
   3.741333194413378*^9},ExpressionUUID->"cb9492f0-b404-4806-b14f-\
15b4bf1d1fe8"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The {t,x} coordinates that the fly meets the car: \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.2757650672131263`", ",", "22.0612053770501`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.35415709890254177`", ",", "15.789842841896867`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.3741429308825122`", ",", "17.388709400294502`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3915902042175712`", ",", "15.992927533489784`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3950597667309502`", ",", "16.27049253456011`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.39844395002734834`", ",", "15.999757870848262`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.39907937595487397`", ",", "16.05059194505031`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.39971187903511585`", ",", "15.999991698630959`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.39982931235158997`", ",", "16.009386363948888`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.39994664545933445`", ",", "15.999999715329299`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.3999683842328861`", ",", "16.00173881721343`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.39999011957008257`", ",", "15.999999990237711`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.3999941449900358`", ",", "16.000322023833974`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3999981702921453`", ",", "15.999999999665217`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.39999891573072316`", ",", "16.000059634751445`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.3999996611652597`", ",", "15.99999999998852`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.3999997992091129`", ",", "16.000011043496777`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3999999372528275`", ",", "15.999999999999606`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.399999962816493`", ",", "16.000002045092817`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.3999999883801526`", ",", "15.999999999999986`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3999999931141646`", ",", "16.000000378720944`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3999999978481764`", ",", "16.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3999999987248453`", ",", "16.00000007013351`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.39999999960151417`", ",", "16.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.39999999976386025`", ",", "16.000000012987687`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.39999999992620633`", ",", "16.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.39999999995627045`", ",", "16.000000002405127`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.3999999999863345`", ",", "16.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.39999999999190194`", ",", "16.000000000445393`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.3999999999974694`", ",", "16.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3999999999985004`", ",", "16.00000000008248`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.3999999999995314`", ",", "16.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3999999999997223`", ",", "16.000000000015273`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3999999999999132`", ",", "16.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.39999999999994856`", ",", "16.00000000000283`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.399999999999984`", ",", "16.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.39999999999999053`", ",", "16.000000000000522`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.3999999999999971`", ",", "16.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3999999999999971`", ",", "16.000000000000163`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.3999999999999971`", ",", "16.`"}], "}"}]}], "}"}]}],
  SequenceForm[
  "The {t,x} coordinates that the fly meets the car: ", {{0, 0.}, {
    0.2757650672131263, 22.0612053770501}, {0.35415709890254177`, 
    15.789842841896867`}, {0.3741429308825122, 17.388709400294502`}, {
    0.3915902042175712, 15.992927533489784`}, {0.3950597667309502, 
    16.27049253456011}, {0.39844395002734834`, 15.999757870848262`}, {
    0.39907937595487397`, 16.05059194505031}, {0.39971187903511585`, 
    15.999991698630959`}, {0.39982931235158997`, 16.009386363948888`}, {
    0.39994664545933445`, 15.999999715329299`}, {0.3999683842328861, 
    16.00173881721343}, {0.39999011957008257`, 15.999999990237711`}, {
    0.3999941449900358, 16.000322023833974`}, {0.3999981702921453, 
    15.999999999665217`}, {0.39999891573072316`, 16.000059634751445`}, {
    0.3999996611652597, 15.99999999998852}, {0.3999997992091129, 
    16.000011043496777`}, {0.3999999372528275, 15.999999999999606`}, {
    0.399999962816493, 16.000002045092817`}, {0.3999999883801526, 
    15.999999999999986`}, {0.3999999931141646, 16.000000378720944`}, {
    0.3999999978481764, 16.}, {0.3999999987248453, 16.00000007013351}, {
    0.39999999960151417`, 16.}, {0.39999999976386025`, 16.000000012987687`}, {
    0.39999999992620633`, 16.}, {0.39999999995627045`, 16.000000002405127`}, {
    0.3999999999863345, 16.}, {0.39999999999190194`, 16.000000000445393`}, {
    0.3999999999974694, 16.}, {0.3999999999985004, 16.00000000008248}, {
    0.3999999999995314, 16.}, {0.3999999999997223, 16.000000000015273`}, {
    0.3999999999999132, 16.}, {0.39999999999994856`, 16.00000000000283}, {
    0.399999999999984, 16.}, {0.39999999999999053`, 16.000000000000522`}, {
    0.3999999999999971, 16.}, {0.3999999999999971, 16.000000000000163`}, {
    0.3999999999999971, 16.}}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.741322660328042*^9, 3.741322699760215*^9}, 
   3.741323168633009*^9, 3.741323747872485*^9, 
   3.741333194424705*^9},ExpressionUUID->"506d1e3e-6cf1-4eab-b5f8-\
ed7bfd7a3d28"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Explicitly sum the flight distance from the coordinates above: \
\"\>", "\[InvisibleSpace]", "32.00000000000014`", 
   "\[InvisibleSpace]", "\<\" km.\"\>"}],
  SequenceForm[
  "Explicitly sum the flight distance from the coordinates above: ", 
   32.00000000000014, " km."],
  Editable->False]], "Print",
 CellChangeTimes->{{3.741322660328042*^9, 3.741322699760215*^9}, 
   3.741323168633009*^9, 3.741323747872485*^9, 
   3.7413331944399*^9},ExpressionUUID->"6d6ab778-89a4-469c-926b-d538729160b6"]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV0gs4lNkfB/AhpTTZFhkGZXJZuZ1Wm11q/U5SbLGVLJGiYqmUlKSSVa6t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        "]]},
      Annotation[#, "Charting`Private`Tag$3095#1"]& ], 
     TagBox[
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV0Gs01HkcBvBxq6MmOjWFoVqtii72l8sMY6bvd6SpVlFKLkdRdAYpKakV
0tZG6zZjW5aJWl10dYxUQ5RLbGQwCH+51BZKF0K6mBk7++I5z3lePG8+5nvC
PfZq02i0zZr833lDJZHyBP6a9/NGVVNTPAzVnldRxPgBVo4t9k7Q7Anj6MI0
BgF229wsA83mXr5lGcdAuPu3fZOZmod9b2uCjjC2gCD0F7qDkofS5BbtCEYA
lEm1noZ85SGzt1NxgHEQ1CbzvEtHeNg4za9kPyMeOt3XFxm+5CHj5WaflEoR
ZC8Kqysr52GEjeSVXv9fMGBIjjEkPFwYmfShKfwiOGTZbU08ysPvEbunblVf
hk3Os8ZY7jwssDIwlsivQZz9Eq2RZTz00m0VmFjfhtD0ufL0SS5KEo3mM8oL
gemW02jTyMUv7wjd4mERZOpkBkAeFxsDdsyKGSqG0m7S13yQi2KbQXH3p3tw
/lXJKI3PxYM51RF6wzJYKu12SZ/NxXqTW35RRg/gTGgxEXQ54eyxqfphZjno
mivx6xUnVPT4u0g3PoLxlHKTmH1O2FH4W/KC+xXgeuyUhzNxQq65WDZwrxLw
bn1q8BcO7sxePLStoQpaLu7VV97n4OfKkJ3rmqphyym3YPPjHHQdZbV3DT6G
8sau9j1sDloPX4/ZPlkDCv0FIvqYI57JbgnyUNZCFWTE3JA64nm3kx7jc55A
7wrx8algR7SU9p9kGtVBLdvjSfSPjuj8YrjXYn49OMQOnqvqcUAT43h+6/Kn
4N627PMukQMK1TX9eqsaoPOAcOdJgQMe/iBO63aRg8ozKCh/nI306zrCTK9G
qEpVqaPz2MicuyK+3asJyor9b7K2s3HMOaypm9UM9UX7Uaxi4bnWnBMiWTP4
2pr36t1kYczPeYJ7bAUsIstVSd4srK4JmV1QqYCiXGO5m8oe1xnTJ4XOLcD1
qWUmXbXHJeERb8bkLUD41rvuCOwRc6QT/C2tMCNp3D3hnR3mSR+baje3whpv
oV+6yA4D67PXnvNtg0v8ljtLV9qhf6lr8pvnbdCpm5Jb22CLpQWPOgyCn4Eo
7cKD3EBb9Ds7jZP/6RkYGp3+lvrdBh2dLMu1DrVDUBRn6n2GDUZ+oq+1VrWD
Tpmr50IrGxyKa3hrdqIDKv1N44crVmP+6K78WHUHdNEz+rk+q7E6tFhYmNgJ
a+Ul7MkBgszS1xuu6FNwRv+AWhZNUBWry+yfSQEfc9WKYwRf8C3eWRhQYJXz
U99QFMGrdYEpl+dQcKLuCN/sMEFb6l/FJVMK1r9P+z12H8FNX1/45q2iQOA7
ac3xIxjL6gm7sJUCZUdBhYRHMOC7kte3jQLPNh15oRNBl4dmhot2UPB8oqSk
xpHgDIGfNNeXgvCCjXbD9gQzPJ9/zgmkoGhw4jZaEyyIpOLOH6Eg/9fEOz0L
CYodvrl3H6Wg+eVwzYgZwUilsblZNAVLhTKZjilBzmnvakkcBT6vw8DKiOA/
f3RMlyRQ0HktUHHIkOANry+dXWcpCHFsGzg9i2CqqdENZrLmP3KlO2Mmwe2X
dmzKFlFg2RwWUjqdIFsYtaArnYKwb7tpDXoavxUZH03+pKBng+xoj47G7+Pd
Rz6ZFMQ8DG/6qKXxK3omysrS+PgmTqfRCP4HBY5ICg==
        "]]},
      Annotation[#, "Charting`Private`Tag$3095#2"]& ]}, {}, {}}, 
   LineBox[{{0, 0.}, {0.2757650672131263, 22.0612053770501}, {
     0.35415709890254177`, 15.789842841896867`}, {0.3741429308825122, 
     17.388709400294502`}, {0.3915902042175712, 15.992927533489784`}, {
     0.3950597667309502, 16.27049253456011}, {0.39844395002734834`, 
     15.999757870848262`}, {0.39907937595487397`, 16.05059194505031}, {
     0.39971187903511585`, 15.999991698630959`}, {0.39982931235158997`, 
     16.009386363948888`}, {0.39994664545933445`, 15.999999715329299`}, {
     0.3999683842328861, 16.00173881721343}, {0.39999011957008257`, 
     15.999999990237711`}, {0.3999941449900358, 16.000322023833974`}, {
     0.3999981702921453, 15.999999999665217`}, {0.39999891573072316`, 
     16.000059634751445`}, {0.3999996611652597, 15.99999999998852}, {
     0.3999997992091129, 16.000011043496777`}, {0.3999999372528275, 
     15.999999999999606`}, {0.399999962816493, 16.000002045092817`}, {
     0.3999999883801526, 15.999999999999986`}, {0.3999999931141646, 
     16.000000378720944`}, {0.3999999978481764, 16.}, {0.3999999987248453, 
     16.00000007013351}, {0.39999999960151417`, 16.}, {0.39999999976386025`, 
     16.000000012987687`}, {0.39999999992620633`, 16.}, {0.39999999995627045`,
      16.000000002405127`}, {0.3999999999863345, 16.}, {0.39999999999190194`, 
     16.000000000445393`}, {0.3999999999974694, 16.}, {0.3999999999985004, 
     16.00000000008248}, {0.3999999999995314, 16.}, {0.3999999999997223, 
     16.000000000015273`}, {0.3999999999999132, 16.}, {0.39999999999994856`, 
     16.00000000000283}, {0.399999999999984, 16.}, {0.39999999999999053`, 
     16.000000000000522`}, {0.3999999999999971, 16.}, {0.3999999999999971, 
     16.000000000000163`}, {0.3999999999999971, 16.}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], 
    FormBox["\"x\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox[
   "\"Spacetime diagram of two trains and a fly\\n Fly's path length = 32.\"",
     TraditionalForm],
  PlotRange->NCache[{{0, 
      Rational[2, 5]}, {0., 29.99999987755102}}, {{0, 0.4}, {0., 
     29.99999987755102}}],
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.741322660483273*^9, 3.7413226999223948`*^9}, 
   3.741323168795768*^9, 3.74132374805812*^9, 
   3.741333194528388*^9},ExpressionUUID->"5cea7f62-0ecb-4e99-9fca-\
62f26f67a6dc"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "t_", "]"}], " ", ":=", " ", 
   RowBox[{"InterpolatingPolynomial", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"0.5", ",", " ", "0.2"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0.3"}], "}"}]}], "}"}], ",", "t"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "[", "t_", "]"}], ":=", " ", 
  RowBox[{"InterpolatingPolynomial", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"0.5", ",", " ", "0.5"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0.3"}], "}"}]}], "}"}], ",", "t"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Vfly", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"-", "2"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"coords", " ", "=", 
    RowBox[{"flyTurnCoords", "[", 
     RowBox[{"f", ",", " ", "g", " ", ",", " ", "Vfly", ",", " ", "30"}], 
     "]"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Find", " ", "30", " ", "round", " ", "of", " ", "the", " ", "fly", " ", 
    "meeting", " ", "both", " ", "cars"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<The fly flies a total of \>\"", ",", " ", 
    RowBox[{"flyPathLength", "[", 
     RowBox[{"1", ",", " ", "0.3", ",", "Vfly"}], "]"}], ",", " ", 
    "\"\< km. (Given by theoretical formula.)\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<The {t,x} coordinates that the fly meets the car: \>\"", ",", " ", 
    "coords"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<Explicitly sum the flight distance from the coordinates above: \>\"", 
   ",", 
   RowBox[{"pathLength", "[", "coords", "]"}], ",", " ", "\"\< km.\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"showFlyFlight", "[", 
  RowBox[{"f", ",", "g", ",", "Vfly", ",", " ", "1", ",", " ", "30"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.741322866795744*^9, 3.741322934070867*^9}, {
  3.7413231814982977`*^9, 3.741323269309369*^9}, {3.7413237272247*^9, 
  3.741323727393963*^9}},ExpressionUUID->"fdfbdd8a-f074-46a8-b2e0-\
7f5f5dab3f76"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The fly flies a total of \"\>", "\[InvisibleSpace]", 
   "1.2333333333333334`", 
   "\[InvisibleSpace]", "\<\" km. (Given by theoretical formula.)\"\>"}],
  SequenceForm[
  "The fly flies a total of ", 1.2333333333333334`, 
   " km. (Given by theoretical formula.)"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.7413231830679092`*^9, 3.7413232702775183`*^9}, 
   3.741323748245102*^9, 
   3.741333194752694*^9},ExpressionUUID->"9bb12bed-504c-41fd-a292-\
89e7c4f273b1"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The {t,x} coordinates that the fly meets the car: \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.49999999999999994`", ",", "0.5`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.631948736438942`", ",", "0.23610252712211593`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.7559768880222029`", ",", "0.3601306787053768`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.8000387408486024`", ",", "0.27200697305257776`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.8551152086026986`", ",", "0.32708344080667384`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.8763670845563293`", ",", "0.28457968889941254`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.906403276084991`", ",", "0.3146158804280743`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.9184535229438618`", ",", "0.2905153867103327`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9366764197482448`", ",", "0.3087382835147158`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9441499846919934`", ",", "0.2937911536272184`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9559309801552901`", ",", "0.30557214909051506`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9608290391598682`", ",", "0.29577603108135897`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9687622599285209`", ",", "0.30370925185001185`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9720902677797973`", ",", "0.29705323614745904`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9775805550362081`", ",", "0.30254352340386986`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9798978347077019`", ",", "0.2979089640608824`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9837699270969834`", ",", "0.301781056450164`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.9854111797045967`", ",", "0.29849855123493735`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9881786141524306`", ",", "0.3012659856827712`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9893551792520857`", ",", "0.29891285548345753`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.991351996857851`", ",", "0.30090967308922284`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9922027743573659`", ",", "0.29920811809019215`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.993653475717685`", ",", "0.3006588194505111`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.9942725388800272`", ",", "0.29942069312582653`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9953317466434918`", ",", "0.30047990088929116`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9957842612699441`", ",", "0.2995748716363864`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9965604436022597`", ",", "0.300351053968702`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.9968923203370471`", ",", "0.2996873004991272`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9974626207400229`", ",", "0.3002576009021031`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9977066163351789`", ",", "0.29976960971179106`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9981264660917918`", ",", "0.3001894594684039`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9983061740291769`", ",", "0.2998300435936338`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9986157092654947`", ",", "0.3001395788299531`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9987482432095024`", ",", "0.29987451094193773`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9989766914216656`", ",", "0.30010295915410135`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9990745301411069`", ",", "0.29990728171521874`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9992432654674361`", ",", "0.300076017041548`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.9993155436535801`", ",", "0.29993146066925996`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9994402463443754`", ",", "0.3000561633600554`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.999493670153709`", ",", "0.2999493157413882`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.9995858702857936`", ",", "0.3000415158734727`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9996253735781195`", ",", "0.29996250928882073`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9996935642100316`", ",", "0.30003069992073284`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9997227827193715`", ",", "0.29997226290205303`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.999773227884249`", ",", "0.3000227080669306`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.9997948439301102`", ",", "0.2999794759752084`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9998321680503998`", ",", "0.30001680009549797`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9998481622891598`", ",", "0.2999848116179779`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.999875781753896`", ",", "0.30001243108271397`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9998876176745064`", ",", "0.2999887592414932`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999080577318561`", ",", "0.3000091992988428`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999168172125859`", ",", "0.2999916803373833`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999319451400734`", ",", "0.300006808264871`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.9999384282396354`", ",", "0.2999938420657472`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999496251786018`", ",", "0.30000503900471337`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999544237035032`", ",", "0.29999544195491057`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999627114389588`", ",", "0.3000037296903662`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999662632361512`", ",", "0.29999662609598127`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999723978157258`", ",", "0.30000276067555576`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999750268722566`", ",", "0.29999750256249424`"}], "}"}]}], 
    "}"}]}],
  SequenceForm[
  "The {t,x} coordinates that the fly meets the car: ", {{0, 0.}, {
    0.49999999999999994`, 0.5}, {0.631948736438942, 0.23610252712211593`}, {
    0.7559768880222029, 0.3601306787053768}, {0.8000387408486024, 
    0.27200697305257776`}, {0.8551152086026986, 0.32708344080667384`}, {
    0.8763670845563293, 0.28457968889941254`}, {0.906403276084991, 
    0.3146158804280743}, {0.9184535229438618, 0.2905153867103327}, {
    0.9366764197482448, 0.3087382835147158}, {0.9441499846919934, 
    0.2937911536272184}, {0.9559309801552901, 0.30557214909051506`}, {
    0.9608290391598682, 0.29577603108135897`}, {0.9687622599285209, 
    0.30370925185001185`}, {0.9720902677797973, 0.29705323614745904`}, {
    0.9775805550362081, 0.30254352340386986`}, {0.9798978347077019, 
    0.2979089640608824}, {0.9837699270969834, 0.301781056450164}, {
    0.9854111797045967, 0.29849855123493735`}, {0.9881786141524306, 
    0.3012659856827712}, {0.9893551792520857, 0.29891285548345753`}, {
    0.991351996857851, 0.30090967308922284`}, {0.9922027743573659, 
    0.29920811809019215`}, {0.993653475717685, 0.3006588194505111}, {
    0.9942725388800272, 0.29942069312582653`}, {0.9953317466434918, 
    0.30047990088929116`}, {0.9957842612699441, 0.2995748716363864}, {
    0.9965604436022597, 0.300351053968702}, {0.9968923203370471, 
    0.2996873004991272}, {0.9974626207400229, 0.3002576009021031}, {
    0.9977066163351789, 0.29976960971179106`}, {0.9981264660917918, 
    0.3001894594684039}, {0.9983061740291769, 0.2998300435936338}, {
    0.9986157092654947, 0.3001395788299531}, {0.9987482432095024, 
    0.29987451094193773`}, {0.9989766914216656, 0.30010295915410135`}, {
    0.9990745301411069, 0.29990728171521874`}, {0.9992432654674361, 
    0.300076017041548}, {0.9993155436535801, 0.29993146066925996`}, {
    0.9994402463443754, 0.3000561633600554}, {0.999493670153709, 
    0.2999493157413882}, {0.9995858702857936, 0.3000415158734727}, {
    0.9996253735781195, 0.29996250928882073`}, {0.9996935642100316, 
    0.30003069992073284`}, {0.9997227827193715, 0.29997226290205303`}, {
    0.999773227884249, 0.3000227080669306}, {0.9997948439301102, 
    0.2999794759752084}, {0.9998321680503998, 0.30001680009549797`}, {
    0.9998481622891598, 0.2999848116179779}, {0.999875781753896, 
    0.30001243108271397`}, {0.9998876176745064, 0.2999887592414932}, {
    0.9999080577318561, 0.3000091992988428}, {0.9999168172125859, 
    0.2999916803373833}, {0.9999319451400734, 0.300006808264871}, {
    0.9999384282396354, 0.2999938420657472}, {0.9999496251786018, 
    0.30000503900471337`}, {0.9999544237035032, 0.29999544195491057`}, {
    0.9999627114389588, 0.3000037296903662}, {0.9999662632361512, 
    0.29999662609598127`}, {0.9999723978157258, 0.30000276067555576`}, {
    0.9999750268722566, 0.29999750256249424`}}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.7413231830679092`*^9, 3.7413232702775183`*^9}, 
   3.741323748245102*^9, 
   3.741333194763845*^9},ExpressionUUID->"98005d76-05e0-472f-99b0-\
8ad60c2ade34"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Explicitly sum the flight distance from the coordinates above: \
\"\>", "\[InvisibleSpace]", "1.2333008683088493`", 
   "\[InvisibleSpace]", "\<\" km.\"\>"}],
  SequenceForm[
  "Explicitly sum the flight distance from the coordinates above: ", 
   1.2333008683088493`, " km."],
  Editable->False]], "Print",
 CellChangeTimes->{{3.7413231830679092`*^9, 3.7413232702775183`*^9}, 
   3.741323748245102*^9, 
   3.741333194777521*^9},ExpressionUUID->"90c7a527-5e19-4a95-a81c-\
3f85d84e1b02"]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVzn081AcABvAjleaTuKzr8tYVtbzHJWr1EJsiKxJZSDplelNZtGqcUKvI
dKREhBLjmJepTqTrDd3bj6hw7lzycvz4LCwtt9sfz+d5vv89jLCjvuGaFArF
W53/2zN8QNw4uHOjegoaB7/bqOW2JEpKZ4ISSxNvoJvB4VbWzSq6OyhZBqyo
xUx4ver4M4fuBwrTx4NGc0cAa6o+nc4CpeigMsnAD922591S6NGIZ4wXnVjA
Qt7X25Iv0hNBiSjcHjA7GmztqpW/0TloNJI+XjZ+DrsC87lj44WoqGUcdbjB
gY6KHeRhwsXSf/W+ZAflwtxndODJpWrESwvMBuUFiBE4I+vjfTjpFUtNPhSD
Vq3fo6HRAObZFWcS4stQK3drFX7bBJta7ZL79pVoiswxDFTyUTzTdsA0tQoT
KzYsKDv8HJGZtqvTamug+alUz9C8GamnvYI3adbBURVau6O8FV1h9ZUweoDW
RKbgmYUQL+Izfi9h8GCaNvzp3qgIncneqTKPRxiekva020kQkN5XuM+0EYVD
D5t1UwnI9ZL/drZ4DF3ju6RC0QbDlGtgWTTh8k81+/PMXsPR29XQ1OAJJl1K
FRFxHSiLqi/7rMNHtD2/etGTTthsnT6oPcqHtJx/Scx4i1+pRxc7dD/F58i2
7FW/vENFdz3NsukZLF3nzux/2IVd64Y6U9Kfw+M240AlrQdJ1C0hLUdeIMZ4
zzJZkBRWDQnTC9e+hJVyp06Hdy94k2lXIydfYuGCMW3+dC+aNPwfhzY2Q6sh
m7v8pgxKpTSQE9OCg8yHb+Z5yfFaY3cMy6kVpVvC8h5NyuF/gZ8jJVsxMbxE
rz+zD8K7PR/EGa9Qs8NjFsddAX+uV5SJuwBxm5NuVfcrkG5tqWLLBGB0e3YW
JL1Hb+eZINFJIdatTeTQ7fshj53jf2ueCEEmwk8aRD+cHFm86W0iTDSnyKPY
HzDMixhjXRchSysk2tdsAEJPQYXbOxEW9tTc1uQP4K31PxQ/uhizz7L9nI8N
IuHSU5f2QDEo90K4cuoQcha5nWZdFeP4DW4KtWkIHZx9CrlAjHrLC9r6R4bx
V3Ci9945Euh7HrdK0FVCut1ccnGtBF3WIuIUT4lr2W2GmpESVOTCTBEyApfq
yozoTAmCuY76xjMjkIUMOZ1vkCA+KZ/dVTIKk3sypuegBGUDxtm6W0lsCqgP
zZ9P4EJOUmjPDyQe9ZfINugSYPmOmJf7kNhWRbF7q7YRj1fhHUCifNZ7JlWP
wMUru59dDiOxn50mjaMSiHC8Pv7VKRL3x47X+dAILEs02Dz3Donh3PBY4VIC
M05n5ncUk1CJfrwTziDwZqRPcqeUxEqXuvzPaqcFVAV/X0mipr2UsnI5AZWF
74kkHomW7p/3nDYn0CW+kjuLIPFmb0beEgsCdclT+4h2Ek7hukVlanPW71lV
0EnijyLypIslAa8im+pNPSQk3UMJ4VYEHsS+eskeJEGz5K8vsyGQab3mio+S
hBEtrnSjLYFj8pt+DJLEGpfbA0K1v9l6SNr4kcTdLYyWcTsCWhpthWlT6v+r
zkYlrCbQW7M+MnSaxCEP1z6qPQFeZIGt3RcSI/mHlxeofc1UZ0KlInHOWXO1
gwOB/wBYtGQ+
        "]]},
      Annotation[#, "Charting`Private`Tag$3147#1"]& ], 
     TagBox[
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV1Hs01AkUB3DPZSlFRVPUIdrQQ4VQ+ZKWIlseJUzIqkVUSk1arVgjK2Jb
lfe7IjG1Rtm8Wk0IefQbjfcwzBiv+dEJS2KnP+655/PPPeeee+5X0/uC4xkp
CQkJJ3F967ZnhG2vR46bqxT8O7W0RELGat1FLsUQFk2LI+ULJHZnJqWVUA5C
GNa+4docCbv3nL/TKc54mnTUfOoTCRef2cq7FB/IJFx1FvBJ9O64ZRVHCQbv
XnxvdyOJrDVHo2IokQhYnPD+/IBEuHzJD39QEsE8QDXrNiBx0jWbMTmVBx+l
ee8/nUVQXAqn2mxgYHM7m8aPmYCOg0j45jYTZdlx9Z/qx0FrNkXS538QFa2Y
UTc/BjWmcp+kZDXYpiGnnc3H8IJn1dSyrwYfnC7rnbs6ihr/9PWu4ywoJAdd
p78YwfTm/SuKAutw0thhe4DcCKTmCleu12nAS7XO3mZ7IYyXvF44FTdB9TxN
QM8bRlOkYXOtXgtidSO9jkkNY2PC2FyBqBXLGIGtEScEGJvl9rUbfMAFB1lL
7Vd85I2WNyjdIWAYlJ1OruZDSeMxOTTEhvUybvha2hBi/UrPZml/hLledsTb
4UHMWBQO+YZx0GA+8yru2CCCd7GYqm86oB723M27jgduMet2m2YXAhIuy6/Z
w8MXf3aq7vVu5HBq9zcUDUDfUm7xbHkP4h+PjmTuHIBNjuYvz9X6MOmeLG3N
6AdNw1NrgMoF65Gbc6JpP7aOH1fk2Pdjhu7tNvIXF6tWTMqz5vvhI+1ZvOlJ
H2SqUxmb0gZgkpb9icfpxTnD8s7v7XhI/6/7YtZCDwoPe2dVzfBQo7EuUHV7
D6bH1q0U3B+Eyrt9LLMr3Sh1spFOPDiEX1MOVluUdiHsED2TKRhCkI6SpaxC
FzR7bTty6XyQ3HtJOX6dMNsTmUjZJYD5Nc3v5sR7Uze0zEkSAoT6udZb7ezA
dEMc72L4MNg3F7UaUzhIkvEIdtQW30k0ITyuysGqvtIcKZYQ1i1zCrJpHyF7
I9zZNGgExTWhng0bP0KiwIPBUxkFNZnKri1px6UURpxKzSi61pZWedi0o1I/
Wl75/Bhi9a8yGXw2lG0vbY1QGoe0vrav1102era1EiEV45h7KN+cYMHGswxo
D3lMoEyrrcRggcAphrGyxuIEmNTJLQWvCdykZ4f3PBFhmZnRvZBoAstpcran
i0RwX2EYUHaLQIpvoIqAIQKlZqliNopAiZ1pLskUYbD6ayONTkCg3MaSqhYh
Xz0x80YEAbsMCXldQgQJdz2NrFACqi8971z5IkL36EKQRRCBIqFGqtIR8V+6
mEWI3AlEp9O9+n4iUR8jKTQR28dxQqfYgYS8XAL/dzcC6hUVz+xdSDR1SuWv
dyUQE+9eG+tNwl8IW8cTBHyNk6cUQkh8LVCT6TlGQCty9SG5RyR+q9pvf9qa
wKJJ6HJOPgkjBVFh1Y8EOicGPzwqJFGccSZHXewEl5JT1s9JCLKfnOiyIrCk
53iZXkHinHJsD9WSQE9bfIY0QaIx8emp3/YRKIua/ZloF+dEQJsJfy+BxL2e
urkd4vlxlYVHxLZ7uJ15oI/E4/yxkxpmBF5de/8ufIRE5qHM1rd7CNzfZhTv
ME4i4uyi306xg3hpzpokic3vtVPTjQlsORLAff2ZBDO4jkUzIiAjyc5LmCWR
UWpVyTck0F+6199rnsRh3LJ3FrvCP3eHwVcSL5XvXnmzm8CDjYrT33JRsNXH
aLfY/wPOtqzq
        "]]},
      Annotation[#, "Charting`Private`Tag$3147#2"]& ]}, {}, {}}, 
   LineBox[{{0, 0.}, {0.49999999999999994`, 0.5}, {0.631948736438942, 
     0.23610252712211593`}, {0.7559768880222029, 0.3601306787053768}, {
     0.8000387408486024, 0.27200697305257776`}, {0.8551152086026986, 
     0.32708344080667384`}, {0.8763670845563293, 0.28457968889941254`}, {
     0.906403276084991, 0.3146158804280743}, {0.9184535229438618, 
     0.2905153867103327}, {0.9366764197482448, 0.3087382835147158}, {
     0.9441499846919934, 0.2937911536272184}, {0.9559309801552901, 
     0.30557214909051506`}, {0.9608290391598682, 0.29577603108135897`}, {
     0.9687622599285209, 0.30370925185001185`}, {0.9720902677797973, 
     0.29705323614745904`}, {0.9775805550362081, 0.30254352340386986`}, {
     0.9798978347077019, 0.2979089640608824}, {0.9837699270969834, 
     0.301781056450164}, {0.9854111797045967, 0.29849855123493735`}, {
     0.9881786141524306, 0.3012659856827712}, {0.9893551792520857, 
     0.29891285548345753`}, {0.991351996857851, 0.30090967308922284`}, {
     0.9922027743573659, 0.29920811809019215`}, {0.993653475717685, 
     0.3006588194505111}, {0.9942725388800272, 0.29942069312582653`}, {
     0.9953317466434918, 0.30047990088929116`}, {0.9957842612699441, 
     0.2995748716363864}, {0.9965604436022597, 0.300351053968702}, {
     0.9968923203370471, 0.2996873004991272}, {0.9974626207400229, 
     0.3002576009021031}, {0.9977066163351789, 0.29976960971179106`}, {
     0.9981264660917918, 0.3001894594684039}, {0.9983061740291769, 
     0.2998300435936338}, {0.9986157092654947, 0.3001395788299531}, {
     0.9987482432095024, 0.29987451094193773`}, {0.9989766914216656, 
     0.30010295915410135`}, {0.9990745301411069, 0.29990728171521874`}, {
     0.9992432654674361, 0.300076017041548}, {0.9993155436535801, 
     0.29993146066925996`}, {0.9994402463443754, 0.3000561633600554}, {
     0.999493670153709, 0.2999493157413882}, {0.9995858702857936, 
     0.3000415158734727}, {0.9996253735781195, 0.29996250928882073`}, {
     0.9996935642100316, 0.30003069992073284`}, {0.9997227827193715, 
     0.29997226290205303`}, {0.999773227884249, 0.3000227080669306}, {
     0.9997948439301102, 0.2999794759752084}, {0.9998321680503998, 
     0.30001680009549797`}, {0.9998481622891598, 0.2999848116179779}, {
     0.999875781753896, 0.30001243108271397`}, {0.9998876176745064, 
     0.2999887592414932}, {0.9999080577318561, 0.3000091992988428}, {
     0.9999168172125859, 0.2999916803373833}, {0.9999319451400734, 
     0.300006808264871}, {0.9999384282396354, 0.2999938420657472}, {
     0.9999496251786018, 0.30000503900471337`}, {0.9999544237035032, 
     0.29999544195491057`}, {0.9999627114389588, 0.3000037296903662}, {
     0.9999662632361512, 0.29999662609598127`}, {0.9999723978157258, 
     0.30000276067555576`}, {0.9999750268722566, 0.29999750256249424`}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], 
    FormBox["\"x\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox[
   "\"Spacetime diagram of two trains and a fly\\n Fly's path length = 1.2333\
\"", TraditionalForm],
  PlotRange->{{0, 1}, {0., 0.9999999734693878}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.741323183224098*^9, 3.741323270439726*^9}, 
   3.741323748400518*^9, 
   3.741333194865663*^9},ExpressionUUID->"7d0be6cc-a3d1-4879-9fd7-\
93c4f8af7669"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "t_", "]"}], " ", ":=", " ", 
   RowBox[{"InterpolatingPolynomial", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"0.5", ",", " ", "0.15"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0.3"}], "}"}]}], "}"}], ",", "t"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "[", "t_", "]"}], ":=", " ", 
  RowBox[{"InterpolatingPolynomial", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"0.5", ",", " ", "0.65"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0.3"}], "}"}]}], "}"}], ",", "t"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Vfly", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"-", "2"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"coords", " ", "=", 
    RowBox[{"flyTurnCoords", "[", 
     RowBox[{"f", ",", " ", "g", " ", ",", " ", "Vfly", ",", " ", "30"}], 
     "]"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Find", " ", "30", " ", "round", " ", "of", " ", "the", " ", "fly", " ", 
    "meeting", " ", "both", " ", "cars"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<The fly flies a total of \>\"", ",", " ", 
    RowBox[{"flyPathLength", "[", 
     RowBox[{"1", ",", " ", "0.3", ",", "Vfly"}], "]"}], ",", " ", 
    "\"\< km. (Given by theoretical formula.)\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<The {t,x} coordinates that the fly meets the car: \>\"", ",", " ", 
    "coords"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<Explicitly sum the flight distance from the coordinates above: \>\"", 
   ",", 
   RowBox[{"pathLength", "[", "coords", "]"}], ",", " ", "\"\< km.\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"showFlyFlight", "[", 
  RowBox[{"f", ",", "g", ",", "Vfly", ",", " ", "1", ",", " ", "30"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.741323328448682*^9, 3.7413233384376087`*^9}, {
  3.741323737563033*^9, 
  3.7413237391952477`*^9}},ExpressionUUID->"7d11a85f-3053-4d2d-86a8-\
c843e526e34a"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The fly flies a total of \"\>", "\[InvisibleSpace]", 
   "1.2333333333333334`", 
   "\[InvisibleSpace]", "\<\" km. (Given by theoretical formula.)\"\>"}],
  SequenceForm[
  "The fly flies a total of ", 1.2333333333333334`, 
   " km. (Given by theoretical formula.)"],
  Editable->False]], "Print",
 CellChangeTimes->{3.741323342339384*^9, 3.741323748510025*^9, 
  3.741333194947291*^9},ExpressionUUID->"cb1a16d0-54d5-4312-abd5-\
e0b45c6fd3fa"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The {t,x} coordinates that the fly meets the car: \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.5882352941176471`", ",", "0.588235294117647`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.7672634271099744`", ",", "0.23017902813299232`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9041672935158718`", ",", "0.36708289453888976`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9458336876394058`", ",", "0.28375010629182174`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9776962243221082`", ",", "0.31561264297452424`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9873935180951047`", ",", "0.2962180554285314`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9948090956862196`", ",", "0.3036336330196463`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9970660106052546`", ",", "0.2991198031815764`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9987918867198107`", ",", "0.30084567929613254`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9993171533633712`", ",", "0.29979514600901136`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9997188278555057`", ",", "0.300196820501146`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.9998410766139815`", ",", "0.29995232298419444`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999345609586983`", ",", "0.30004580732891123`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.999963012715786`", ",", "0.2999889038147358`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.9999847699417942`", ",", "0.30001066104074403`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999913917062315`", ",", "0.2999974175118694`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999964554084484`", ",", "0.3000024812140861`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999979965352099`", ",", "0.299999398960563`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.99999917504391`", ",", "0.300000577469263`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999995337204709`", ",", "0.29999986011614127`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999998080025468`", ",", "0.3000001343982172`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999998914797004`", ",", "0.2999999674439101`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999553151707`", ",", "0.30000003127938046`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999747433573`", ",", "0.2999999924230072`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999896002061`", ",", "0.3000000072798557`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999941218556`", ",", "0.29999999823655665`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999975795876`", ",", "0.3000000016942887`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999986319408`", ",", "0.29999999958958223`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999994366814`", ",", "0.300000000394323`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.9999999996816025`", ",", "0.29999999990448073`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999998688951`", ",", "0.3000000000917734`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999258973`", ",", "0.29999999997776916`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999694871`", ",", "0.300000000021359`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.9999999999827536`", ",", "0.29999999999482607`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999928985`", ",", "0.30000000000497107`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999959861`", ",", "0.29999999999879584`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999983472`", ",", "0.30000000000115695`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999990659`", ",", "0.29999999999971977`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999996153`", ",", "0.3000000000002693`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999997826`", ",", "0.29999999999993476`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999105`", ",", "0.3000000000000626`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999494`", ",", "0.2999999999999848`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999792`", ",", "0.30000000000001453`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999882`", ",", "0.29999999999999644`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999951`", ",", "0.30000000000000343`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999951`", ",", "0.29999999999999855`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999951`", ",", "0.30000000000000343`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999951`", ",", "0.29999999999999855`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999951`", ",", "0.30000000000000343`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999951`", ",", "0.29999999999999855`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999951`", ",", "0.30000000000000343`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999951`", ",", "0.29999999999999855`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999951`", ",", "0.30000000000000343`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999951`", ",", "0.29999999999999855`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999951`", ",", "0.30000000000000343`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999951`", ",", "0.29999999999999855`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999951`", ",", "0.30000000000000343`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999951`", ",", "0.29999999999999855`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999951`", ",", "0.30000000000000343`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999951`", ",", "0.29999999999999855`"}], "}"}]}], 
    "}"}]}],
  SequenceForm[
  "The {t,x} coordinates that the fly meets the car: ", {{0, 0.}, {
    0.5882352941176471, 0.588235294117647}, {0.7672634271099744, 
    0.23017902813299232`}, {0.9041672935158718, 0.36708289453888976`}, {
    0.9458336876394058, 0.28375010629182174`}, {0.9776962243221082, 
    0.31561264297452424`}, {0.9873935180951047, 0.2962180554285314}, {
    0.9948090956862196, 0.3036336330196463}, {0.9970660106052546, 
    0.2991198031815764}, {0.9987918867198107, 0.30084567929613254`}, {
    0.9993171533633712, 0.29979514600901136`}, {0.9997188278555057, 
    0.300196820501146}, {0.9998410766139815, 0.29995232298419444`}, {
    0.9999345609586983, 0.30004580732891123`}, {0.999963012715786, 
    0.2999889038147358}, {0.9999847699417942, 0.30001066104074403`}, {
    0.9999913917062315, 0.2999974175118694}, {0.9999964554084484, 
    0.3000024812140861}, {0.9999979965352099, 0.299999398960563}, {
    0.99999917504391, 0.300000577469263}, {0.9999995337204709, 
    0.29999986011614127`}, {0.9999998080025468, 0.3000001343982172}, {
    0.9999998914797004, 0.2999999674439101}, {0.9999999553151707, 
    0.30000003127938046`}, {0.9999999747433573, 0.2999999924230072}, {
    0.9999999896002061, 0.3000000072798557}, {0.9999999941218556, 
    0.29999999823655665`}, {0.9999999975795876, 0.3000000016942887}, {
    0.9999999986319408, 0.29999999958958223`}, {0.9999999994366814, 
    0.300000000394323}, {0.9999999996816025, 0.29999999990448073`}, {
    0.9999999998688951, 0.3000000000917734}, {0.9999999999258973, 
    0.29999999997776916`}, {0.9999999999694871, 0.300000000021359}, {
    0.9999999999827536, 0.29999999999482607`}, {0.9999999999928985, 
    0.30000000000497107`}, {0.9999999999959861, 0.29999999999879584`}, {
    0.9999999999983472, 0.30000000000115695`}, {0.9999999999990659, 
    0.29999999999971977`}, {0.9999999999996153, 0.3000000000002693}, {
    0.9999999999997826, 0.29999999999993476`}, {0.9999999999999105, 
    0.3000000000000626}, {0.9999999999999494, 0.2999999999999848}, {
    0.9999999999999792, 0.30000000000001453`}, {0.9999999999999882, 
    0.29999999999999644`}, {0.9999999999999951, 0.30000000000000343`}, {
    0.9999999999999951, 0.29999999999999855`}, {0.9999999999999951, 
    0.30000000000000343`}, {0.9999999999999951, 0.29999999999999855`}, {
    0.9999999999999951, 0.30000000000000343`}, {0.9999999999999951, 
    0.29999999999999855`}, {0.9999999999999951, 0.30000000000000343`}, {
    0.9999999999999951, 0.29999999999999855`}, {0.9999999999999951, 
    0.30000000000000343`}, {0.9999999999999951, 0.29999999999999855`}, {
    0.9999999999999951, 0.30000000000000343`}, {0.9999999999999951, 
    0.29999999999999855`}, {0.9999999999999951, 0.30000000000000343`}, {
    0.9999999999999951, 0.29999999999999855`}, {0.9999999999999951, 
    0.30000000000000343`}, {0.9999999999999951, 0.29999999999999855`}}],
  Editable->False]], "Print",
 CellChangeTimes->{3.741323342339384*^9, 3.741323748510025*^9, 
  3.741333194958947*^9},ExpressionUUID->"9b2d57e2-e60e-4bc3-af07-\
946f3353dd55"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Explicitly sum the flight distance from the coordinates above: \
\"\>", "\[InvisibleSpace]", "1.2333333333333993`", 
   "\[InvisibleSpace]", "\<\" km.\"\>"}],
  SequenceForm[
  "Explicitly sum the flight distance from the coordinates above: ", 
   1.2333333333333993`, " km."],
  Editable->False]], "Print",
 CellChangeTimes->{3.741323342339384*^9, 3.741323748510025*^9, 
  3.7413331949740057`*^9},ExpressionUUID->"efd5d8ae-3dea-4fa1-8906-\
824f3503df57"]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVxnk4lAkAx/FxPbWjVY6WyRqNoyhFzspOP2VKklqDp3RgZVohhfap9kma
mqlUCo+VkiORpAyZUa6IEYmYeRW1GkwTk+tVzvTEtn98n8+XEXSEzVGlUCie
P/rfbRylpOaT74YfayP0WL9B3XXJ0W6aPShnjJcuMDaAXWbqrRIaCxSLxxc7
6BbwaOl4lE7zAWValVlFX4tdwVNVSbRgUGQW+kX0rXhvfcE1nnYMFMKZl0/f
jazFO89fovFA8axff5ceAu78kuVxtGS4UKkpOfQT2O13WzD6OQdZknENH5M4
aM5x97nRBWjjCEPFBUkw9xpR1l0Wwma1l+JxXiqOv1qH1PEyjK7QiT1nngl9
obZMRaUaLplUtv3NbJTKXZtbf6uFiyt9Ikmei9rQdEO/ITGU200ZGYb5mFjG
XPjwcANG/3DXcTR6ANWvBYsMzZtgn6iiVx4ggONcYKl3YTNGOIcPcxyK0cyz
f/V8RSv0StmLWSWPYJww+DV/pA17dLn1qV5CDE51y17bSLFjEp127SLkDFQ0
aV0l4N/nNsY6/hhaRnmkQtEOVlwj+4FOGa4cEh3MMnuDd8Vv9fYklWPSpUAR
EtuBq/123TG2lThmKxb+UteJL9n0BcrSKnQXii9LGO8QFcbe2Li3Gt9C29Ms
//4XwdGx+2NP1WDlxnmzByu60D+W/pLJfAa3bMafxfoyTM/0MJ20anHcKMCk
d183elnhvd6SWlgN+Wp2ePbAQWmXl5ZQB92Fo/PFMz3Q11kaSQ8UQ706TWB6
qxeS0z7hYkY9wuwr3v7kIceSqIdhuWP1KHAPyno6KUfL003xxc+eY2JwyaK+
lA/w27G0p4fbAJG3m1oyS4GoYBMnD3YjYrfyM4V9CnCqwqs79V6A8X5b5x3+
Rzw7MnYokXiB9U68ZJptHx7cyzDgZzdhH731qwrRhwizpOm0Ay8x0RQvP8rt
R82y+13D9s1IVfc/xjZTYiCM+iVouhm6MlG2qliJGGqepdqTFmjEcH3WRX5C
pnUIR3bhFSj5/gK5zgBuXI+Udrm3IuqmIF6ndgDada0MTa02VK28OF87YhCa
/bww5l9t0N4WZXVWawhHrWSe3Ndt6FrVRpysHIKRyP2RnClBUQbMFP7DcAzw
E/hmSrBf4KhtNDsMdccLTNmsBGf4t7ld90dA+73Bk3dQiodKozSt7STSLhdM
OjdIcTGdHyjbQYLvf44YbJQimD1sXuhF4siavUVpTVL8WllZ5LmLBKuDGvqt
RYpL1/Y+vxJEYsgk9H15uxQhjjc+U0+S2FBuIV4nl8KEp7d13l0SvcrcRKfv
UsyuPfVzxz0SLytiIvpnpXg7/EF6t4CE6Kqvx3UKgYRdJfu3FJOIs9fQmFIj
MLeCHc2vJGF7JvhEKZVAl+RahhpBgqdvGuBgQODJ+akDxGsSEQMzzh9pBJKd
AyzvdJLwq5Ia/GNIwCN3tXCTjMSqA2el43QC5SdaXnA/kXhT2LtZaE4gZZXD
Na8hEjXcMpPg5QQi5bd8GCSJ+z6Jc7qWBCy2h3fXjJM4PeNSFm1FQF2lPSdh
isShFoMU09UEekTOoYEzJLyzRqMIawKVoXesbb6TYEY37jy3hsB1Y82JuTkS
y7dkWdnZEfgPWcZfvg==
        "]]},
      Annotation[#, "Charting`Private`Tag$3198#1"]& ], 
     TagBox[
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVlPs31GkAh90qZSPKappGZ0RCpaJaqT6i0shl3bLZkmaRppukpHRqZEou
GWWlRImy1goZnXLZrKRNMvGdkMYYY4z7vJwN6TK2fnjO8wc85zxM9lGvYA01
NTW3b3y3S3BfU3W/76aFaT4fp6YItJwWhHXSbCH4Gl65UUVgczv9ViltC1yC
U86f+UKw43Xrw0yaD07ZNmpPfCTwC5qoukoLgqjZmaYcJeiwvuSURItAvJ79
enE3wR1Dj4vxtFiMxzGjH78g4GqXml+mpeLNGeVUWDLBL7uyi0ZGc1FcxdjK
MSTQmeLudjYuwqYLSYVROUqYeSr7niUI4PpUy/G5jRKRjXZI//AEcX76826U
D8NIoC9RV3+KsOMBMy+whvFI5tQg3FCDi4MOG8Yah1DDyaTvGqqFcbtlRs7O
IYwt2ahXePgF2K6+jFDFIDQmC+bQzerRvMCwQ3BoEGunAh95P2jAyCHDaqPP
A2iItW2ssxSCv4YhfJQwgEX8wcl85Rv4+5fTJQYDGJzolLxd2QyRRnoC/W4/
cgcq6nWvUDg9Q8euy7wfuow8IpeLkB3DM+gu6kPigbKQO6YtOMF10PuMPow7
FMhDz7XipJjPyqjrRcTqWsGPz9pgWsHM8/TtReeD2oQmZjtUY86O/HYFPnNE
GRan38M/78RMHbYCVptnqEIqxAgSd/+XMdoD57vM/SVGEtw83Esvi+xBJGOv
SdfuTkTHWO2XT+vBsiFfnVY3KbpmR0o80uSYqzeiXftJivAxv2tODDm0nmYU
Lb7VheLAqINuf3XjoG3Fu5k7ZKAvXcntXNWNAhb7zt/jMmiHKGsKn8gwNrhg
jiKtG9nmw+ZXWTKUeTtrpm6RI3Qrt14l7MK57bzbAoUc7QpfPjegC8wOl7Yc
Xg+EqlUxDkSK9etiU2mrFRgNzym5dFKK3cbCSXVKgWqOr1bPNCnG6pNkYdxe
nDxrZ/G7USfStQIivEz7ULuMxU+0kWCupOyuRm0f5r/c7/HFuwPTznJ97I71
o45Rcjl6nxhq+QFFsm+dGqLOzLI49x7hN4uSDGoGsPxK2HTF5XZUWcVp6x8Z
REpyhD/9xjvou4Qvi9Edgnv65Ifox20QL39DRVUOIXhX/ixS24riLJjKA4bR
wmwPSepqwZ6itfoM1TBcWmn0XI0WnOdlc8V/KkHbGuvyas5bFPYxMnRdCTaX
H602thYhLpMXKHEnOLH4lIG1lQhBXsNmDzwJ8hLPB8FchIWVlcVufgQ/7E3R
DlwkQnzyr3WJbII2zdKfs/VECF17Y3RWFMERt3Hp4hEKJrHzts+4T5ApjVa3
KKGg+il6dusfBEIWz9uukMK74e7m+wUEmqVJ91j5FPh+pXu2lRAc4GWxONkU
piy9jvMqCWwtq1MKUiiIm5KzNCmChuOaJivCKTy+OPEb9ZZAJdaJ2HSEQqr9
XoucNoJV2+bVuXMo7Li3QuAoIbg+34xzlE2h/NTrl9x+AnbVtofFXhTSlq9J
9hwiSF3iofWPO4Vjsls+TELwb7LfziYXCktdD3VWfyBYwQ79NOpIQUtdlMuf
INj3KsxVAxSkZfacwE8E12yjsgzsKVRycqxXfiV4nskdMVlH4foinbHv35qc
Hu9oY0PhfwVhcGg=
        "]]},
      Annotation[#, "Charting`Private`Tag$3198#2"]& ]}, {}, {}}, 
   LineBox[{{0, 0.}, {0.5882352941176471, 0.588235294117647}, {
     0.7672634271099744, 0.23017902813299232`}, {0.9041672935158718, 
     0.36708289453888976`}, {0.9458336876394058, 0.28375010629182174`}, {
     0.9776962243221082, 0.31561264297452424`}, {0.9873935180951047, 
     0.2962180554285314}, {0.9948090956862196, 0.3036336330196463}, {
     0.9970660106052546, 0.2991198031815764}, {0.9987918867198107, 
     0.30084567929613254`}, {0.9993171533633712, 0.29979514600901136`}, {
     0.9997188278555057, 0.300196820501146}, {0.9998410766139815, 
     0.29995232298419444`}, {0.9999345609586983, 0.30004580732891123`}, {
     0.999963012715786, 0.2999889038147358}, {0.9999847699417942, 
     0.30001066104074403`}, {0.9999913917062315, 0.2999974175118694}, {
     0.9999964554084484, 0.3000024812140861}, {0.9999979965352099, 
     0.299999398960563}, {0.99999917504391, 0.300000577469263}, {
     0.9999995337204709, 0.29999986011614127`}, {0.9999998080025468, 
     0.3000001343982172}, {0.9999998914797004, 0.2999999674439101}, {
     0.9999999553151707, 0.30000003127938046`}, {0.9999999747433573, 
     0.2999999924230072}, {0.9999999896002061, 0.3000000072798557}, {
     0.9999999941218556, 0.29999999823655665`}, {0.9999999975795876, 
     0.3000000016942887}, {0.9999999986319408, 0.29999999958958223`}, {
     0.9999999994366814, 0.300000000394323}, {0.9999999996816025, 
     0.29999999990448073`}, {0.9999999998688951, 0.3000000000917734}, {
     0.9999999999258973, 0.29999999997776916`}, {0.9999999999694871, 
     0.300000000021359}, {0.9999999999827536, 0.29999999999482607`}, {
     0.9999999999928985, 0.30000000000497107`}, {0.9999999999959861, 
     0.29999999999879584`}, {0.9999999999983472, 0.30000000000115695`}, {
     0.9999999999990659, 0.29999999999971977`}, {0.9999999999996153, 
     0.3000000000002693}, {0.9999999999997826, 0.29999999999993476`}, {
     0.9999999999999105, 0.3000000000000626}, {0.9999999999999494, 
     0.2999999999999848}, {0.9999999999999792, 0.30000000000001453`}, {
     0.9999999999999882, 0.29999999999999644`}, {0.9999999999999951, 
     0.30000000000000343`}, {0.9999999999999951, 0.29999999999999855`}, {
     0.9999999999999951, 0.30000000000000343`}, {0.9999999999999951, 
     0.29999999999999855`}, {0.9999999999999951, 0.30000000000000343`}, {
     0.9999999999999951, 0.29999999999999855`}, {0.9999999999999951, 
     0.30000000000000343`}, {0.9999999999999951, 0.29999999999999855`}, {
     0.9999999999999951, 0.30000000000000343`}, {0.9999999999999951, 
     0.29999999999999855`}, {0.9999999999999951, 0.30000000000000343`}, {
     0.9999999999999951, 0.29999999999999855`}, {0.9999999999999951, 
     0.30000000000000343`}, {0.9999999999999951, 0.29999999999999855`}, {
     0.9999999999999951, 0.30000000000000343`}, {0.9999999999999951, 
     0.29999999999999855`}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], 
    FormBox["\"x\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox[
   "\"Spacetime diagram of two trains and a fly\\n Fly's path length = \
1.23333\"", TraditionalForm],
  PlotRange->{{0, 1}, {0., 0.9999999857142856}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.741323342518992*^9, 3.741323748632964*^9, 
  3.741333195064403*^9},ExpressionUUID->"307442fd-698c-4568-accf-\
62cb00e5993b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "t_", "]"}], " ", ":=", " ", 
   RowBox[{"InterpolatingPolynomial", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"0.2", ",", " ", "0.15"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0.5", ",", " ", "0.20"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"1", ",", "0.3"}], "}"}]}], "}"}], ",", "t"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"g", "[", "t_", "]"}], ":=", " ", 
  RowBox[{"InterpolatingPolynomial", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "1"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"0.2", ",", " ", "0.9"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0.7", ",", "0.4"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0.3"}], "}"}]}], "}"}], ",", "t"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Vfly", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"-", "2"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"coords", " ", "=", 
    RowBox[{"flyTurnCoords", "[", 
     RowBox[{"f", ",", " ", "g", " ", ",", " ", "Vfly", ",", " ", "30"}], 
     "]"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Find", " ", "30", " ", "round", " ", "of", " ", "the", " ", "fly", " ", 
    "meeting", " ", "both", " ", "cars"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<The fly flies a total of \>\"", ",", " ", 
    RowBox[{"flyPathLength", "[", 
     RowBox[{"1", ",", " ", "0.3", ",", "Vfly"}], "]"}], ",", " ", 
    "\"\< km. (Given by theoretical formula.)\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<The {t,x} coordinates that the fly meets the car: \>\"", ",", " ", 
    "coords"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<Explicitly sum the flight distance from the coordinates above: \>\"", 
   ",", 
   RowBox[{"pathLength", "[", "coords", "]"}], ",", " ", "\"\< km.\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"showFlyFlight", "[", 
  RowBox[{"f", ",", "g", ",", "Vfly", ",", " ", "1", ",", " ", "30"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.741323328448682*^9, 3.7413233384376087`*^9}, {
  3.741323737563033*^9, 3.7413237391952477`*^9}, {3.741325274183983*^9, 
  3.741325437031108*^9}, {3.741325486419887*^9, 
  3.741325628405702*^9}},ExpressionUUID->"7b65bbc7-a3c1-4066-a62f-\
ef823f631d59"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The fly flies a total of \"\>", "\[InvisibleSpace]", 
   "1.2333333333333334`", 
   "\[InvisibleSpace]", "\<\" km. (Given by theoretical formula.)\"\>"}],
  SequenceForm[
  "The fly flies a total of ", 1.2333333333333334`, 
   " km. (Given by theoretical formula.)"],
  Editable->False]], "Print",
 CellChangeTimes->{{3.741325304066078*^9, 3.74132532306609*^9}, {
   3.741325383059689*^9, 3.7413254380118427`*^9}, {3.741325488759585*^9, 
   3.741325629225685*^9}, 
   3.741333195147744*^9},ExpressionUUID->"8f63f26e-d240-4924-a98c-\
3d64b0522f17"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The {t,x} coordinates that the fly meets the car: \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.5465031328456735`", ",", "0.5465031328456736`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.7184558966735498`", ",", "0.2025976051899211`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.8317823483635645`", ",", "0.31592405687993624`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.8727386205010461`", ",", "0.23401151260497288`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9304357858393724`", ",", "0.29170867794329924`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9436721154674346`", ",", "0.2652360186871748`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9723808293408863`", ",", "0.2939447325606264`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9770242838785701`", ",", "0.2846578234852588`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9896560099089164`", ",", "0.2972895495156051`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9913024528958371`", ",", "0.29399666354176385`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9962650640236753`", ",", "0.2989592746696033`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9968468691814862`", ",", "0.29779566435398136`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9986735065826057`", ",", "0.2996223017551008`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9988785042212824`", ",", "0.29921230647774816`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.999531894152832`", ",", "0.29986569640929756`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9996040303098507`", ",", "0.29972142409526004`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9998351957628213`", ",", "0.29995258954823056`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9998605669254598`", ",", "0.29990184722295377`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999420262686982`", ",", "0.29998330656619365`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999509480026745`", ",", "0.29996546309824107`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999796123830401`", ",", "0.29999412747860676`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999827494970154`", ",", "0.2999878532506563`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999928310307872`", ",", "0.29999793478442793`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999939340967656`", ",", "0.2999957286524711`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999974792420434`", ",", "0.29999927379774877`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999978670968874`", ",", "0.29999849808806056`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999991136606822`", ",", "0.29999974465185525`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999992500359862`", ",", "0.2999994719012472`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999996883501465`", ",", "0.2999999102154075`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999997363016058`", ",", "0.29999981431249284`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999998904195325`", ",", "0.2999999684304196`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999072799277`", ",", "0.2999999347096296`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999614699894`", ",", "0.29999998889969115`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999673983365`", ",", "0.299999977042997`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.9999999864523158`", ",", "0.29999999609697714`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999885368044`", ",", "0.299999991928`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999952364477`", ",", "0.2999999986276433`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999959693825`", ",", "0.2999999971617735`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999983250694`", ",", "0.2999999995174605`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999985827793`", ",", "0.29999999900204044`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999994110714`", ",", "0.2999999998303325`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999995016858`", ",", "0.2999999996491038`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999997929248`", ",", "0.2999999999403426`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.999999999824786`", ",", "0.2999999998766202`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.9999999999271896`", ",", "0.29999999997902366`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999383924`", ",", "0.29999999995661797`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999743988`", ",", "0.2999999999926244`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999783379`", ",", "0.29999999998474625`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999909982`", ",", "0.2999999999974066`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999923832`", ",", "0.2999999999946365`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999968349`", ",", "0.2999999999990881`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999973218`", ",", "0.2999999999981141`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999988871`", ",", "0.29999999999967936`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999990583`", ",", "0.2999999999993369`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999996085`", ",", "0.2999999999998872`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999996687`", ",", "0.29999999999976673`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999998624`", ",", "0.29999999999996035`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999998836`", ",", "0.29999999999991805`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999517`", ",", "0.29999999999998606`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999591`", ",", "0.29999999999997123`"}], "}"}]}], 
    "}"}]}],
  SequenceForm[
  "The {t,x} coordinates that the fly meets the car: ", {{0, 0.}, {
    0.5465031328456735, 0.5465031328456736}, {0.7184558966735498, 
    0.2025976051899211}, {0.8317823483635645, 0.31592405687993624`}, {
    0.8727386205010461, 0.23401151260497288`}, {0.9304357858393724, 
    0.29170867794329924`}, {0.9436721154674346, 0.2652360186871748}, {
    0.9723808293408863, 0.2939447325606264}, {0.9770242838785701, 
    0.2846578234852588}, {0.9896560099089164, 0.2972895495156051}, {
    0.9913024528958371, 0.29399666354176385`}, {0.9962650640236753, 
    0.2989592746696033}, {0.9968468691814862, 0.29779566435398136`}, {
    0.9986735065826057, 0.2996223017551008}, {0.9988785042212824, 
    0.29921230647774816`}, {0.999531894152832, 0.29986569640929756`}, {
    0.9996040303098507, 0.29972142409526004`}, {0.9998351957628213, 
    0.29995258954823056`}, {0.9998605669254598, 0.29990184722295377`}, {
    0.9999420262686982, 0.29998330656619365`}, {0.9999509480026745, 
    0.29996546309824107`}, {0.9999796123830401, 0.29999412747860676`}, {
    0.9999827494970154, 0.2999878532506563}, {0.9999928310307872, 
    0.29999793478442793`}, {0.9999939340967656, 0.2999957286524711}, {
    0.9999974792420434, 0.29999927379774877`}, {0.9999978670968874, 
    0.29999849808806056`}, {0.9999991136606822, 0.29999974465185525`}, {
    0.9999992500359862, 0.2999994719012472}, {0.9999996883501465, 
    0.2999999102154075}, {0.9999997363016058, 0.29999981431249284`}, {
    0.9999998904195325, 0.2999999684304196}, {0.9999999072799277, 
    0.2999999347096296}, {0.9999999614699894, 0.29999998889969115`}, {
    0.9999999673983365, 0.299999977042997}, {0.9999999864523158, 
    0.29999999609697714`}, {0.9999999885368044, 0.299999991928}, {
    0.9999999952364477, 0.2999999986276433}, {0.9999999959693825, 
    0.2999999971617735}, {0.9999999983250694, 0.2999999995174605}, {
    0.9999999985827793, 0.29999999900204044`}, {0.9999999994110714, 
    0.2999999998303325}, {0.9999999995016858, 0.2999999996491038}, {
    0.9999999997929248, 0.2999999999403426}, {0.999999999824786, 
    0.2999999998766202}, {0.9999999999271896, 0.29999999997902366`}, {
    0.9999999999383924, 0.29999999995661797`}, {0.9999999999743988, 
    0.2999999999926244}, {0.9999999999783379, 0.29999999998474625`}, {
    0.9999999999909982, 0.2999999999974066}, {0.9999999999923832, 
    0.2999999999946365}, {0.9999999999968349, 0.2999999999990881}, {
    0.9999999999973218, 0.2999999999981141}, {0.9999999999988871, 
    0.29999999999967936`}, {0.9999999999990583, 0.2999999999993369}, {
    0.9999999999996085, 0.2999999999998872}, {0.9999999999996687, 
    0.29999999999976673`}, {0.9999999999998624, 0.29999999999996035`}, {
    0.9999999999998836, 0.29999999999991805`}, {0.9999999999999517, 
    0.29999999999998606`}, {0.9999999999999591, 0.29999999999997123`}}],
  Editable->False]], "Print",
 CellChangeTimes->{{3.741325304066078*^9, 3.74132532306609*^9}, {
   3.741325383059689*^9, 3.7413254380118427`*^9}, {3.741325488759585*^9, 
   3.741325629225685*^9}, 
   3.741333195160972*^9},ExpressionUUID->"88af7980-8f65-4a13-a36f-\
d932e7ee52ed"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Explicitly sum the flight distance from the coordinates above: \
\"\>", "\[InvisibleSpace]", "1.2333333333332894`", 
   "\[InvisibleSpace]", "\<\" km.\"\>"}],
  SequenceForm[
  "Explicitly sum the flight distance from the coordinates above: ", 
   1.2333333333332894`, " km."],
  Editable->False]], "Print",
 CellChangeTimes->{{3.741325304066078*^9, 3.74132532306609*^9}, {
   3.741325383059689*^9, 3.7413254380118427`*^9}, {3.741325488759585*^9, 
   3.741325629225685*^9}, 
   3.741333195175394*^9},ExpressionUUID->"acb5834f-842d-4a9f-b4ab-\
2916af1c9308"]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV13c81H8YAHBUEqWsRBsJCSHS8AgZGVmJspJUysjeI1tGQ0VFtjIyIiMr
GXdndva6O753h1JHP1GE3+f+4v16fe/7fT7PZzzP57C9q8lNNhYWlgFWFhbm
34s3Z742zV5WRf/KCMtbqG7WEHYjCykCi1VzRY2MEii8SXn9QUgTWLxVqqyO
aYFe11B5mpAZsBxzOTUnZg5XHJbrnwg5QGg1ab/CHkeYkI3WSBDyhNBlovPk
uhdkCFyKihOKgAzN8PTQzkgI4/hwNFYoGSjNamHvbj8DC8vMkvmFHOAQYdWd
vJ8LXBthVtoHSkBxfJVVvew9HDH+OfPlYQUc2H2/mSv6A/h0q0DKYg2on4jy
CiipAsEKHhIrayN4sloXLqh8go9TGp09Z5vBafrUp5HKBmh2SttrOdcC/HUP
JY7RmuC3+Lmdxc7t8LtY/Ou8bDOw/S3ctfcIAcbNzy86un0BpQ27j6bvO0H/
xo+qLL8W6IxQ7G6T6oGymA/fC2xb4eCj73/f/ewFu1+GmR9V2uD7Mpk0IEeE
pkOHO31n2+DjraTmi0pE2FWSUHJ6rg1Ch1TzGs8Qodn7bePKzzbYXZXm/E6L
CBw5J297LbaBuve1f4FWRJDjxX8z22iDl4uDQmIxRAjY/06pnr8ddBa6zNzJ
RChYXGQoqbZDzrdPBO7EPnhC+G8/42E7uLy4JOr0tA9Wbj+bOJnYDsqaWEBr
Sh/0R+it+z9qB0Ia5/HA7D7gdBG5yfKsHRaMLJNmq/sg+XnV0HJaO6hWLZm2
YH3A//kGIbWkHUbCT0z4qfTD0oPpiuKv7cC9P59BpfaD/mKdoCIPDtTMwyew
2X4w9HUmL/HiwD3JtmPqZz9sHwu2qubHwSDrnnzKn34gqsT4Ku/BQTo9xmZ8
+wCo6zzWFD+IA5lSp64+xQFIZLdKapPGgYGGTGFzxAAYLnezC2jjIP5OpWOG
2CA07Gc7yeaLg29qxTFcUoPwsNzkxDM/HGjvyS3wlh2EFd5VvHgADtjak3/q
nx4EzemnxAvBOPAT8/T+e2kQHMsKjDwicOBIlo8yCRgEOaenwfGPcHD+cmnu
ZuIgdNhFPfmUj+KTftvuOjQIHD+OnBB9h4N/mzJmR8cHQRUvEhxbgIPq8qTj
ZdODsE/E64hJMYp/l2ul9doguEmer+krx8G+juOtHyWGYFQ6zSOlHgdLaoXU
2yFD8PZvqpg0EQd1Od9f+UQMQdRIq8/lPhw84JA2jYodAtnHPhVB/Tjg7i36
nP10CBa9z88RBnEgbvs+nZQ/BHG55+0txnBgHlRmYdY7BGwj0d1AxUFlTVUn
HB6GO9+6xjV+48B//59wQ/FhKIkf1tBbQvMTduqM9bFh4A3ZlW28jINOnZp3
/ieHQV5jQu/aXxxQh2qjKnWHQZZYZ2q/hgP+pXq1Y+7DcPqyRDZswYOnfEvF
7i/D0K9m6nWaHw+OiocyHuOGQeJ+PfdJATxYKAU+3N49DLgXOeEyu/Fw5rSi
PdvIMDyxV2U7sAcPbOo5O3/+HIZpiXl7xl48JBlHOLUKj4CVQbeilSgeCtw0
D3m6j4D5q3AZ+xN4eO2ewcXwGQHf4GgLFXk8JHj+W7oTNAJHjhe77VTAg5tv
RZdtzAgQosudqxXxoBwqFqCXPgLEe78L1pTx0JK0eVCEMAKvCBMVl1XxQH7f
8vDr4VFgCdAWVruIh94fm+fkj44CZ5zc2C/kJukL+snSo6Apy5eXo4eHjILW
7VeUR8F/6O+1LQZ4sM9rSxjXHwXFiborny7hgZ6GS5r2GQXh0lecK2Z4+BHf
+XStaxRqt3SqtNnggdSxfdGmbxQebbmhd80WD92cBmZNw6PA7ZXiy0B+H9PF
H46Ngqwqn4TAdTSeiO5nHH9HwaSq+tvlG3hYDOh9wSc2BhbKF/yLb+Fh1an/
laT/GLiyeKZXu+LBTMn6sUzIGJi5uvBJueGhiJUepRAxBhJJf3pfItukLN8/
lzgGAnpRR/3v4+Fzq7COcdYYeD7fdUnOAw/Rh64v+hLGgJB4dM7fGw98gz/0
ccLjkJL5IjQ+EA/3Mr3Vuw6Ow2btp7Rp5JZ7G8pEsXHQmb2fqR6EB+9NPKLj
MuNAScg6uIQ8Iqf4l6E+DqUqV9Uvh+DhzUP/XMG742Aq6xS5GIaHY+e3rjt+
GgdXmQtitVF4KC0oPDrcNA5q97pUtkbjQZHfyFi3bRxmqu+lmiKfnU7JOfZ1
HJbqTql8QzZMkNKbp6P3i7Jw7YzFg/uIQYof7wT0cwj7KD/Ew5L6r8/fBCdg
T0icux9yQNHz79f2T8DhNfnPtcgRIWRVVYkJaDP0vHomHg/Pj9ynsalOwOpq
WbxiAh5q7ifLx9+ZAI29065bk/CgOnbKas1lArZaXsJUkZs1JyJdPCfgwYtd
H7yQCYLiI0YhE0A2o9+ZRB6vrwoReDYBvRHDmmWP8MDCOdaZ3jQBTea5sgpP
0Pc9QpZ2tk2AwHf+YjvkbROih8I6JoDXbz0pAZm39J7HjcEJ0G6KjqEhi5mv
C0nMTYBiyT2zxKd40M46fKtMkASGRQZDX5JRvlK4xdv2keBP9sVHNORDiavU
0cMk4A8PJbA/w8OK34D9ZmkSEAPcW7SRi41jba6okeDJouvYF+SX2t77710g
wbZWxcJJ5KhzN8ZDL5LgYuTsxjqyneS5qwVmJLCxXFc59RytD9aFy2u3SbA2
N7CWg8yyPMHP64J+PyLM1og8N0foE/cgwZl69qRh5LbhHGOjIBKc/vVek/MF
HvxKLQyyH5MAKzwvfRvZMe/C9urnJDBZangQjGzyWr6j8xUJ4PzLm8nI0jHb
dZdySdBspUVsQCbbNmnq1pIgW9vLjDsFD52XizfZNJJAVQETPoxcrfey2b2F
BOVHHe8rID9R9lR73Y3yVRLVa458YafEWcYUCZ4OyjukIMtvEVjdNEMCiTzd
6nzkA6ustXt+kOBnlHTGR+Q/9DFl9WUUP4v88T7kwoYkhWdcZOBxPau7NRUP
KRWBv97tIsOdmxU6fMgRBXfKGgTIoO9VQj6AbPNcQ3bmIBkoNzkHFZH14uV+
/hMjQz6HhRIgn3qwv5hHigxiupvldJF5XJalziiSwfOo2cI15PUb1NlLKmS4
Fk2rcUD+Zvn1rYMqGY5uK9vvjNxyoVA8UYcMKUtfqwORy86k0LIMyGAqJrAQ
jpx+IjKnyoQMh/44t8Uh++y3FZm0IsOe3WcvvkC2N5IzH79OhkvHVyZeIxuG
s8YNOZLB3ceZPwv59EdiPfEuGbKWt/zMQxafzV7ociMDW5nC3UJk3n1eR/Be
ZKjIc4wvQV4z1LJs8SfD+Bi3yQfkmTDBhMYQMrwyfV33Ebm/YqapNoIM/Dwh
nTXITdM1i5WxZHASPPqgDrlQ+KFEWSIZGu5sJjUgPzewsip6SgZ5rmhKE/KD
0OOP8lPI8G39QFwzssuH9S9ZaWTYpnN27AuyJb1nOS2LDKWzhv0tyJpCmcdS
81G8021erchy+u62yUVkENHgb2J6X4jG06QyMsix5n9gems5f3vcRzKYiDGM
mP5Fpa1EfiLD2xKrFOb7SIJVMmFNZDDLs41jfo9wMcY+sJUMgVy3jzLjqQyy
fO5DIIPqFM2VGW9GqRTBvYcMTcd1HZjjicdW15z70fcXWLcwx+u7u+vEnREy
xMiGmjDzcUM3/aYDiQx8cwoGzHwZBrqm2mJkoEsm/C5nzkeJWtfVGbRe5lb1
mPkWn+JhNf9BhvmT80bM+eARwBSNf6F8co5uzmfm3z/ytfY/MqzYGgakMdeP
+bHbmSwUMJmuVk1BtpvnYzu4iQLULSPlT5jrU5R2UpiDAmcFVt5HMeenrqvn
BScFdLePKYciK5l/vCOwgwJ78k94+CGLxEan7eKlQFz/Bttd5n4QcVNO5KeA
u/MVixvI3HUWX7kEKZD3kXqduZ7//pTcsnUfBUId7Z5eRO4167y3doQC1U/3
BR5B1vpZwR4gQYFOdvuQvch10WkZf6QooKZhfZoHOb/Wpf8/WQoQxU6OrKL9
GHyI5+w3FQrcmipo60JerPk7cOssBdT/kJ5+RnYynXKlqVLgybzOvkrky1Ef
sikaFNj9LNjuFbL03GWuIQMK+G8pa3Zgnh9m+o1xRhTIWpU9exlZo17dQ9WU
AtLm2O0LyFcTZcdyLShwWkuUJIYcK7et0PMGBTg8irQp6Hyie9Zd5PWjAGHL
1mRdZPeJ8vXWAArMUAbCTyKvXXhX7heMxnsFL3sYmV/wufBkOBqf+NWGZXRe
atS4fitJpEBbfntrJnLGmkicQQ4F2DR+r8yi81jaUUiVNR/l31dw/ityVffO
XxXvKCAXalhQg9z95p/lvhIUn6CyWwzy2vlBye81FIj6/NxYFPlqVCw+pocC
Fjs+TBuiesG3c56jZYUCmyt9LoahekOsj4vWXUP5B7kNB+Qn946w92xQ4Hu6
yCMdZn0iXN00unkSEhsjdXYyHdm6xuCehAO9qwdfPcbDrtWXv/aKTsLoNcue
IlT/tk9fGPfQm4T42LvWnxLxsLnxVYno60mwf+2TnR6Hh9Gzmjrk9EngCDA5
6o9cUjtHeZk5CWbPzLIvI1/9eI6XN38S0i0PRG1HLisme7KUT4KI1DK7P6r/
Nq9FT0+0T4KNopKPWQyaP7/Cluf/TYKOStF+LtRfJC6bWpssTcID3/2t9Ei0
v7z+/d7xdxIMRxR9mpG57xscjVyfhKvjuWt+yDdvM2I9tk2B+0Jj9mwEGt8V
hUtGB6eAP1N/sCMcD3cVP41s05uC6utxlDeon2nqHSiqNpiCNyXJqcHIAs7z
IbeMpoAz6IOLNXJj7hHx1stTEPvGxnUvMp/gI/dQuykQ0Pg0khKKh09/HbiW
vabAf9OurlTUL3E1cp+jZkyBlr0yWzXqp+yuSe56mj0FRtt3G7xCrlzWwM7n
TQElOLY1GNlWzi/2TSGKp83mvBbyh0xs4OrHKThwmM9zCPVr1yKqXb52TAF9
Q0xtE3Khrn1Gw9IUiNmsaUX4o/5B+rAq/J2C8fvdHa7IDdyUscZV5Cjf6GvI
vX3Wgp9ZMBAWO5CrgLxobZn4hRMDGeV9UXQ/PASp7ZHW3IHBoJ1Idx8yu+gQ
vmUnBrFOiUafkYVmzLa08WNwP8GGPQ1Z1d0oEHcAgx/79NWvILeb7RTWPYzB
E5Ofd7SQjZS7q/CiGOo3w3tOItv/0/uPIIFB6ZieuQBydJS2U5c8Bm2NLTZD
vii+l6oWRC0MRHrrG24hWwat/TbRxWB2o3PlKvKUbd3TPj0MWIpmAgyRF8VO
9/QbYRA6w3VJCVmo5KTW0FUMHNddLmxDznq8iF2xxsBk36WP6z5ov3l+CBu2
xcDoGc51EVlV5UT9iAMGlK2GDRRk+y/SiuMuGPxb2TlYh/w99/tXq/sYCK0d
TalA9owpcJ3wwGCbimNeEXK0gUQhyReDlq6979KQd8lN69gGYAA23unPkV/y
5tHJQRj8fFE/mYRcNCQqMvkAA23vYdNw5JO1U43XIzHIMkkKD0JueJ1pPRWN
wVPtv2y+yNohdqv2cRjMz0cT3ZF7rx9MxeJRfr8V/XJGttQkKTkkYWDcO3Lj
DvKUeFo/9TEG7Kqh4jeR722zcr+ZjEFMD8+Z68i/vwvvoj9H+T/EkmWNnJw2
3f46FQOzf417riIrXKoIMX2NgVOX+4I5MpElTJnzDQaqvu+kzZDvlxswmjLR
+plcJBgzx+sgnO+Tg8HFOVrnJeQSgWkbmXwM9gTvUDBENmz/sJv2DoNu/39r
+sg/fEO7XxVhUNWmIcN0vJRBlEkJBge0PFv0kI+NC6luK8fg0sSBz0wTEui/
GyvQeN36xZjP34EPxd5VGChRj8wzzbEQcvN4LZr/fTmizO/lZ+nvp9Zh0LhG
bmTGo2UmNPCyEYOz95xamfHSttDjjZsx0NTvV2SOJ6KqXJOjFX3/wXvuK8ii
d0L+NbRjIPgr1pSZj2Zh/QovAgZ+ocubbJCvd+65J92FwSOemEP2yCzBNFGs
B4Pc2M53jshvZMvHUolovXddzriLPPFET2/rMAZ4Lf8hb+RAzT2bGkbRermg
LMSc771L1FrPCQwUMwMJzPVgaRksNTWFQfo6FvQE+Q+n3lQKDQNp/NGwl8gv
6gRfXprBwDJMeSkLeeBg2bb6HxjU6a0rVzLX59egzx7zaL7Fh7Y0IvOFX/ST
+g+D/aGN2nhkYzo28+IPBn1qbFJk5PkXpRmGq+h5t+COb8hJukEWW9YxOFFq
gC0hdxXtxrlvosKjeQnfXWg/3bPBQiTZqTBaY760H5lrV6kyhYMKmmJ7fxxD
1vXQzTfgpkKWc6GWLnKrSmCUhBAVqgnNNbHIDt91VMl7qSDzLHj7K+RNaQJL
zw5QYa+oxXgR8nmWkpubxKgQKvz291fk+rZJTZIMFd66Jh8QQeeFle/7f8kn
qLBiIOikjLwqGVChp0iFPbygbICsksAvVqNCBcp4k4U/cqWp9qZkTSoMeDri
RpFj9Koj92lTobRqX+Av5vs0JDlydangaFqZw4nOQzYFrh0fDamgxn7T/Cyy
IW/P7mELKhS4ZunkIh/mVEu1u0YF26RLpU3M85O1bO+sNRVyZxMejSO/Wnhy
aMWeCk0Nz+oEAlC/1msutc+ZCgqsH3sSkD/h2otyXKngxvWVoxg5semU7HF3
Kvw+Id3QiaxYKqyo6oPi0/R/swOd72FJpHN2YVSgPrfUfYYsbOhonPOMCvLp
FzLrUH34cWGoTzqFCvF5mQMYctM5HfPKl1RITXyVwBWM7mPHpa61vaFCvota
nBXyh+0/HWbeUSExQv7LZlSf9Du8fKUbUDxVwy9dUP06+IW+UtFEhcxFY7V0
5F+1V4LOfaHCfH+bWzdyaoHKA0McFdoY/p5yqP7RY9ceuhGpoJMzz7eKHKIT
+aaCjuKplhcuRPWVaHPbSm6WCqRNojFTyGJeekJF31H8ZpUPhFE9JmTyPM2e
p0LtkcCD8cj8q2lRT1aooOVXtckb1e+3xR+d3bhpQNLdPuwQje6/X1Kl5nbR
YHRcQjMX2WA0cPoWHw3O/xvSoCP/Yte4bruHBiJsBRt3UP9w1q7HzFCEBtKC
6l6+qL/o5Z05I61EA/buOzVlD1G/K9nxJ/8UDfYc/PRkFdkL3leKnqHBangS
u1Y8yvc9T9m9ajTgLAxqHEd2aGUR5bxIA/VryQ94UP/zx0eIc8aaBpWFxPcp
qD86PHFxODuSBum63W8PoX4vrvlMyeUYGvwqMy+LQv6VLx219SENFjNkQ38g
N7tzK959RIPwCE6PetQ/OnAQk+Rf0UAjcKbOEfXHbxUstT+X0qCR1dGa/BoP
MnG3PpLG0PtZXMrv5aD7lKtFwiMSDRqUp17MIW+Y6TqoT9IgMMz+snMuGu/B
Y6gC0UC/oeHq/Tx0flf+dHZeoEHx8p308Ld4qKB4HfnHToeFs0WRX4vQfUQ5
IllIng7uxfSK3R/xMGgvpJSmSIf4+kbFt8geie+HDinTQWeFN/R0FapntGFh
ibN0sBhb9L9eje7bycczlbTokHJLjbumFu2nhcFi06t0eMmO25nUiIeOAsn2
hAd0+GYoljuCx8PtwYbbPJF0SNcI9YgkoH6SzYzzWTQdbrrX75XvQPXZMtjg
dTwdRmzfriZ04qF0a19fwXM68OaNbjHqQfXLIZDSXkCH7nMP3q71o/18oOcv
ax8dauNuG7BNon5QyL3y0wAdsjRf7BxD/swncN9rmA4ZKYSpiil039p2bWZm
gg6CinENd6l4YPxHH+yZocP6uYBr9Gl0P8Wvf0hbpwO9JblwJwPNh6eMi4rU
NDSNiL9VWkf9rOtXyf+kp2E31TBffgMPO5w8aUWy01Be3o+XZSGAu22t1aGT
0/Dns2bAcTYCnLmopbdVbRoai1veKLEToPugjcTA5WnwnvzgGspNgN+EhCm3
sGlQWuyVWTpIgHGugdv/wqdhF/94yObDBGjW38eIjpqGi6+/k/hECPCou2A1
/eE0DC/8xp0UI4AUsZ2/69k0KGwhWEZJEMBmhFVbsmAa3t1lG7p6ggBt016F
k0T0/HHdiH4NAqRstvE0EZuBsyqD3WL3CLB+Q/DkV/EZaJKKSPVwJoDDl97f
lyRnoCrZLeKLCwHkHmj4GMjMwDGD9jrH+wTAbUj465yagWvv67/UehNgeeW/
EFX9GXAXtUxIDSOA+ULsQynPGdh3M0v0ZAoB+EiVWWwtM8BddHrjH44AiduD
gqraZkDZr/9gLYEAnGc0Le7hZyD1fX2FbycB2FKIOwa7Z+DB2fpzKz0E+GXM
8H03MgNOhpLj3EME6G2VuGTEmIHB5764YBoB4otfraYJz8LvvdwGQZs6YEtQ
mJnK/VmQYp/x5tfsgIqFub+NHrPwdhfvKLdWBzg4WrzR8p6FmejuDE6dDmi5
JPvNNGAWJA4Rr7Lrd0CEyESIS+QsaJV2JHCbdcBm3KnC7NRZaOJru2zv0AFs
fPOs3M2z8G1H2xvhqA5geWdTMsX7DdhYHQqnuzrA/WVJAm/zNxirzuR0C+6E
+mMxHDwu3yHJo5PsptsFPBfdpR9wz4H6kvK8lmg3jB/v7fOrm4O5RF7rPLke
KE0HMarND3gsQeV/I94L1iVKPPvXf8CN0HmZhOZeCI3MDBsv+AmvTbcPHAn5
CsUz+19x6zPAM7lc31idCDFpkXYkQwZELjVqUS8QwcHkx5H3xgz4b+tki68u
EfbV1ZUaXGGATGiGYZ4REeKSrrXF2zNApYaawWdLhNtKqQucfgywobNGKwcS
QSSCX2drHgOifj1MyKsiwvqpwB1DbxnAg5fMc/pEhJEfGDGvkAFXY3/oyzUS
4dGVD9ZaZQzw4ZbUamojwoaUiUdkHQPm9qvN/xogwvjXpPRNfQzw/uZ8J3uR
CNVRyzf6BhhArZKJC/1DhOQztpLZwww4H39A1fYfEfRyZSrUSQwQetxld3hz
H9T6duHDZhlwZf3Uy2q+Pnh+/GSS8RyKd+m8dZZgH9yfem12mMGAH+HrlQl7
+0BC/x65aZEBv/P6Je+I9sFm1v6cR8sM4LdLumB5tA8olWec7FYYwLEEfy4e
64M6p2xZuTUG5K4oqavK9sGLg1y/NzYYULfRIqqg0Af/A/0+5PQ=
        "]]},
      Annotation[#, "Charting`Private`Tag$3249#1"]& ], 
     TagBox[
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV13k0VV0fB3ClUCTShFJokKRSeRL5Ft4ypQxpklmhEpXqMRUhjRqkSMjQ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        "]]},
      Annotation[#, "Charting`Private`Tag$3249#2"]& ]}, {}, {}}, 
   LineBox[{{0, 0.}, {0.5465031328456735, 0.5465031328456736}, {
     0.7184558966735498, 0.2025976051899211}, {0.8317823483635645, 
     0.31592405687993624`}, {0.8727386205010461, 0.23401151260497288`}, {
     0.9304357858393724, 0.29170867794329924`}, {0.9436721154674346, 
     0.2652360186871748}, {0.9723808293408863, 0.2939447325606264}, {
     0.9770242838785701, 0.2846578234852588}, {0.9896560099089164, 
     0.2972895495156051}, {0.9913024528958371, 0.29399666354176385`}, {
     0.9962650640236753, 0.2989592746696033}, {0.9968468691814862, 
     0.29779566435398136`}, {0.9986735065826057, 0.2996223017551008}, {
     0.9988785042212824, 0.29921230647774816`}, {0.999531894152832, 
     0.29986569640929756`}, {0.9996040303098507, 0.29972142409526004`}, {
     0.9998351957628213, 0.29995258954823056`}, {0.9998605669254598, 
     0.29990184722295377`}, {0.9999420262686982, 0.29998330656619365`}, {
     0.9999509480026745, 0.29996546309824107`}, {0.9999796123830401, 
     0.29999412747860676`}, {0.9999827494970154, 0.2999878532506563}, {
     0.9999928310307872, 0.29999793478442793`}, {0.9999939340967656, 
     0.2999957286524711}, {0.9999974792420434, 0.29999927379774877`}, {
     0.9999978670968874, 0.29999849808806056`}, {0.9999991136606822, 
     0.29999974465185525`}, {0.9999992500359862, 0.2999994719012472}, {
     0.9999996883501465, 0.2999999102154075}, {0.9999997363016058, 
     0.29999981431249284`}, {0.9999998904195325, 0.2999999684304196}, {
     0.9999999072799277, 0.2999999347096296}, {0.9999999614699894, 
     0.29999998889969115`}, {0.9999999673983365, 0.299999977042997}, {
     0.9999999864523158, 0.29999999609697714`}, {0.9999999885368044, 
     0.299999991928}, {0.9999999952364477, 0.2999999986276433}, {
     0.9999999959693825, 0.2999999971617735}, {0.9999999983250694, 
     0.2999999995174605}, {0.9999999985827793, 0.29999999900204044`}, {
     0.9999999994110714, 0.2999999998303325}, {0.9999999995016858, 
     0.2999999996491038}, {0.9999999997929248, 0.2999999999403426}, {
     0.999999999824786, 0.2999999998766202}, {0.9999999999271896, 
     0.29999999997902366`}, {0.9999999999383924, 0.29999999995661797`}, {
     0.9999999999743988, 0.2999999999926244}, {0.9999999999783379, 
     0.29999999998474625`}, {0.9999999999909982, 0.2999999999974066}, {
     0.9999999999923832, 0.2999999999946365}, {0.9999999999968349, 
     0.2999999999990881}, {0.9999999999973218, 0.2999999999981141}, {
     0.9999999999988871, 0.29999999999967936`}, {0.9999999999990583, 
     0.2999999999993369}, {0.9999999999996085, 0.2999999999998872}, {
     0.9999999999996687, 0.29999999999976673`}, {0.9999999999998624, 
     0.29999999999996035`}, {0.9999999999998836, 0.29999999999991805`}, {
     0.9999999999999517, 0.29999999999998606`}, {0.9999999999999591, 
     0.29999999999997123`}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], 
    FormBox["\"x\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox[
   "\"Spacetime diagram of two trains and a fly\\n Fly's path length = \
1.23333\"", TraditionalForm],
  PlotRange->{{0, 1}, {0., 0.9999999971331381}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.741325304187909*^9, 3.74132532317694*^9}, {
   3.741325383175604*^9, 3.741325438114593*^9}, {3.7413254888659773`*^9, 
   3.7413256293344307`*^9}, 
   3.741333195265709*^9},ExpressionUUID->"307263e1-9f60-409f-a915-\
ebaa1bf800e1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "t_", "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"Log", "[", 
     RowBox[{"t", "+", "1"}], "]"}], "/", 
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{"Log", "[", "2", "]"}], "/", "0.3"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"g", "[", "t_", "]"}], ":=", " ", 
   RowBox[{"1", "+", " ", 
    RowBox[{
     RowBox[{"1", "/", "4"}], 
     RowBox[{"Log", "[", 
      RowBox[{"t", "+", "1"}], "]"}]}], "-", " ", 
    RowBox[{"1.8176320469261664`", 
     RowBox[{
      RowBox[{"Log", "[", 
       RowBox[{"t", "+", "1"}], "]"}], "^", "2"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Vfly", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"-", "2"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"coords", " ", "=", 
    RowBox[{"flyTurnCoords", "[", 
     RowBox[{"f", ",", " ", "g", " ", ",", " ", "Vfly", ",", " ", "30"}], 
     "]"}]}], ";"}], " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Find", " ", "30", " ", "round", " ", "of", " ", "the", " ", "fly", " ", 
    "meeting", " ", "both", " ", "cars"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{"\"\<The fly flies a total of \>\"", ",", " ", 
    RowBox[{"flyPathLength", "[", 
     RowBox[{"1", ",", " ", "0.3", ",", "Vfly"}], "]"}], ",", " ", 
    "\"\< km. (Given by theoretical formula.)\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<The {t,x} coordinates that the fly meets the car: \>\"", ",", " ", 
    "coords"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<Explicitly sum the flight distance from the coordinates above: \>\"", 
   ",", 
   RowBox[{"pathLength", "[", "coords", "]"}], ",", " ", "\"\< km.\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"showFlyFlight", "[", 
  RowBox[{"f", ",", "g", ",", "Vfly", ",", " ", "1", ",", " ", "30"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.741323328448682*^9, 3.7413233384376087`*^9}, {
   3.741323737563033*^9, 3.7413237391952477`*^9}, {3.741325274183983*^9, 
   3.741325437031108*^9}, {3.741325486419887*^9, 3.741325628405702*^9}, {
   3.7413259431269913`*^9, 3.741326125471767*^9}, 3.741326428570953*^9, {
   3.741326459937542*^9, 
   3.741326467833425*^9}},ExpressionUUID->"d6a95b89-95d8-4861-9f09-\
caedccfeec8e"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The fly flies a total of \"\>", "\[InvisibleSpace]", 
   "1.2333333333333334`", 
   "\[InvisibleSpace]", "\<\" km. (Given by theoretical formula.)\"\>"}],
  SequenceForm[
  "The fly flies a total of ", 1.2333333333333334`, 
   " km. (Given by theoretical formula.)"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7413259896929617`*^9, 3.741326034934328*^9, {3.741326074136589*^9, 
   3.741326125965577*^9}, 3.741326429597159*^9, 3.74132646880976*^9, 
   3.741333195345585*^9},ExpressionUUID->"ab792ee6-2f02-4de5-a26c-\
23a1887f07b6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The {t,x} coordinates that the fly meets the car: \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.6599081350284899`", ",", "0.6599081350284898`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.8560292818235299`", ",", "0.2676658414384096`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9474786378936086`", ",", "0.3591151975084873`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.97928890522135`", ",", "0.29549466285300463`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.9924044378480472`", ",", "0.3086101954797018`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9970310238114782`", ",", "0.2993570235528398`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9989103858538678`", ",", "0.3012363855952289`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9995746114892357`", ",", "0.2999079343244931`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9998438666447973`", ",", "0.3001771894800549`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999390557796347`", ",", "0.29998681121038007`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.999977630887865`", ",", "0.3000253863186102`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.9999912687852489`", ",", "0.2999981105238423`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999967952674511`", ",", "0.3000036370060444`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999987491185504`", ",", "0.2999997293038458`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999995408723984`", ",", "0.3000005210576939`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999998207919378`", ",", "0.2999999612186109`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999342228874`", ",", "0.30000007464955836`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999743256823`", ",", "0.2999999944439683`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999905764145`", ",", "0.30000001069470017`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999963217582`", ",", "0.2999999992040128`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.999999998649926`", ",", "0.30000000153218087`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999994730351`", ",", "0.29999999988596254`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.999999999806581`", ",", "0.3000000002195088`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.9999999999245043`", ",", "0.29999999998366245`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999722897`", ",", "0.300000000031448`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.999999999989184`", ",", "0.29999999999765936`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999960301`", ",", "0.30000000000450544`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999984505`", ",", "0.2999999999996647`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999994312`", ",", "0.30000000000064564`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999997781`", ",", "0.29999999999995197`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999186`", ",", "0.3000000000000922`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999681`", ",", "0.2999999999999931`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999885`", ",", "0.30000000000001303`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999954`", ",", "0.29999999999999905`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999954`", ",", "0.30000000000000493`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999954`", ",", "0.29999999999999905`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999954`", ",", "0.30000000000000493`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999954`", ",", "0.29999999999999905`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999954`", ",", "0.30000000000000493`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999954`", ",", "0.29999999999999905`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999954`", ",", "0.30000000000000493`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999954`", ",", "0.29999999999999905`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999954`", ",", "0.30000000000000493`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999954`", ",", "0.29999999999999905`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999954`", ",", "0.30000000000000493`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999954`", ",", "0.29999999999999905`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999954`", ",", "0.30000000000000493`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999954`", ",", "0.29999999999999905`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999954`", ",", "0.30000000000000493`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999954`", ",", "0.29999999999999905`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999954`", ",", "0.30000000000000493`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999954`", ",", "0.29999999999999905`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999954`", ",", "0.30000000000000493`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999954`", ",", "0.29999999999999905`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999954`", ",", "0.30000000000000493`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999954`", ",", "0.29999999999999905`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999954`", ",", "0.30000000000000493`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999954`", ",", "0.29999999999999905`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999954`", ",", "0.30000000000000493`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999999999999954`", ",", "0.29999999999999905`"}], "}"}]}], 
    "}"}]}],
  SequenceForm[
  "The {t,x} coordinates that the fly meets the car: ", {{0, 0.}, {
    0.6599081350284899, 0.6599081350284898}, {0.8560292818235299, 
    0.2676658414384096}, {0.9474786378936086, 0.3591151975084873}, {
    0.97928890522135, 0.29549466285300463`}, {0.9924044378480472, 
    0.3086101954797018}, {0.9970310238114782, 0.2993570235528398}, {
    0.9989103858538678, 0.3012363855952289}, {0.9995746114892357, 
    0.2999079343244931}, {0.9998438666447973, 0.3001771894800549}, {
    0.9999390557796347, 0.29998681121038007`}, {0.999977630887865, 
    0.3000253863186102}, {0.9999912687852489, 0.2999981105238423}, {
    0.9999967952674511, 0.3000036370060444}, {0.9999987491185504, 
    0.2999997293038458}, {0.9999995408723984, 0.3000005210576939}, {
    0.9999998207919378, 0.2999999612186109}, {0.9999999342228874, 
    0.30000007464955836`}, {0.9999999743256823, 0.2999999944439683}, {
    0.9999999905764145, 0.30000001069470017`}, {0.9999999963217582, 
    0.2999999992040128}, {0.999999998649926, 0.30000000153218087`}, {
    0.9999999994730351, 0.29999999988596254`}, {0.999999999806581, 
    0.3000000002195088}, {0.9999999999245043, 0.29999999998366245`}, {
    0.9999999999722897, 0.300000000031448}, {0.999999999989184, 
    0.29999999999765936`}, {0.9999999999960301, 0.30000000000450544`}, {
    0.9999999999984505, 0.2999999999996647}, {0.9999999999994312, 
    0.30000000000064564`}, {0.9999999999997781, 0.29999999999995197`}, {
    0.9999999999999186, 0.3000000000000922}, {0.9999999999999681, 
    0.2999999999999931}, {0.9999999999999885, 0.30000000000001303`}, {
    0.9999999999999954, 0.29999999999999905`}, {0.9999999999999954, 
    0.30000000000000493`}, {0.9999999999999954, 0.29999999999999905`}, {
    0.9999999999999954, 0.30000000000000493`}, {0.9999999999999954, 
    0.29999999999999905`}, {0.9999999999999954, 0.30000000000000493`}, {
    0.9999999999999954, 0.29999999999999905`}, {0.9999999999999954, 
    0.30000000000000493`}, {0.9999999999999954, 0.29999999999999905`}, {
    0.9999999999999954, 0.30000000000000493`}, {0.9999999999999954, 
    0.29999999999999905`}, {0.9999999999999954, 0.30000000000000493`}, {
    0.9999999999999954, 0.29999999999999905`}, {0.9999999999999954, 
    0.30000000000000493`}, {0.9999999999999954, 0.29999999999999905`}, {
    0.9999999999999954, 0.30000000000000493`}, {0.9999999999999954, 
    0.29999999999999905`}, {0.9999999999999954, 0.30000000000000493`}, {
    0.9999999999999954, 0.29999999999999905`}, {0.9999999999999954, 
    0.30000000000000493`}, {0.9999999999999954, 0.29999999999999905`}, {
    0.9999999999999954, 0.30000000000000493`}, {0.9999999999999954, 
    0.29999999999999905`}, {0.9999999999999954, 0.30000000000000493`}, {
    0.9999999999999954, 0.29999999999999905`}, {0.9999999999999954, 
    0.30000000000000493`}, {0.9999999999999954, 0.29999999999999905`}}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7413259896929617`*^9, 3.741326034934328*^9, {3.741326074136589*^9, 
   3.741326125965577*^9}, 3.741326429597159*^9, 3.74132646880976*^9, 
   3.741333195353526*^9},ExpressionUUID->"6c50e8d3-9dda-4a17-8862-\
e94692225c93"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Explicitly sum the flight distance from the coordinates above: \
\"\>", "\[InvisibleSpace]", "1.2333333333334786`", 
   "\[InvisibleSpace]", "\<\" km.\"\>"}],
  SequenceForm[
  "Explicitly sum the flight distance from the coordinates above: ", 
   1.2333333333334786`, " km."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7413259896929617`*^9, 3.741326034934328*^9, {3.741326074136589*^9, 
   3.741326125965577*^9}, 3.741326429597159*^9, 3.74132646880976*^9, 
   3.74133319536524*^9},ExpressionUUID->"c8e65e5a-ae4a-4a15-95a4-\
d1ea7fe8daa5"]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVk/k71AkAhyn7UDQlGc/U0rJjWhRTyZFdnxg2mSRXsii5CtWiPKV2syNU
jqhmI1eJlKQhR+VYR5MiDPNVQ8tMMeQYvrSuarHtD+/zPu8f8Gr7/uocsERO
Ts7hK//bPmCoo27YzTKmlv1mYNbaUoG1NlRCM4bBTOmqBwHa2HozLbOUZgOb
x/cPifw3g90qepRFc8VmY02dw35WcPefrblK80deUdtkro8Teo0usJJoJ3GO
0DQ28jyEW+qOcfG0GPhY+vn9sjcMHKXSDZdoXPQFOYqGt3Ow3yOHNzGZh3lf
dsoM/wqUFzleO7V48M0Wue5lpEPXaXzoWUIZ2unzHyPW5eBUmznSpp7iyPIs
r5DAO9AoUxXLy9dinBrFNXQrQEUfq0XwYwM6L2VRj8cUoSE4a52HjI9NexOt
gxqLMc34aWXRsReIZ8eapd58hCWfClet023G/smCmtHUMpgs+lS4PGxBo1oa
XgZWoCXGuK1RXwCdODLOWfcJ1qeMfioYb0dS5VnBonwlRmcl4tdMIXpzGHqF
j6uQN1LVTLlM4IfIfZXc+BpQNO+SUmknHD1DzG441CIxqDzwFv0N4gKLT4xF
1GFmR6H0SJQIsRb6tiYu9Ti5hV9GfdaFM+Vh6jytBkge8hM6tN+i4fMcdWS2
AV+COzP0zvwNZiIs5JqfwcBKcSGwqgeskMtR5gl87LytfbhEQwxK96tTTR7P
cUrzoM57LwmORx59P6vRiI0yN2WRwzv4U4or5gSNUFs5ocT//A5PqaolMu4L
KNRm8L7PfA9u+gXqLvuXCDGu6l7G7kNA0pQLS6UJhbt8b/010wdmj/raDS+b
MD26dtXg9X5MDJmmG0U0o9xl51KujRTxC/P/Rhq+QpRd7M2yQSlsFZs+2nW/
gnavfVdu7AD+GTx9pf5cC7abxnBpWwbhluzQzGC2wktL8Eme+NpdeSIe0Yrp
5qS+UM4HrKGlGPVGtyFN4cBJZ/oQoj0Yu6PpAqiJy28v4Q8h4BI1zLRegG9+
57iahw3jar31xRzjdsgVHOD1rR7Boc4Nx/Si2xGezkta3TCCe1ZzxRav21Fj
cFFJ9fgowq9ZPX+r2wFV+/CN0RQZzDqt3S1DO9CzqZ2IrJYhJHVGUamuA8XZ
oEsPjCH4gQ39yTIhvHkmqpoLY9hha6Ji7iTEH7E5nJ774yA8890WsoQoGtLM
oOwmwdp2NKhfKsTFrFgf8R4SOzImvLUGhfB3HtN96ESi5OxpG48PQnxbXV3s
4E7iWm7qh7ZhIeKTPRsTfUmcY5vEPR0X4ojJjcnlkSTEzssZiXNC6MSssVPM
J7FsP2+OoUJgwey3FaJ7JDz6FZk+Kwh0j/UL8wtJKO1L8LhBIZDiXur9cwkJ
006N88qqBBb1nU/EVpPI9g5ikuoEejqSs5cSJPaELE6VrifwJG7Wj3hNoulu
mqPsOwJci4N6uV0kylihmXQdAuw7hmXWYhIW4RKVP+kEKk+3NnGGSfQkSOwi
9Ahc37Qt2UlGojI/aVuRPoGwvkxXbZLE/dbzawYMvn6y+6ikboqEgppDgash
AQX5zryUWRJF6ToHE40IvCu3CPb5TGJAzlaRzyRQHZxrxJwnIY0sz/mymUDq
euXpxUUSNeYRhlu3EvgP8VZmMA==
        "]]},
      Annotation[#, "Charting`Private`Tag$3300#1"]& ], 
     TagBox[
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV1nk0lGscB3BpIUqUyBaKW9lCpSK+Imu0kKsFKUJkK7cr3YgQhYpJKaSs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        "]]},
      Annotation[#, "Charting`Private`Tag$3300#2"]& ]}, {}, {}}, 
   LineBox[{{0, 0.}, {0.6599081350284899, 0.6599081350284898}, {
     0.8560292818235299, 0.2676658414384096}, {0.9474786378936086, 
     0.3591151975084873}, {0.97928890522135, 0.29549466285300463`}, {
     0.9924044378480472, 0.3086101954797018}, {0.9970310238114782, 
     0.2993570235528398}, {0.9989103858538678, 0.3012363855952289}, {
     0.9995746114892357, 0.2999079343244931}, {0.9998438666447973, 
     0.3001771894800549}, {0.9999390557796347, 0.29998681121038007`}, {
     0.999977630887865, 0.3000253863186102}, {0.9999912687852489, 
     0.2999981105238423}, {0.9999967952674511, 0.3000036370060444}, {
     0.9999987491185504, 0.2999997293038458}, {0.9999995408723984, 
     0.3000005210576939}, {0.9999998207919378, 0.2999999612186109}, {
     0.9999999342228874, 0.30000007464955836`}, {0.9999999743256823, 
     0.2999999944439683}, {0.9999999905764145, 0.30000001069470017`}, {
     0.9999999963217582, 0.2999999992040128}, {0.999999998649926, 
     0.30000000153218087`}, {0.9999999994730351, 0.29999999988596254`}, {
     0.999999999806581, 0.3000000002195088}, {0.9999999999245043, 
     0.29999999998366245`}, {0.9999999999722897, 0.300000000031448}, {
     0.999999999989184, 0.29999999999765936`}, {0.9999999999960301, 
     0.30000000000450544`}, {0.9999999999984505, 0.2999999999996647}, {
     0.9999999999994312, 0.30000000000064564`}, {0.9999999999997781, 
     0.29999999999995197`}, {0.9999999999999186, 0.3000000000000922}, {
     0.9999999999999681, 0.2999999999999931}, {0.9999999999999885, 
     0.30000000000001303`}, {0.9999999999999954, 0.29999999999999905`}, {
     0.9999999999999954, 0.30000000000000493`}, {0.9999999999999954, 
     0.29999999999999905`}, {0.9999999999999954, 0.30000000000000493`}, {
     0.9999999999999954, 0.29999999999999905`}, {0.9999999999999954, 
     0.30000000000000493`}, {0.9999999999999954, 0.29999999999999905`}, {
     0.9999999999999954, 0.30000000000000493`}, {0.9999999999999954, 
     0.29999999999999905`}, {0.9999999999999954, 0.30000000000000493`}, {
     0.9999999999999954, 0.29999999999999905`}, {0.9999999999999954, 
     0.30000000000000493`}, {0.9999999999999954, 0.29999999999999905`}, {
     0.9999999999999954, 0.30000000000000493`}, {0.9999999999999954, 
     0.29999999999999905`}, {0.9999999999999954, 0.30000000000000493`}, {
     0.9999999999999954, 0.29999999999999905`}, {0.9999999999999954, 
     0.30000000000000493`}, {0.9999999999999954, 0.29999999999999905`}, {
     0.9999999999999954, 0.30000000000000493`}, {0.9999999999999954, 
     0.29999999999999905`}, {0.9999999999999954, 0.30000000000000493`}, {
     0.9999999999999954, 0.29999999999999905`}, {0.9999999999999954, 
     0.30000000000000493`}, {0.9999999999999954, 0.29999999999999905`}, {
     0.9999999999999954, 0.30000000000000493`}, {0.9999999999999954, 
     0.29999999999999905`}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], 
    FormBox["\"x\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox[
   "\"Spacetime diagram of two trains and a fly\\n Fly's path length = \
1.23333\"", TraditionalForm],
  PlotRange->{{0, 1}, {0., 1.0085963427951317`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.741325989931841*^9, 3.74132603504243*^9, {3.741326074227261*^9, 
   3.741326126053337*^9}, 3.741326429718849*^9, 3.741326468910872*^9, 
   3.7413331954477654`*^9},ExpressionUUID->"6594f878-323f-4d56-b114-\
6258a1031669"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "t_", "]"}], " ", ":=", " ", 
   RowBox[{
    RowBox[{"Log", "[", 
     RowBox[{"t", "+", "1"}], "]"}], "/", 
    RowBox[{"(", " ", 
     RowBox[{
      RowBox[{"Log", "[", "2", "]"}], "/", "0.3"}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"g", "[", "t_", "]"}], ":=", " ", 
   RowBox[{"1", "+", " ", 
    RowBox[{
     RowBox[{"1", "/", "4"}], 
     RowBox[{"Log", "[", 
      RowBox[{"t", "+", "1"}], "]"}]}], "-", " ", 
    RowBox[{"1.8176320469261664`", 
     RowBox[{
      RowBox[{"Log", "[", 
       RowBox[{"t", "+", "1"}], "]"}], "^", "2"}]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Vfly", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{"4", ",", 
     RowBox[{"-", "8"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"coords", " ", "=", 
   RowBox[{"flyTurnCoords", "[", 
    RowBox[{"f", ",", " ", "g", " ", ",", " ", "Vfly", ",", " ", "30"}], 
    "]"}]}], ";", " ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Find", " ", "30", " ", "round", " ", "of", " ", "the", " ", "fly", " ", 
    "meeting", " ", "both", " ", "cars"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Print", "[", 
   RowBox[{"\"\<The fly flies a total of \>\"", ",", " ", 
    RowBox[{"flyPathLength", "[", 
     RowBox[{"1", ",", " ", "0.3", ",", "Vfly"}], "]"}], ",", " ", 
    "\"\< km. (Given by theoretical formula.)\>\""}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Print", "[", 
   RowBox[{
   "\"\<The {t,x} coordinates that the fly meets the car: \>\"", ",", " ", 
    "coords"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Print", "[", 
  RowBox[{
  "\"\<Explicitly sum the flight distance from the coordinates above: \>\"", 
   ",", 
   RowBox[{"pathLength", "[", "coords", "]"}], ",", " ", "\"\< km.\>\""}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"showFlyFlight", "[", 
  RowBox[{"f", ",", "g", ",", "Vfly", ",", " ", "1", ",", " ", "30"}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.741333506174499*^9, 
  3.741333514037925*^9}},ExpressionUUID->"4e008789-a9f8-4949-98c9-\
8a4253b9dea3"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The fly flies a total of \"\>", "\[InvisibleSpace]", 
   "5.2333333333333325`", 
   "\[InvisibleSpace]", "\<\" km. (Given by theoretical formula.)\"\>"}],
  SequenceForm[
  "The fly flies a total of ", 5.2333333333333325`, 
   " km. (Given by theoretical formula.)"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.741333520577395*^9},ExpressionUUID->"7c5c7adf-6720-43b6-b152-\
212261f0f23f"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"The {t,x} coordinates that the fly meets the car: \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0", ",", "0.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.24218240783414097`", ",", "0.9687296313365639`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.34715189207908076`", ",", "0.12897375737704528`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.5128924180059387`", ",", "0.7919358610844772`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.5869014311654687`", ",", "0.19986375580823693`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.6937047375877368`", ",", "0.627076981497308`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.7420595863437099`", ",", "0.24023819144952288`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.8092991967355955`", ",", "0.5091966330170647`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.8399609575935245`", ",", "0.26390254615363207`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.8818524578552761`", ",", "0.4314685472006383`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9010316797314812`", ",", "0.2780347721909975`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9269951953142289`", ",", "0.38188883452198785`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9389095920783262`", ",", "0.28657366040920945`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9549563536366295`", ",", "0.35076070664242254`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9623301499716711`", ",", "0.2917703359620811`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9722322540822979`", ",", "0.3313787524045887`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9767862160321061`", ",", "0.29494705680612104`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9828909898274968`", ",", "0.31936615198768403`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9856999717223832`", ",", "0.29689429682859225`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9894615933953093`", ",", "0.3119407835202964`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9911929527318428`", ",", "0.29808990882802744`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9935100175279338`", ",", "0.307358168012385`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.9945766911830236`", ",", "0.2988247787716668`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9960036607637965`", ",", "0.3045326570947581`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.996660649601446`", ",", "0.2992767463935624`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.9975393451497713`", ",", "0.30279152858686387`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9979439325495788`", ",", "0.29955482938840367`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9984849730591161`", ",", "0.301718991426553`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.9987341010687013`", ",", "0.299725967349871`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.999067221511881`", ",", "0.3010584491225893`"}], "}"}], ",", 
     
     RowBox[{"{", 
      RowBox[{"0.9992206145521867`", ",", "0.2998313048001436`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9994257121567206`", ",", "0.30065169521827895`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9995201556610097`", ",", "0.29989614718396634`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9996464292105447`", ",", "0.30040124138210633`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9997045763407294`", ",", "0.29993606434062847`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9997823190325973`", ",", "0.3002470351080997`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9998181186325892`", ",", "0.2999606383081643`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9998659820738091`", ",", "0.30015209207304383`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9998880227129279`", ",", "0.2999757669600935`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999174904317557`", ",", "0.30009363783540477`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999310600554988`", ",", "0.2999850808454595`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999492021756528`", ",", "0.30005764932607515`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999575564735655`", ",", "0.2999908149427724`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999687258492348`", ",", "0.3000354924454496`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999738692599539`", ",", "0.2999943451596968`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999807457900757`", ",", "0.30002185128018355`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999839123805149`", ",", "0.29999651855667037`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999881459778601`", ",", "0.30001345294605164`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999900955182799`", ",", "0.2999978566226937`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999927019694678`", ",", "0.3000082824274457`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999939022213077`", ",", "0.2999986804127264`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999955069053984`", ",", "0.30000509914908935`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999962458508613`", ",", "0.29999918758538574`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999972337882898`", ",", "0.30000313933509937`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999976887263926`", ",", "0.2999994998302653`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999982969584349`", ",", "0.3000019327584348`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999985770449437`", ",", "0.29999969206635996`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999989515081311`", ",", "0.30000118991910973`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999991239457582`", ",", "0.29999981041809193`"}], "}"}], 
     ",", 
     RowBox[{"{", 
      RowBox[{"0.9999993544871726`", ",", "0.3000007325837407`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.9999994606498506`", ",", "0.2999998832823164`"}], "}"}]}], 
    "}"}]}],
  SequenceForm[
  "The {t,x} coordinates that the fly meets the car: ", {{0, 0.}, {
    0.24218240783414097`, 0.9687296313365639}, {0.34715189207908076`, 
    0.12897375737704528`}, {0.5128924180059387, 0.7919358610844772}, {
    0.5869014311654687, 0.19986375580823693`}, {0.6937047375877368, 
    0.627076981497308}, {0.7420595863437099, 0.24023819144952288`}, {
    0.8092991967355955, 0.5091966330170647}, {0.8399609575935245, 
    0.26390254615363207`}, {0.8818524578552761, 0.4314685472006383}, {
    0.9010316797314812, 0.2780347721909975}, {0.9269951953142289, 
    0.38188883452198785`}, {0.9389095920783262, 0.28657366040920945`}, {
    0.9549563536366295, 0.35076070664242254`}, {0.9623301499716711, 
    0.2917703359620811}, {0.9722322540822979, 0.3313787524045887}, {
    0.9767862160321061, 0.29494705680612104`}, {0.9828909898274968, 
    0.31936615198768403`}, {0.9856999717223832, 0.29689429682859225`}, {
    0.9894615933953093, 0.3119407835202964}, {0.9911929527318428, 
    0.29808990882802744`}, {0.9935100175279338, 0.307358168012385}, {
    0.9945766911830236, 0.2988247787716668}, {0.9960036607637965, 
    0.3045326570947581}, {0.996660649601446, 0.2992767463935624}, {
    0.9975393451497713, 0.30279152858686387`}, {0.9979439325495788, 
    0.29955482938840367`}, {0.9984849730591161, 0.301718991426553}, {
    0.9987341010687013, 0.299725967349871}, {0.999067221511881, 
    0.3010584491225893}, {0.9992206145521867, 0.2998313048001436}, {
    0.9994257121567206, 0.30065169521827895`}, {0.9995201556610097, 
    0.29989614718396634`}, {0.9996464292105447, 0.30040124138210633`}, {
    0.9997045763407294, 0.29993606434062847`}, {0.9997823190325973, 
    0.3002470351080997}, {0.9998181186325892, 0.2999606383081643}, {
    0.9998659820738091, 0.30015209207304383`}, {0.9998880227129279, 
    0.2999757669600935}, {0.9999174904317557, 0.30009363783540477`}, {
    0.9999310600554988, 0.2999850808454595}, {0.9999492021756528, 
    0.30005764932607515`}, {0.9999575564735655, 0.2999908149427724}, {
    0.9999687258492348, 0.3000354924454496}, {0.9999738692599539, 
    0.2999943451596968}, {0.9999807457900757, 0.30002185128018355`}, {
    0.9999839123805149, 0.29999651855667037`}, {0.9999881459778601, 
    0.30001345294605164`}, {0.9999900955182799, 0.2999978566226937}, {
    0.9999927019694678, 0.3000082824274457}, {0.9999939022213077, 
    0.2999986804127264}, {0.9999955069053984, 0.30000509914908935`}, {
    0.9999962458508613, 0.29999918758538574`}, {0.9999972337882898, 
    0.30000313933509937`}, {0.9999976887263926, 0.2999994998302653}, {
    0.9999982969584349, 0.3000019327584348}, {0.9999985770449437, 
    0.29999969206635996`}, {0.9999989515081311, 0.30000118991910973`}, {
    0.9999991239457582, 0.29999981041809193`}, {0.9999993544871726, 
    0.3000007325837407}, {0.9999994606498506, 0.2999998832823164}}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.741333520581831*^9},ExpressionUUID->"996532be-a77a-4094-8951-\
5602609f63c9"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Explicitly sum the flight distance from the coordinates above: \
\"\>", "\[InvisibleSpace]", "5.233330495705096`", 
   "\[InvisibleSpace]", "\<\" km.\"\>"}],
  SequenceForm[
  "Explicitly sum the flight distance from the coordinates above: ", 
   5.233330495705096, " km."],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.7413335205935297`*^9},ExpressionUUID->"3ef7b60a-9df8-4d9d-8b78-\
e12482e62404"]
}, Open  ]],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVk/k71AkAhyn7UDQlGc/U0rJjWhRTyZFdnxg2mSRXsii5CtWiPKV2syNU
jqhmI1eJlKQhR+VYR5MiDPNVQ8tMMeQYvrSuarHtD+/zPu8f8Gr7/uocsERO
Ts7hK//bPmCoo27YzTKmlv1mYNbaUoG1NlRCM4bBTOmqBwHa2HozLbOUZgOb
x/cPifw3g90qepRFc8VmY02dw35WcPefrblK80deUdtkro8Teo0usJJoJ3GO
0DQ28jyEW+qOcfG0GPhY+vn9sjcMHKXSDZdoXPQFOYqGt3Ow3yOHNzGZh3lf
dsoM/wqUFzleO7V48M0Wue5lpEPXaXzoWUIZ2unzHyPW5eBUmznSpp7iyPIs
r5DAO9AoUxXLy9dinBrFNXQrQEUfq0XwYwM6L2VRj8cUoSE4a52HjI9NexOt
gxqLMc34aWXRsReIZ8eapd58hCWfClet023G/smCmtHUMpgs+lS4PGxBo1oa
XgZWoCXGuK1RXwCdODLOWfcJ1qeMfioYb0dS5VnBonwlRmcl4tdMIXpzGHqF
j6uQN1LVTLlM4IfIfZXc+BpQNO+SUmknHD1DzG441CIxqDzwFv0N4gKLT4xF
1GFmR6H0SJQIsRb6tiYu9Ti5hV9GfdaFM+Vh6jytBkge8hM6tN+i4fMcdWS2
AV+COzP0zvwNZiIs5JqfwcBKcSGwqgeskMtR5gl87LytfbhEQwxK96tTTR7P
cUrzoM57LwmORx59P6vRiI0yN2WRwzv4U4or5gSNUFs5ocT//A5PqaolMu4L
KNRm8L7PfA9u+gXqLvuXCDGu6l7G7kNA0pQLS6UJhbt8b/010wdmj/raDS+b
MD26dtXg9X5MDJmmG0U0o9xl51KujRTxC/P/Rhq+QpRd7M2yQSlsFZs+2nW/
gnavfVdu7AD+GTx9pf5cC7abxnBpWwbhluzQzGC2wktL8Eme+NpdeSIe0Yrp
5qS+UM4HrKGlGPVGtyFN4cBJZ/oQoj0Yu6PpAqiJy28v4Q8h4BI1zLRegG9+
57iahw3jar31xRzjdsgVHOD1rR7Boc4Nx/Si2xGezkta3TCCe1ZzxRav21Fj
cFFJ9fgowq9ZPX+r2wFV+/CN0RQZzDqt3S1DO9CzqZ2IrJYhJHVGUamuA8XZ
oEsPjCH4gQ39yTIhvHkmqpoLY9hha6Ji7iTEH7E5nJ774yA8890WsoQoGtLM
oOwmwdp2NKhfKsTFrFgf8R4SOzImvLUGhfB3HtN96ESi5OxpG48PQnxbXV3s
4E7iWm7qh7ZhIeKTPRsTfUmcY5vEPR0X4ojJjcnlkSTEzssZiXNC6MSssVPM
J7FsP2+OoUJgwey3FaJ7JDz6FZk+Kwh0j/UL8wtJKO1L8LhBIZDiXur9cwkJ
006N88qqBBb1nU/EVpPI9g5ikuoEejqSs5cSJPaELE6VrifwJG7Wj3hNoulu
mqPsOwJci4N6uV0kylihmXQdAuw7hmXWYhIW4RKVP+kEKk+3NnGGSfQkSOwi
9Ahc37Qt2UlGojI/aVuRPoGwvkxXbZLE/dbzawYMvn6y+6ikboqEgppDgash
AQX5zryUWRJF6ToHE40IvCu3CPb5TGJAzlaRzyRQHZxrxJwnIY0sz/mymUDq
euXpxUUSNeYRhlu3EvgP8VZmMA==
        "]]},
      Annotation[#, "Charting`Private`Tag$3377#1"]& ], 
     TagBox[
      {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwV1nk0lGscB3BpIUqUyBaKW9lCpSK+Imu0kKsFKUJkK7cr3YgQhYpJKaSs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        "]]},
      Annotation[#, "Charting`Private`Tag$3377#2"]& ]}, {}, {}}, 
   LineBox[{{0, 0.}, {0.24218240783414097`, 0.9687296313365639}, {
     0.34715189207908076`, 0.12897375737704528`}, {0.5128924180059387, 
     0.7919358610844772}, {0.5869014311654687, 0.19986375580823693`}, {
     0.6937047375877368, 0.627076981497308}, {0.7420595863437099, 
     0.24023819144952288`}, {0.8092991967355955, 0.5091966330170647}, {
     0.8399609575935245, 0.26390254615363207`}, {0.8818524578552761, 
     0.4314685472006383}, {0.9010316797314812, 0.2780347721909975}, {
     0.9269951953142289, 0.38188883452198785`}, {0.9389095920783262, 
     0.28657366040920945`}, {0.9549563536366295, 0.35076070664242254`}, {
     0.9623301499716711, 0.2917703359620811}, {0.9722322540822979, 
     0.3313787524045887}, {0.9767862160321061, 0.29494705680612104`}, {
     0.9828909898274968, 0.31936615198768403`}, {0.9856999717223832, 
     0.29689429682859225`}, {0.9894615933953093, 0.3119407835202964}, {
     0.9911929527318428, 0.29808990882802744`}, {0.9935100175279338, 
     0.307358168012385}, {0.9945766911830236, 0.2988247787716668}, {
     0.9960036607637965, 0.3045326570947581}, {0.996660649601446, 
     0.2992767463935624}, {0.9975393451497713, 0.30279152858686387`}, {
     0.9979439325495788, 0.29955482938840367`}, {0.9984849730591161, 
     0.301718991426553}, {0.9987341010687013, 0.299725967349871}, {
     0.999067221511881, 0.3010584491225893}, {0.9992206145521867, 
     0.2998313048001436}, {0.9994257121567206, 0.30065169521827895`}, {
     0.9995201556610097, 0.29989614718396634`}, {0.9996464292105447, 
     0.30040124138210633`}, {0.9997045763407294, 0.29993606434062847`}, {
     0.9997823190325973, 0.3002470351080997}, {0.9998181186325892, 
     0.2999606383081643}, {0.9998659820738091, 0.30015209207304383`}, {
     0.9998880227129279, 0.2999757669600935}, {0.9999174904317557, 
     0.30009363783540477`}, {0.9999310600554988, 0.2999850808454595}, {
     0.9999492021756528, 0.30005764932607515`}, {0.9999575564735655, 
     0.2999908149427724}, {0.9999687258492348, 0.3000354924454496}, {
     0.9999738692599539, 0.2999943451596968}, {0.9999807457900757, 
     0.30002185128018355`}, {0.9999839123805149, 0.29999651855667037`}, {
     0.9999881459778601, 0.30001345294605164`}, {0.9999900955182799, 
     0.2999978566226937}, {0.9999927019694678, 0.3000082824274457}, {
     0.9999939022213077, 0.2999986804127264}, {0.9999955069053984, 
     0.30000509914908935`}, {0.9999962458508613, 0.29999918758538574`}, {
     0.9999972337882898, 0.30000313933509937`}, {0.9999976887263926, 
     0.2999994998302653}, {0.9999982969584349, 0.3000019327584348}, {
     0.9999985770449437, 0.29999969206635996`}, {0.9999989515081311, 
     0.30000118991910973`}, {0.9999991239457582, 0.29999981041809193`}, {
     0.9999993544871726, 0.3000007325837407}, {0.9999994606498506, 
     0.2999998832823164}}]},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"t\"", TraditionalForm], 
    FormBox["\"x\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
     Charting`ScaledFrameTicks[{Identity, Identity}]}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotLabel->FormBox[
   "\"Spacetime diagram of two trains and a fly\\n Fly's path length = \
5.23333\"", TraditionalForm],
  PlotRange->{{0, 1}, {0., 1.0085963427951317`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.741333520710154*^9},ExpressionUUID->"b2845906-26e6-47fd-9e36-\
341e65a1eab8"]
}, Open  ]]
},
WindowSize->{1120, 1028},
WindowMargins->{{Automatic, 0}, {Automatic, 0}},
FrontEndVersion->"11.2 for Mac OS X x86 (32-bit, 64-bit Kernel) (September \
10, 2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 12330, 279, 997, "Input",ExpressionUUID->"26c5627a-761b-4c37-88eb-ad85b5c29dbf"],
Cell[CellGroupData[{
Cell[12913, 303, 3370, 83, 262, "Input",ExpressionUUID->"928a85d9-42c3-4186-8265-0cee8aabe1d2"],
Cell[CellGroupData[{
Cell[16308, 390, 680, 12, 24, "Print",ExpressionUUID->"7edca5f8-b883-4ba7-8fe0-3503ab2a6116"],
Cell[16991, 404, 2203, 48, 44, "Print",ExpressionUUID->"ea40fb29-9b92-427c-b65b-5945aa24129e"],
Cell[19197, 454, 728, 14, 24, "Print",ExpressionUUID->"f596cf8b-b1a4-49c2-9234-34b21ef5f8fc"]
}, Open  ]],
Cell[19940, 471, 5962, 119, 287, "Output",ExpressionUUID->"588da5bd-c883-4fed-967c-ab6dcc73f13e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25939, 595, 2590, 70, 220, "Input",ExpressionUUID->"bff9cfb2-dcdf-4b83-929a-cc96b6e8731a"],
Cell[CellGroupData[{
Cell[28554, 669, 552, 11, 24, "Print",ExpressionUUID->"437ee6fd-5464-4f83-8300-f76c28109d72"],
Cell[29109, 682, 2945, 63, 63, "Print",ExpressionUUID->"a538f80f-134a-488a-989d-a11fb081215e"],
Cell[32057, 747, 604, 13, 24, "Print",ExpressionUUID->"577f9c22-7924-4e5e-9c9c-0af6e9ae8085"]
}, Open  ]],
Cell[32676, 763, 6262, 124, 287, "Output",ExpressionUUID->"25f3163e-d048-4b8a-9374-07d1cf54e1a2"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38975, 892, 2729, 77, 199, "Input",ExpressionUUID->"e7aec5fb-b84e-4bdd-8a21-27332f67fc14"],
Cell[CellGroupData[{
Cell[41729, 973, 525, 10, 24, "Print",ExpressionUUID->"5779cc5a-eb12-4873-8c63-153f99ebc349"],
Cell[42257, 985, 6510, 144, 139, "Print",ExpressionUUID->"c2e55fbb-e965-463b-a1fa-af63afd8b626"],
Cell[48770, 1131, 577, 12, 24, "Print",ExpressionUUID->"b905afe9-de86-4b47-a345-8cf4129fd920"]
}, Open  ]],
Cell[49362, 1146, 8876, 164, 287, "Output",ExpressionUUID->"98a76991-f70f-4fba-8f71-772a7162c3cb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[58275, 1315, 2706, 77, 199, "Input",ExpressionUUID->"d9f2d61b-af28-4db3-9ff7-3580181cbc85"],
Cell[CellGroupData[{
Cell[61006, 1396, 501, 10, 24, "Print",ExpressionUUID->"cb9492f0-b404-4806-b14f-15b4bf1d1fe8"],
Cell[61510, 1408, 6149, 135, 120, "Print",ExpressionUUID->"506d1e3e-6cf1-4eab-b5f8-ed7bfd7a3d28"],
Cell[67662, 1545, 546, 11, 24, "Print",ExpressionUUID->"6d6ab778-89a4-469c-926b-d538729160b6"]
}, Open  ]],
Cell[68223, 1559, 8691, 161, 287, "Output",ExpressionUUID->"5cea7f62-0ecb-4e99-9fca-62f26f67a6dc"]
}, Open  ]],
Cell[CellGroupData[{
Cell[76951, 1725, 2450, 68, 178, "Input",ExpressionUUID->"fdfbdd8a-f074-46a8-b2e0-7f5f5dab3f76"],
Cell[CellGroupData[{
Cell[79426, 1797, 525, 12, 24, "Print",ExpressionUUID->"9bb12bed-504c-41fd-a292-89e7c4f273b1"],
Cell[79954, 1811, 9434, 209, 215, "Print",ExpressionUUID->"98005d76-05e0-472f-99b0-8ad60c2ade34"],
Cell[89391, 2022, 535, 12, 24, "Print",ExpressionUUID->"90c7a527-5e19-4a95-a81c-3f85d84e1b02"]
}, Open  ]],
Cell[89941, 2037, 8220, 152, 285, "Output",ExpressionUUID->"7d0be6cc-a3d1-4879-9fd7-93c4f8af7669"]
}, Open  ]],
Cell[CellGroupData[{
Cell[98198, 2194, 2410, 68, 178, "Input",ExpressionUUID->"7d11a85f-3053-4d2d-86a8-c843e526e34a"],
Cell[CellGroupData[{
Cell[100633, 2266, 492, 11, 24, "Print",ExpressionUUID->"cb1a16d0-54d5-4312-abd5-e0b45c6fd3fa"],
Cell[101128, 2279, 9519, 218, 158, "Print",ExpressionUUID->"9b2d57e2-e60e-4bc3-af07-946f3353dd55"],
Cell[110650, 2499, 504, 11, 24, "Print",ExpressionUUID->"efd5d8ae-3dea-4fa1-8906-824f3503df57"]
}, Open  ]],
Cell[111169, 2513, 8121, 150, 285, "Output",ExpressionUUID->"307442fd-698c-4568-accf-62cb00e5993b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[119327, 2668, 2650, 73, 178, "Input",ExpressionUUID->"7b65bbc7-a3c1-4066-a62f-ef823f631d59"],
Cell[CellGroupData[{
Cell[122002, 2745, 596, 13, 24, "Print",ExpressionUUID->"8f63f26e-d240-4924-a98c-3d64b0522f17"],
Cell[122601, 2760, 9516, 206, 177, "Print",ExpressionUUID->"88af7980-8f65-4a13-a36f-d932e7ee52ed"],
Cell[132120, 2968, 606, 13, 24, "Print",ExpressionUUID->"acb5834f-842d-4a9f-b4ab-2916af1c9308"]
}, Open  ]],
Cell[132741, 2984, 19292, 333, 285, "Output",ExpressionUUID->"307263e1-9f60-409f-a915-ebaa1bf800e1"]
}, Open  ]],
Cell[CellGroupData[{
Cell[152070, 3322, 2446, 67, 178, "Input",ExpressionUUID->"d6a95b89-95d8-4861-9f09-caedccfeec8e"],
Cell[CellGroupData[{
Cell[154541, 3393, 591, 13, 24, "Print",ExpressionUUID->"ab792ee6-2f02-4de5-a26c-23a1887f07b6"],
Cell[155135, 3408, 9592, 215, 139, "Print",ExpressionUUID->"6c50e8d3-9dda-4a17-8862-e94692225c93"],
Cell[164730, 3625, 600, 13, 24, "Print",ExpressionUUID->"c8e65e5a-ae4a-4a15-95a4-d1ea7fe8daa5"]
}, Open  ]],
Cell[165345, 3641, 11151, 200, 285, "Output",ExpressionUUID->"6594f878-323f-4d56-b114-6258a1031669"]
}, Open  ]],
Cell[CellGroupData[{
Cell[176533, 3846, 2138, 60, 178, "Input",ExpressionUUID->"4e008789-a9f8-4949-98c9-8a4253b9dea3"],
Cell[CellGroupData[{
Cell[178696, 3910, 448, 11, 24, "Print",ExpressionUUID->"7c5c7adf-6720-43b6-b152-212261f0f23f"],
Cell[179147, 3923, 9409, 210, 215, "Print",ExpressionUUID->"996532be-a77a-4094-8951-5602609f63c9"],
Cell[188559, 4135, 457, 11, 24, "Print",ExpressionUUID->"3ef7b60a-9df8-4d9d-8b78-e12482e62404"]
}, Open  ]],
Cell[189031, 4149, 10993, 198, 285, "Output",ExpressionUUID->"b2845906-26e6-47fd-9e36-341e65a1eab8"]
}, Open  ]]
}
]
*)

